@@ -1,8 +1,6 @@
 //  -*-C++-*-           emacs magic for .h files
 /*
 
- $Id: arch.h,v 1.42.2.1 2003/01/13 10:32:43 helio Exp $
-
  ark -- archiver for the KDE project
 
  Copyright (C)
@@ -24,7 +22,7 @@
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
- Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
@@ -44,10 +42,8 @@
 // To add a new archive:
 // 1. Create a new header file and a source code module
 // 2. Add an entry to the ArchType enum in arch.h.
-// 3. Add appropriate types to getArchType() and archFactory() in arch.cpp
-// 4. Add your extension to the list of valid archives in
-//   ArkSettings::getFilter (you might also want to add a separate entry)
-//
+// 3. Add appropriate types to buildFormatInfo() in archiveformatinfo.cpp
+//    and archFactory() in arch.cpp
 
 
 #ifndef ARCH_H
@@ -139,14 +135,9 @@ public:
 
   QString getUtility() { return m_archiver_program; }
 
-  static ArchType getArchType(const QString &archname, QString &extension,
-                              const KURL &realURL = KURL());
-
-  static ArchType getArchTypeByExtension(const QString &archname,
-                                         QString & extension);
-
   static Arch *archFactory(ArchType aType, ArkSettings *settings,
-			   ArkWidgetBase *parent, const QString &filename);
+                ArkWidgetBase *parent, const QString &filename,
+                const QString &openAsMimeType = QString::null );
 
 protected slots:
   void slotCancel();
