@@ -1,42 +1,77 @@
 /*
   Copyright (C)
- 
+
   2001: Macadamian Technologies Inc (author: Jian Huang, jian@macadamian.com)
- 
+
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.
- 
+
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
- 
+
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- 
+  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+
 */
 
 #ifndef __ark_part_h__
 #define __ark_part_h__
 
+#include "arkwidget.h"
+
 #include <kparts/part.h>
 #include <kparts/browserextension.h>
+#include <kparts/statusbarextension.h>
 #include <kparts/factory.h>
+#include <kaction.h>
+#include <kprogress.h>
+
+#include <qlabel.h>
+
 
-class QObject;
-class QString;
-class QStringList;
-class KAction;
-class KRecentFilesAction;
-class KToggleAction;
-class KInstance;
-class KLibFactory;
 class KAboutData;
 
-class ArkWidget;
+
+class ArkBrowserExtension: public KParts::BrowserExtension
+{
+    Q_OBJECT
+public:
+    ArkBrowserExtension( KParts::ReadOnlyPart * parent, const char * name = 0L );
+public slots:
+    void slotOpenURLRequested( const KURL & url );
+};
+
+class ArkStatusBarExtension: public KParts::StatusBarExtension
+{
+    Q_OBJECT
+public:
+    ArkStatusBarExtension( KParts::ReadWritePart * parent );
+    ~ArkStatusBarExtension();
+
+public slots:
+    void slotSetStatusBarSelectedFiles( const QString & text );
+    void slotSetStatusBarText( const QString & text );
+    void slotSetBusy( const QString & text );
+    void slotSetReady();
+    void slotProgress();
+
+protected:
+    void setupStatusBar();
+
+private:
+    bool m_bBusy;
+    QLabel *m_pStatusLabelSelect; // How many files are selected
+    QLabel *m_pStatusLabelTotal;  // How many files in archive
+    QLabel *m_pBusyText;
+    KProgress *m_pProgressBar;
+    QTimer *m_pTimer;
+};
+
 
 class ArkPart: public KParts::ReadWritePart
 {
@@ -47,22 +82,24 @@ public:
     virtual ~ArkPart();
 
     static KAboutData* createAboutData();
-    void setArchivePopupEnabled( const bool b );
 
 public slots:
     void fixEnables();//rename to slotFixEnables()...
     void disableActions();
-    void slotArchivePopup( const QPoint & pPoint );
     void slotFilePopup( const QPoint & pPoint );
+    void file_save_as();
     bool saveFile();
+    bool openURL( const KURL & url );
     bool closeURL();
-    virtual bool openURL( const KURL &url );
+
 signals:
     void fixActionState( const bool & bHaveFiles );
-    void removeRecentURL( const QString & url );
-    void addRecentURL(  const QString & url );
+    void removeRecentURL( const KURL & url );
+    void addRecentURL( const KURL & url );
+
 protected:
     virtual bool openFile();  //Opening an archive file
+    bool closeArchive();
     void setupActions();
     void initialEnables();
     void init();
@@ -72,9 +109,10 @@ protected slots:
 
 private:
     ArkWidget  *awidget;
-    bool m_ArchivePopupEnabled;
+    ArkBrowserExtension *m_ext;
+    ArkStatusBarExtension *m_bar;
 
-    //actions that were formerly defined in Arkwidget
+    KAction *saveAsAction;
     KAction *addFileAction;
     KAction *addDirAction;
     KAction *extractAction;
@@ -93,6 +131,7 @@ private:
     KAction *popupViewAction;
     KAction *popupOpenWithAction;
     KAction *shellOutputAction;
+
 };
 
 #endif
