@@ -1,7 +1,5 @@
 /*
 
- $Id: arksettings.h,v 1.15.6.1 2003/01/13 10:32:43 helio Exp $
-
  ark -- archiver for the KDE project
 
  Copyright (C)
@@ -23,7 +21,7 @@
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
- Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
@@ -67,8 +65,6 @@ public:
     LAST_ADD_DIR, FIXED_ADD_DIR
   };
 
-  const QString getFilter();
-	
   QString getTarCommand() const { return tar_exe; }
   void setTarCommand(const QString& _cmd) { tar_exe = _cmd; }
 	
