@@ -1,12 +1,11 @@
 //  -*- mode: c++; c-basic-offset: 4; -*-
 /*
  
-  $Id: arkwidget.h,v 1.70.2.1 2003/01/13 10:32:43 helio Exp $
- 
   ark -- archiver for the KDE project
  
   Copyright (C)
  
+  2003: Georg Robbers <Georg.Robbers@urz.uni-hd.de>
   2002: Helio Chissini de Castro <helio@conectiva.com.br>
   2001: Corel Corporation (author: Michael Jarrett, michaelj@corel.com)
   1999-2000: Corel Corporation (author: Emily Ezust, emilye@corel.com)
@@ -25,19 +24,19 @@
  
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  
 */
 
 #ifndef ARKWIDGET_H
 #define ARKWIDGET_H
 
-#define ARK_VERSION "1.9"
+#define ARK_VERSION "2.1.9"
 
 #include "arkwidgetbase.h"
-#include "arktoplevelwindow.h"
+#include <kio/job.h>
+#include <qwidget.h>
 
-class QWidget;
 class QPoint;
 class QString;
 class QStringList;
@@ -51,6 +50,7 @@ class KConfig;
 class KURL;
 class KRun;
 class KTempFile;
+class KTempDir;
 
 class Arch;
 class ArkSettings;
@@ -63,24 +63,31 @@ class ArkWidget : public QWidget, public ArkWidgetBase
 public:
     ArkWidget( QWidget *parent=0, const char *name=0 );
     virtual ~ArkWidget();
-    void showZip( const QString & name );
 
-    bool isEditInProgress() { return m_bEditInProgress; }
-    void setExtractOnly(bool extOnly) { m_extractOnly = extOnly; }
-    bool getExtractOnly() { return m_extractOnly; }
-    ArkSettings *settings() { return m_settings; }
+    virtual void setExtractOnly(bool extOnly) { m_extractOnly = extOnly; }
+    virtual ArkSettings *settings() { return m_settings; }
     bool allowedArchiveName( const KURL & u );
     bool file_save_as( const KURL & u );
-    KURL getSaveAsFileName();
+    virtual KURL getSaveAsFileName();
+    virtual void setOpenAsMimeType( const QString & mimeType );
+    QString & openAsMimeType(){ return m_openAsMimeType; }
+    void prepareViewFiles( const QStringList & fileList );
+    virtual void setArchivePopupEnabled( bool b );
+
+    virtual void extractTo( const KURL & targetDirectory, const KURL & archive, bool bGuessName );
+    virtual void addToArchive( const KURL::List & filesToAdd, const KURL & archive = KURL() );
+    void convertTo( const KURL & u );
+
+    bool isModified() { return m_modified; }
+    void setModified( bool b ) { m_modified = b; }
 
 public slots:
-    void file_open(const KURL& url);
-    //void file_open(const QString &);  // opens the specified archive
+    void file_open( const KURL& url);
     void edit_view_last_shell_output();
-    void file_close();
-    void file_new();
-    void options_dirs();
-    void options_saveNow();
+    virtual void file_close();
+    virtual void file_new();
+    virtual void options_dirs();
+    virtual void options_saveNow();
 
 protected slots:
     void edit_select();
@@ -95,11 +102,10 @@ protected slots:
     bool action_extract();
     void slotOpenWith();
     void action_edit();
-    void slotSaveAsDone(KIO::Job *);
 
     void doPopup(QListViewItem *, const QPoint &, int); // right-click menus
+    void viewFile(); // doubleClick view files
 
-    void showFavorite();
     void slotSelectionChanged();
     void slotOpen(Arch *, bool, const QString &, int);
     void slotCreate(Arch *, bool, const QString &, int);
@@ -110,25 +116,32 @@ protected slots:
     void slotEditFinished(KProcess *);
     void selectByPattern(const QString & _pattern);
 signals:
+    void openURLRequest( const KURL & url );
     void request_file_quit();
+    void setBusy( const QString & );
+    void setReady();
     void fixActions();
     void disableAllActions();
     void signalFilePopup( const QPoint & pPoint );
     void signalArchivePopup( const QPoint & pPoint );
     void setStatusBarText( const QString & text );
     void setStatusBarSelectedFiles( const QString & text );
-    void removeRecentURL( const QString & url );
-    void addRecentURL( const QString & url );
+    void removeRecentURL( const KURL & url );
+    void addRecentURL( const KURL & url );
     void setWindowCaption( const QString &caption );
     void removeOpenArk( const KURL & );
     void addOpenArk( const KURL & );
+    void createDone( bool );
+    void openDone( bool );
+    void createRealArchiveDone( bool );
+    void extractRemoteMovingDone();
 
 protected:
 
     // DND
     void dragMoveEvent(QDragMoveEvent *e);
     void dropEvent(QDropEvent* event);
-    void dropAction(QStringList *list);
+    void dropAction(QStringList & list);
 
 private: // methods
     // disabling/enabling of buttons and menu items
@@ -146,15 +159,54 @@ private: // methods
     // ask user whether to create a real archive from a compressed file
     // returns filename if so. Otherwise, empty.
     KURL askToCreateRealArchive();
-    void createRealArchive(const QString &strFilename);
-    KURL getCreateFilename(const QString & _caption,
-                           const QString & _filter = QString::null,
-                           const QString & _extension = QString::null);
+    Arch * getNewArchive( const QString & _fileName );
+    void createRealArchive( const QString &strFilename,
+                            const QStringList & filesToAdd = QStringList() );
+    KURL getCreateFilename( const QString & _caption,
+                            const QString & _defaultMimeType = QString::null,
+                            bool allowCompressed = true,
+                            const QString & _suggestedName = QString::null );
 
-    // complains if the filename has capital letters or is tbz or tbz2
-    bool badBzipName(const QString & _filename);
     bool reportExtractFailures(const QString & _dest, QStringList *_list);
-    //bool download(const KURL &, QString &);
+    QStringList existingFiles( const QString & _dest, QStringList & _list );
+
+    void extractOnlyOpenDone();
+    void extractRemoteInitiateMoving( const KURL & target );
+    void editStart();
+
+    void busy( const QString & text );
+    void holdBusy();
+    void resumeBusy();
+    void ready();
+
+    //suggests an extract directory based on archive name
+    const QString guessName( const KURL & archive );
+
+private slots:
+    void startDrag( const QStringList & fileList );
+    void startDragSlotExtractDone( bool );
+    void editSlotExtractDone();
+    void editSlotAddDone( bool success );
+    void viewSlotExtractDone();
+    void openWithSlotExtractDone();
+
+    void createRealArchiveSlotCreate( Arch * newArch, bool success,
+                                      const QString & fileName, int nbr );
+    void createRealArchiveSlotAddDone( bool success );
+    void createRealArchiveSlotAddFilesDone( bool success );
+
+    void convertSlotExtractDone( bool success );
+    void convertSlotCreate();
+    void convertSlotCreateDone( bool success );
+    void convertSlotAddDone( bool success );
+    void convertFinish();
+
+    void extractToSlotOpenDone( bool success );
+    void extractToSlotExtractDone( bool success );
+
+    void addToArchiveSlotOpenDone( bool success );
+    void addToArchiveSlotCreateDone( bool success );
+    void addToArchiveSlotAddDone( bool success );
 
 protected:
     void arkWarning(const QString& msg);
@@ -166,25 +218,16 @@ protected:
     void createArchive(const QString & name);
     void openArchive(const QString & name);
 
-    void showFile(FileLVI *);
+    void showCurrentFile();
 
 private: // data
 
-    QString m_strNewArchname;
+    bool m_bBusy;
+    bool m_bBusyHold;
 
-
-    // true if user is trying to view something. For use in slotExtractDone
-    bool m_bViewInProgress;
-    // true if user is trying to openWith something. For use in slotExtractDone
-    bool m_bOpenWithInProgress;
-    // for use in slotExtractDone: the url.
+    // for use in the edit methods: the url.
     QString m_strFileToView;
 
-    //true if user is trying to edit something. For use in slotExtractDone
-    bool m_bEditInProgress;
-
-    // true if user is trying to transform a compressed file into a real archive
-    bool m_bMakeCFIntoArchiveInProgress;
     // the compressed file to be added into the new archive
     QString m_compressedFile;
 
@@ -197,19 +240,32 @@ private: // data
     // URL to extract to.
     KURL m_extractURL;
 
+    // the mimetype the user wants to open this archive as
+    QString m_openAsMimeType;
+
     // if they're dragging in files, this is the temporary list for when
     // we have to create an archive:
     QStringList *m_pTempAddList;
-    bool m_bDropFilesInProgress;
 
     KRun *m_pKRunPtr;
 
-    KURL mSaveAsURL;
-
-    KTempFile *mpTempFile;
     QStringList *mpDownloadedList;
 
-    QStringList *mpAddList;
+    bool m_bArchivePopupEnabled;
+
+    KTempDir * m_convert_tmpDir;
+    KURL m_convert_saveAsURL;
+    bool m_convertSuccess;
+
+    KURL m_extractTo_targetDirectory;
+
+    KURL::List m_addToArchive_filesToAdd;
+    KURL m_addToArchive_archive;
+
+    KTempDir * m_createRealArchTmpDir;
+    KTempDir * m_extractRemoteTmpDir;
+
+    bool m_modified;
 };
 
 #endif /* ARKWIDGET_H*/
