@@ -15,13 +15,12 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
 // Qt includes
 #include <qdir.h>
-#include <qdragobject.h>
 #include <qfile.h>
 #include <qfileinfo.h>
 #include <qregexp.h> 
@@ -36,6 +35,7 @@
 #include <kio/job.h>
 #include <kio/netaccess.h>
 #include <klocale.h>
+#include <kurldrag.h>
 
 // ark includes
 #include "arkapp.h"
@@ -165,7 +165,7 @@ ArkWidgetPart::slotOpen(Arch *_newarch, bool _success, const QString & _filename
 		QString path = fi.dirPath( true );
 		m_settings->setLastOpenDir( path );
 		
-		if ( _filename.left(9) == QString("/tmp/ark.") || !fi.isWritable() )
+		if ( _filename.startsWith("/tmp/ark.") || !fi.isWritable() )
 		{
 			_newarch->setReadOnly(true);
 			QApplication::restoreOverrideCursor(); // no wait cursor during a msg box
@@ -202,16 +202,15 @@ ArkWidgetPart::slotExtractDone()
 	else if (m_bDragInProgress)
 	{
 		m_bDragInProgress = false;
-		QStrList list;
+		KURL::List list;
 		for (QStringList::Iterator it = mDragFiles.begin(); it != mDragFiles.end(); ++it)
 		{
-			QString URL;
-			URL = m_settings->getTmpDir();
-			URL += *it;
-			list.append( QUriDrag::localFileToUri(URL) );
+			KURL url;
+			url.setPath(m_settings->getTmpDir() + *it);
+			list.append( url );
 		}
 		
-		QUriDrag *d = new QUriDrag(list, archiveContent->viewport());
+		KURLDrag *d = new KURLDrag(list, archiveContent->viewport());
 		m_bDropSourceIsSelf = true;
 		d->dragCopy();
 		m_bDropSourceIsSelf = false;
