@@ -1,8 +1,6 @@
 //  -*-C++-*-           emacs magic for .h files
 /*
 
-    $Id: compressedfile.h,v 1.4.6.1 2003/01/13 10:32:43 helio Exp $
-
     ark: A program for modifying archives via a GUI.
 
     Copyright (C)
@@ -22,7 +20,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 #ifndef __COMPRESSED_FILE_H__
@@ -32,6 +30,7 @@ class QString;
 class QCString;
 class QStringList;
 class KProcess;
+class KTempDir;
 
 class Arch;
 class ArkSettings;
@@ -50,8 +49,8 @@ class CompressedFile : public Arch
   Q_OBJECT
 public:
   CompressedFile( ArkSettings *_settings, ArkWidgetBase *_gui,
-		  const QString & _fileName );
-  virtual ~CompressedFile() { }
+		  const QString & _fileName, const QString &_openAsMimeType );
+  virtual ~CompressedFile();
 	
   virtual void open();
   virtual void create();
@@ -63,8 +62,7 @@ public:
   virtual void unarchFile(QStringList *, const QString & _destDir="",
 			  bool viewFriendly=false);
 
-  QString getUnCompressor();
-  QString getCompressor();
+  QString tempFileName(){ return m_tmpfile; }
 
 private slots:
   void slotUncompressDone(KProcess *);
@@ -74,8 +72,14 @@ private slots:
 private:
   void initExtract( bool, bool, bool );
   void setHeaders();
+  void initData();
+  QString extension();
+
+  QString m_openAsMimeType;
+  KTempDir * m_tempDirectory;
   QString m_tmpdir;
   QString m_tmpfile;
+  QStringList m_defaultExtensions;
 
   // for use with addFile
   FILE *fd;
