@@ -1,6 +1,6 @@
 /*
 
- $Id: deleteDlg.cpp,v 1.2 2000/08/29 19:01:05 waba Exp $
+ $Id: deleteDlg.cpp,v 1.3.4.1 2004/04/14 11:45:00 binner Exp $
 
  ark -- archiver for the KDE project
 
@@ -21,7 +21,7 @@
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
- Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
@@ -44,7 +44,7 @@ DeleteDlg::DeleteDlg( bool _selEnabled, QWidget *_parent, const char *_name )
 	: QDialog( _parent, _name, true )
 {
 	setCaption( i18n("Delete") );
-	
+
 	QVBoxLayout *mainLayout = new QVBoxLayout( this, 10 );
 
 	QLabel *l1 = new QLabel( i18n("What do you want to delete?"), this );
@@ -56,39 +56,39 @@ DeleteDlg::DeleteDlg( bool _selEnabled, QWidget *_parent, const char *_name )
 
 	QVBoxLayout *vblg1 = new QVBoxLayout( bg1, 10 );
 	vblg1->addSpacing( 10 );
-	
+
 	m_rbSelection = new QRadioButton( i18n("Selected files"), bg1 );
 	m_rbSelection->setFixedSize( m_rbSelection->sizeHint() );
 	vblg1->addWidget( m_rbSelection, 0, AlignLeft );
 	m_rbSelection->setEnabled( _selEnabled );
 	m_rbSelection->setChecked( _selEnabled );
-		
+
 	QHBoxLayout *hbl1 = new QHBoxLayout();
 	vblg1->addLayout( hbl1 );
-	
+
 	m_rbPatterns = new QRadioButton( i18n("Files: "), bg1 );
 	m_rbPatterns->setFixedSize( m_rbPatterns->sizeHint() );
 	hbl1->addWidget( m_rbPatterns );
 	m_rbPatterns->setChecked( !_selEnabled );
-	
+
 	m_lePatterns = new QLineEdit( bg1 );
 	m_lePatterns->setFixedHeight( m_lePatterns->sizeHint().height() );
 	m_lePatterns->setMinimumWidth( m_lePatterns->sizeHint().width() );
 	hbl1->addWidget( m_lePatterns );
 	connect( m_lePatterns, SIGNAL(textChanged(const QString &)), SLOT(onChange(const QString&)));
-	
+
 	QHBoxLayout *hbl = new QHBoxLayout();
 	mainLayout->addLayout( hbl );
-	
+
 	hbl->addStretch( 1 );
-	
-	QPushButton *ok = new QPushButton( i18n("OK"), this );	
+
+	QPushButton *ok = new KPushButton( KStdGuiItem::ok(), this );
 	ok->setFixedSize( ok->sizeHint() );
 	ok->setDefault(true);
 	connect( ok, SIGNAL( clicked() ), SLOT( accept() ) );
 	hbl->addWidget( ok );
 
-	QPushButton *cancel = new QPushButton( i18n("Cancel"), this );
+	QPushButton *cancel = new KPushButton( KStdGuiItem::cancel(), this );
 	cancel->setFixedSize( cancel->sizeHint() );
 	connect( cancel, SIGNAL( clicked() ), SLOT( reject() ) );
 	hbl->addWidget( cancel );
