@@ -1,6 +1,6 @@
 /*
 
- $Id: deleteDlg.h,v 1.1 1999/10/04 18:40:24 xavier Exp $
+ $Id: deleteDlg.h,v 1.3 2003/03/07 22:06:46 waba Exp $
 
  ark -- archiver for the KDE project
 
@@ -21,19 +21,18 @@
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
- Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
 #ifndef DELETE_DLG_H
 #define DELETE_DLG_H
 
-// Qt includes
-#include <qdialog.h>
-#include <qlineedit.h>
-#include <qradiobutton.h>
-#include <qstring.h>
-
+class QWidget;
+class QDialog;
+class QString;
+class QLineEdit;
+class QRadioButton;
 
 class DeleteDlg : public QDialog {
 	Q_OBJECT
