@@ -1,6 +1,6 @@
 /* -*- c++ -*-
 
-$Id: extractdlg.cpp,v 1.16.2.2 2003/05/01 14:35:47 robbers Exp $
+$Id: extractdlg.cpp,v 1.27.2.1 2004/04/14 11:45:00 binner Exp $
 
 ark -- archiver for the KDE project
 
@@ -25,7 +25,7 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
@@ -46,14 +46,14 @@ Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #include <kurlrequester.h>
 
 // application includes
+#include "arkutils.h"
 #include "arksettings.h"
 #include "generalOptDlg.h"
 #include "extractdlg.h"
-
 #define FIRST_PAGE_WIDTH  390
 
-ExtractDlg::ExtractDlg( ArkSettings *_settings )
-    : KDialogBase( KDialogBase::Plain, i18n("Extract"), Ok | Cancel, Ok ),
+ExtractDlg::ExtractDlg( ArkSettings *_settings, QWidget *parent, const char *name, const QString &prefix )
+    : KDialogBase( KDialogBase::Plain, i18n("Extract"), Ok | Cancel, Ok, parent, name ),
 m_settings( _settings )
 {
 	QFrame *mainFrame = plainPage();
@@ -89,14 +89,16 @@ m_settings( _settings )
 	QStringList list;
 
 	config->setGroup( "History" );
-	list = config->readListEntry( "ExtractTo History" );
+	list = config->readPathListEntry( "ExtractTo History" );
 	m_extractDirCB->setHistoryItems( list );
 
-	m_extractDirCB->setEditURL( KURL( m_settings->getExtractDir() ) );
+	m_extractDirCB->setEditURL( KURL( m_settings->getExtractDir() + prefix ) );
 
 	m_urlRequester = new KURLRequester( m_extractDirCB, mainFrame );
 	m_urlRequester->setMode( KFile::Directory );
 
+	m_extractDirCB->setSizePolicy( QSizePolicy( QSizePolicy::Expanding, QSizePolicy::Fixed ) );
+
 	Layout3->addWidget( m_urlRequester );
 
 
@@ -137,7 +139,7 @@ m_settings( _settings )
 	Layout1->setMargin( 0 );
 
 	m_radioPattern = new QRadioButton( bg, "m_radioPattern" );
-	m_radioPattern->setText( i18n( "Pattern" ) );
+	m_radioPattern->setText( i18n( "Pattern:" ) );
 	Layout1->addWidget( m_radioPattern );
 
 	m_patternLE = new QLineEdit( bg, "m_patternLE" );
@@ -179,7 +181,9 @@ ExtractDlg::~ExtractDlg()
 	QStringList list;
 	config->setGroup( "History" );
 	list = m_extractDirCB->historyItems();
-	config->writeEntry( "ExtractTo History", list );
+	config->writePathEntry( "ExtractTo History", list );
+        config->setGroup( "ark" );
+        config->writePathEntry( "lastExtractDir", m_extractDirCB->lineEdit()->text() );
 }
 
 void
@@ -201,6 +205,7 @@ ExtractDlg::accept()
 	kdDebug( 1601 ) << "+ExtractDlg::accept" << endl;
 
 	KURLCompletion uc;
+	uc.setReplaceHome( true );
 	KURL p( uc.replacedPath(  m_extractDirCB->currentText() ) );
 
 	//if p isn't local KIO and friends will complain later on
@@ -209,8 +214,8 @@ ExtractDlg::accept()
 		QFileInfo fi( p.path() );
 		if ( !fi.isDir() && !fi.exists() )
 		{
-			QString ltext = i18n( "Create directory %1?").arg(p.path());
-			int createDir =  KMessageBox::questionYesNo( this, ltext, i18n( "Missing directory!" ) );
+			QString ltext = i18n( "Create folder %1?").arg(p.path());
+			int createDir =  KMessageBox::questionYesNo( this, ltext, i18n( "Missing folder!" ) );
 			if( createDir == 4 )
 			{
 				return;
@@ -219,13 +224,13 @@ ExtractDlg::accept()
 			p.adjustPath(1);
 			if( !KStandardDirs::makeDir( p.path() ) )
 			{
-				KMessageBox::error( this, i18n( "Directory could not be created. Please check permissions." ) );
+				KMessageBox::error( this, i18n( "The folder could not be created. Please check permissions." ) );
 				return;
 			}
 		}
-		if ( !fi.isWritable() )
+		if ( !ArkUtils::haveDirPermissions( p.path() ) )
 		{
-			KMessageBox::error( this, i18n( "You do not have write permission to this directory! Please provide another directory." ) );
+			KMessageBox::error( this, i18n( "You do not have write permission to this folder! Please provide another folder." ) );
 			return;
 		}
 	}
@@ -304,7 +309,7 @@ ExtractFailureDlg::ExtractFailureDlg( QStringList *list, QWidget *parent, char *
 
 	setCaption( i18n( "Failure to Extract" ) );
 	QLabel *pLabel = new QLabel( this );
-	pLabel->setText( i18n( "Some files already exist in your destination directory.\n"
+	pLabel->setText( i18n( "Some files already exist in your destination folder.\n"
 				"The following files will not be extracted if you continue: " ) );
 	labelWidth = pLabel->sizeHint().width();
 	labelHeight = pLabel->sizeHint().height();
@@ -316,14 +321,12 @@ ExtractFailureDlg::ExtractFailureDlg( QStringList *list, QWidget *parent, char *
 	pBox->setGeometry( 10, 10 + labelHeight + 10, boxWidth, boxHeight );
 	pBox->insertStringList( *list );
 
-	QPushButton *pOKButton = new QPushButton( this, "OKButton" );
+	QPushButton *pOKButton = new KPushButton( KStdGuiItem::cont(), this, "OKButton" );
 	pOKButton->setGeometry( labelWidth / 2 - 50, boxHeight + labelHeight + 30, 70, buttonHeight );
-	pOKButton->setText( i18n( "Continue" ) );
 	connect( pOKButton, SIGNAL( pressed() ), this, SLOT( accept() ) );
 
-	QPushButton *pCancelButton = new QPushButton( this, "CancelButton" );
+	QPushButton *pCancelButton = new KPushButton( KStdGuiItem::cancel(), this, "CancelButton" );
 	pCancelButton->setGeometry( labelWidth / 2 + 20, boxHeight + labelHeight + 30, 70, buttonHeight );
-	pCancelButton->setText( i18n( "Cancel" ) );
 	connect( pCancelButton, SIGNAL( pressed() ), this, SLOT( reject() ) );
 	setFixedSize( 20+labelWidth, 40+labelHeight+boxHeight+buttonHeight );
 	QApplication::restoreOverrideCursor();
