@@ -1,15 +1,13 @@
 /*
 
-  $Id: filelistview.cpp,v 1.29.2.2 2003/05/01 14:33:36 robbers Exp $
-
   ark -- archiver for the KDE project
 
   Copyright (C)
 
-  1999: Francois-Xavier Duranceau duranceau@kde.org
-  1999-2000: Corel Corporation (author: Emily Ezust, emilye@corel.com)
-  2001: Corel Corporation (author: Michael Jarrett, michaelj@corel.com)
   2003: Georg Robbers <Georg.Robbers@urz.uni-hd.de>
+  2001: Corel Corporation (author: Michael Jarrett, michaelj@corel.com)
+  1999-2000: Corel Corporation (author: Emily Ezust, emilye@corel.com)
+  1999: Francois-Xavier Duranceau duranceau@kde.org
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
@@ -23,7 +21,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
@@ -38,7 +36,7 @@
 #include <kglobalsettings.h>
 
 #include "filelistview.h"
-#include "arkwidgetbase.h"
+#include "arkwidget.h"
 
 /////////////////////////////////////////////////////////////////////
 // FileLVI implementation
@@ -163,6 +161,10 @@ void FileLVI::setText(int column, const QString &text)
     }
     else if ( colName == ratioStrCol )
     {
+        int l = text.length() - 1;
+        if ( l>0 && text[l] == '%' )
+            m_ratio = text.left(l).toDouble();
+        else
         m_ratio = text.toDouble();
         QListViewItem::setText(column, i18n("Packed Ratio", "%1 %").arg(KGlobal::locale()->formatNumber(m_ratio, 1)));
     }
@@ -180,7 +182,7 @@ void FileLVI::setText(int column, const QString &text)
 /////////////////////////////////////////////////////////////////////
 
 
-FileListView::FileListView(ArkWidgetBase *baseArk, QWidget *parent,
+FileListView::FileListView(ArkWidget *baseArk, QWidget *parent,
 			   const char* name)
 	: KListView(parent, name), m_pParent(baseArk)
 {
@@ -257,16 +259,16 @@ void FileListView::setSorting(int column, bool inc)
 	KListView::setSorting(sortColumn, increasing);
 }
 
-QStringList * FileListView::selectedFilenames() const
+QStringList FileListView::selectedFilenames() const
 {
-	QStringList *files = new QStringList;
+	QStringList files;
 	
 	FileLVI * flvi = (FileLVI*)firstChild();
 
 	while (flvi)
 	{
 		if( isSelected(flvi) )
-			files->append(flvi->fileName());
+			files.append(flvi->fileName());
 		flvi = (FileLVI*)flvi->itemBelow();
 	}
 	return files;
@@ -294,7 +296,7 @@ bool FileListView::isSelectionEmpty()
 void 
 FileListView::contentsMousePressEvent(QMouseEvent *e)
 {
-	if(e->button()==QMouseEvent::LeftButton)
+	if( e->button()==QMouseEvent::LeftButton )
 	{
 		m_bPressed = true;
 		presspos = e->pos();
@@ -324,11 +326,8 @@ FileListView::contentsMouseMoveEvent(QMouseEvent *e)
 		{
 			return;
 		}
-		QStringList *dragFiles = selectedFilenames();
-		m_pParent->setDragInProgress(true);
-		m_pParent->storeDragNames(*dragFiles);
-		kdDebug(1601) << "Drag Starting..." << endl;
-		m_pParent->prepareViewFiles(dragFiles);
+		QStringList dragFiles = selectedFilenames();
+		emit startDragRequest( dragFiles );
 		KListView::contentsMouseMoveEvent(e);
 	}
 }
