@@ -1,8 +1,6 @@
 //  -*-C++-*-           emacs magic for .h files
 /*
 
- $Id: filelistview.h,v 1.15.2.2 2003/05/01 14:33:36 robbers Exp $
-
   ark -- archiver for the KDE project
 
   Copyright (C)
@@ -24,7 +22,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 #ifndef FILELISTVIEW_H
@@ -45,7 +43,7 @@ class QPoint;
 
 class KListView;
 
-class ArkWidgetBase;
+class ArkWidget;
 
 class FileListView;
 
@@ -79,16 +77,19 @@ class FileListView : public KListView
 {
   Q_OBJECT
 public:
-  FileListView(ArkWidgetBase *baseArk, QWidget* parent = 0,
+  FileListView(ArkWidget *baseArk, QWidget* parent = 0,
 	       const char* name = 0);
   FileLVI *currentItem() {return ((FileLVI *) KListView::currentItem());}
-  QStringList * selectedFilenames() const;
+  QStringList selectedFilenames() const;
   uint count();
   bool isSelectionEmpty();
   virtual int addColumn( const QString & label, int width = -1 );
   virtual void removeColumn( int index );
   columnName nameOfColumn( int index );
 
+signals:
+  void startDragRequest( const QStringList & fileList );
+
 protected:
   void contentsMouseReleaseEvent(QMouseEvent *e);
   void contentsMousePressEvent(QMouseEvent *e);
@@ -100,7 +101,7 @@ private:
   QMap<int, columnName> colMap;
   int sortColumn;
   bool increasing;
-  ArkWidgetBase *m_pParent;
+  ArkWidget *m_pParent;
 
   bool m_bPressed;
   QPoint presspos;  // this will save the click pos to correctly recognize drag events
