@@ -1,6 +1,6 @@
 /*
 
- $Id: generalOptDlg.cpp,v 1.14.2.2 2003/03/15 16:03:57 lukas Exp $
+ $Id: generalOptDlg.cpp,v 1.21 2003/12/15 08:28:44 lukas Exp $
 
  ark -- archiver for the KDE project
 
@@ -23,7 +23,7 @@
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
- Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
@@ -41,27 +41,6 @@
 #include "dirDlg.h"
 #include "generalOptDlg.h"
 
-#define DLG_NAME I18N_NOOP("Settings")
-#define TAB_ADD_NAME I18N_NOOP("Addi&ng")
-#define TAB_EXTRACT_NAME I18N_NOOP("&Extracting")
-#define TAB_PATH_NAME I18N_NOOP("&Directories")
-
-#define GRP_ADDSET I18N_NOOP("Add Settings")
-#define GRP_EXTRACTSET I18N_NOOP("Extract Settings")
-
-#define OPT_REPLACE_NEWER I18N_NOOP("Replace old files only &with newer files")
-#define OPT_MAKEGENERIC I18N_NOOP("Keep entries &generic (Lha)")
-#define OPT_DOS_FILENAMES I18N_NOOP("Force &MS-DOS short filenames (Zip)")
-#define OPT_CONV_CRLF I18N_NOOP("Translate &LF to DOS CRLF (Zip)")
-#define OPT_RECURSE_SUBDIRS I18N_NOOP("&Recursively add subdirectories (Zip, Rar)")
-#define OPT_STORE_SYMLINKS I18N_NOOP("&Store symlinks as links (Zip, Rar)")
-
-#define OPT_OVERWRITE I18N_NOOP("O&verwrite files (Zip, Tar, Zoo, Rar)")
-#define OPT_PRESERVEPERMS I18N_NOOP("&Preserve permissions (Tar)")
-#define OPT_DISCARDPATHS I18N_NOOP("&Ignore directory names (Zip)")
-#define OPT_TOLOWER I18N_NOOP("Convert filenames to &lowercase (Zip, Rar)")
-#define OPT_TOUPPER I18N_NOOP("Convert filenames to &uppercase (Rar)")
-
 // little helper:
 static inline QPixmap loadIcon( const char * name ) {
   return KGlobal::instance()->iconLoader()
@@ -70,7 +49,7 @@ static inline QPixmap loadIcon( const char * name ) {
 }
 
 GeneralOptDlg::GeneralOptDlg(ArkSettings *_d, QWidget *_parent, const char *_name)
-	: KDialogBase(IconList, i18n(DLG_NAME), Ok | Apply | Cancel, Ok,
+	: KDialogBase(IconList, i18n("Configure"), Ok | Apply | Cancel, Ok,
 		      _parent, _name, true, true)
 {
     m_settings = _d;
@@ -84,7 +63,7 @@ GeneralOptDlg::GeneralOptDlg(ArkSettings *_d, QWidget *_parent, const char *_nam
                      loadIcon( "ark_extract" ) );
     createExtractTab( frame );
 
-    frame = addPage( i18n( "Directories" ), i18n( "Directory Settings" ),
+    frame = addPage( i18n( "Folders" ), i18n( "Folder Settings" ),
                      loadIcon( "folder" ) );
     createDirectoryTab( frame );
 }
@@ -95,15 +74,19 @@ void GeneralOptDlg::createAddTab( QFrame *parent ) {
 
     QVBoxLayout *layout = new QVBoxLayout(parent);
 
-    QGroupBox *addSet = new QGroupBox(1, Horizontal, i18n(GRP_ADDSET), addFrame);
-    layout->addWidget( addSet );
+    m_cbReplaceOnlyWithNewer = new QCheckBox(i18n("Replace old files only &with newer files"), addFrame);
+    m_cbMakeGeneric = new QCheckBox(i18n("Keep entries &generic (Lha)"), addFrame);
+    m_cbForceMS = new QCheckBox(i18n("Force &MS-DOS short filenames (Zip)"), addFrame);
+    m_cbConvertCRLF = new QCheckBox(i18n("Translate &LF to DOS CRLF (Zip)"), addFrame);
+    m_cbStoreSymlinks = new QCheckBox(i18n("&Store symlinks as links (Zip, Rar)"), addFrame);
+    m_cbRecurseSubdirs = new QCheckBox(i18n("&Recursively add subfolders (Zip, Rar)"), addFrame);
 
-    m_cbReplaceOnlyWithNewer = new QCheckBox(i18n(OPT_REPLACE_NEWER), addSet);
-    m_cbMakeGeneric = new QCheckBox(i18n(OPT_MAKEGENERIC), addSet);
-    m_cbForceMS = new QCheckBox(i18n(OPT_DOS_FILENAMES), addSet);
-    m_cbConvertCRLF = new QCheckBox(i18n(OPT_CONV_CRLF), addSet);
-    m_cbStoreSymlinks = new QCheckBox(i18n(OPT_STORE_SYMLINKS), addSet);
-    m_cbRecurseSubdirs = new QCheckBox(i18n(OPT_RECURSE_SUBDIRS), addSet);
+    layout->addWidget(m_cbReplaceOnlyWithNewer);
+    layout->addWidget(m_cbMakeGeneric);
+    layout->addWidget(m_cbForceMS);
+    layout->addWidget(m_cbConvertCRLF);
+    layout->addWidget(m_cbStoreSymlinks);
+    layout->addWidget(m_cbRecurseSubdirs);
 
     layout->addStretch();
 
@@ -116,14 +99,17 @@ void GeneralOptDlg::createExtractTab( QFrame *parent ) {
     QFrame *exFrame( parent );// = addVBoxPage(i18n(TAB_EXTRACT_NAME));
     QVBoxLayout *layout = new QVBoxLayout(exFrame);
 
-    QGroupBox *exSet = new QGroupBox(1, Horizontal, i18n(GRP_EXTRACTSET), exFrame);
-    layout->add( exSet );
+    m_cbOverwrite = new QCheckBox(i18n("O&verwrite files (Zip, Tar, Zoo, Rar)"), exFrame);
+    m_cbPreservePerms = new QCheckBox(i18n("&Preserve permissions (Tar)"), exFrame);
+    m_cbDiscardPathnames = new QCheckBox(i18n("&Ignore folder names (Zip)"), exFrame);
+    m_cbToLower = new QCheckBox(i18n("Convert filenames to &lowercase (Zip, Rar)"), exFrame);
+    m_cbToUpper = new QCheckBox(i18n("Convert filenames to &uppercase (Rar)"), exFrame);
 
-    m_cbOverwrite = new QCheckBox(i18n(OPT_OVERWRITE), exSet);
-    m_cbPreservePerms = new QCheckBox(i18n(OPT_PRESERVEPERMS), exSet);
-    m_cbDiscardPathnames = new QCheckBox(i18n(OPT_DISCARDPATHS), exSet);
-    m_cbToLower = new QCheckBox(i18n(OPT_TOLOWER), exSet);
-    m_cbToUpper = new QCheckBox(i18n(OPT_TOUPPER), exSet);
+    layout->addWidget(m_cbOverwrite);
+    layout->addWidget(m_cbPreservePerms);
+    layout->addWidget(m_cbDiscardPathnames);
+    layout->addWidget(m_cbToLower);
+    layout->addWidget(m_cbToUpper);
 
     layout->addStretch();
 
