@@ -1,6 +1,6 @@
 /*
 
- $Id: generalOptDlg.h,v 1.7.4.1 2003/01/13 10:32:44 helio Exp $
+ $Id: generalOptDlg.h,v 1.9 2003/03/07 22:06:46 waba Exp $
 
  ark -- archiver for the KDE project
 
@@ -22,7 +22,7 @@
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
- Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
