@@ -51,7 +51,7 @@
 
 RarArch::RarArch( ArkSettings *_settings, ArkWidgetBase *_gui,
 		  const QString & _fileName )
-  : Arch(_settings, _gui, _fileName ), m_linenumber(0)
+  : Arch(_settings, _gui, _fileName )
 {
   kdDebug(1601) << "RarArch constructor" << endl;
 
@@ -63,38 +63,26 @@ RarArch::RarArch( ArkSettings *_settings, ArkWidgetBase *_gui,
       
   verifyUtilityIsAvailable(m_archiver_program, m_unarchiver_program);
 
-  m_headerString = "----";
+  m_headerString = "-------------------------------------------------------------------------------";
+
+  m_isFirstLine = true;
 }
 
 bool RarArch::processLine(const QCString &line)
 {
-  // For each rar entry, this function is called exactly three times.
-  // The first time, store the first line and return.
-  // The second time, store the second line and return.
-  // The third time, process the data in the first two lines and
-  // send to the GUI. We ignore the third line since the data there
-  // isn't really that important.
-
-  ++m_linenumber;
-  if (m_linenumber == 1)
-    {
-      m_line1 = QString::fromLocal8Bit(line.data());
-      return true;
-    }
-  if (m_linenumber == 2)
-    {
-      m_line2 = QString::fromLocal8Bit(line.data());
-      return true;
-    }
-  // if we made it here, we have all three lines.
-  // Reset the line number.
-  m_linenumber = 0;
+  if ( m_isFirstLine )
+  {
+    m_fileName = line;
+    m_fileName.remove( 0, 1 );
+    m_isFirstLine = false;
+    return true;
+  }
 
   QStringList list;
-  list << m_line1.stripWhiteSpace(); // filename
 
-  QStringList l2 = QStringList::split( ' ', m_line2 );
+  QStringList l2 = QStringList::split( ' ', line );
 
+  list << m_fileName; // filename
   list << l2[ 0 ]; // size
   list << l2[ 1 ]; // packed
   list << l2[ 2 ]; // ratio
@@ -108,6 +96,7 @@ bool RarArch::processLine(const QCString &line)
 
   m_gui->listingAdd(&list); // send to GUI
 
+  m_isFirstLine = true;
   return true;
 }
 
@@ -122,7 +111,7 @@ void RarArch::open()
   
   
   KProcess *kp = new KProcess;
-  *kp << m_archiver_program << "vt" << m_filename;
+  *kp << m_archiver_program << "v" << "-c-" << m_filename;
   connect( kp, SIGNAL(receivedStdout(KProcess*, char*, int)),
 	   this, SLOT(slotReceivedTOC(KProcess*, char*, int)));
   connect( kp, SIGNAL(receivedStderr(KProcess*, char*, int)),
