@@ -1,7 +1,7 @@
 //  -*-C++-*-           emacs magic for .h files
 /*
 
- $Id: rar.h,v 1.9.6.1 2003/01/13 10:32:44 helio Exp $
+ $Id: rar.h,v 1.13 2004/01/12 17:45:53 pinto Exp $
 
  ark -- archiver for the KDE project
 
@@ -21,7 +21,7 @@
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
- Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 #ifndef __RAR_H__
@@ -59,8 +59,8 @@ protected slots:
   virtual bool processLine(const QCString &line);
 
 private: // data
-  int m_linenumber;
-  QString m_line1, m_line2; // for keeping till we have all three lines
+  bool m_isFirstLine;
+  QString m_fileName;
 
   void initExtract( bool, bool, bool );
   void setHeaders();
