@@ -1,6 +1,6 @@
 /*
 
- $Id: shellOutputDlg.cpp,v 1.9.4.1 2003/01/13 10:32:44 helio Exp $
+ $Id: shellOutputDlg.cpp,v 1.11.4.1 2004/04/14 11:45:00 binner Exp $
 
  ark -- archiver for the KDE project
 
@@ -21,15 +21,16 @@
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
- Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
 // Qt includes
-#include <qpushbutton.h>
 #include <qlayout.h>
 
 #include <klocale.h>
+#include <kpushbutton.h>
+#include <kstdguiitem.h>
 
 // ark includes
 #include "shellOutputDlg.h"
@@ -41,7 +42,7 @@ ShellOutputDlg::ShellOutputDlg( ArkSettings *_data, QWidget *_parent,
 	: QDialog( _parent, _name, true )
 {
   setCaption( i18n("Shell Output") );
-  QGridLayout *grid1 = new QGridLayout(this,10,5,15,7);  
+  QGridLayout *grid1 = new QGridLayout(this,10,5,15,7);
   QMultiLineEdit *l1 = new QMultiLineEdit( this );
   l1->setReadOnly( true );
   grid1->addMultiCellWidget(l1,0,8,0,4);
@@ -49,7 +50,7 @@ ShellOutputDlg::ShellOutputDlg( ArkSettings *_data, QWidget *_parent,
   l1->setText( *(_data->getLastShellOutput()) );
   l1->setCursorPosition(l1->numLines(), 0);
 
-  QPushButton *close = new QPushButton( i18n("Close"), this );
+  QPushButton *close = new KPushButton( KStdGuiItem::close(), this );
   grid1->addWidget(close,9,4);
   connect( close, SIGNAL( clicked() ), SLOT( accept() ) );
   close->setFocus();
