@@ -1,7 +1,5 @@
 /*
 
- $Id: tar.cpp,v 1.7.2.2 2003/01/15 01:37:36 helio Exp $
-
  ark -- archiver for the KDE project
 
  Copyright (C)
@@ -11,6 +9,7 @@
  1999-2000: Corel Corporation (author: Emily Ezust, emilye@corel.com)
  2001: Corel Corporation (author: Michael Jarrett, michaelj@corel.com)
  2001: Roberto Selbach Teixeira <maragato@conectiva.com>
+ 2003: Georg Robbers <Georg.Robbers@urz.uni-hd.de>
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
@@ -24,7 +23,7 @@
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
- Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
@@ -41,15 +40,11 @@
 // course, for tape backups, so this is not so surprising!      -Emily
 //
 
-// Unsorted in qdir.h is used, but in some of the headers
-// below it's defined, too. So I brought kurl.h to the top.
-
 // C includes
 #include <stdio.h>
 #include <stdlib.h>
 
 // Qt includes
-#include <qapplication.h>
 #include <qdir.h>
 
 // KDE includes
@@ -57,8 +52,9 @@
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <ktempfile.h>
-#include <kmimemagic.h>
+#include <kmimetype.h>
 #include <kstandarddirs.h>
+#include <ktempdir.h>
 #include <kprocess.h>
 #include <ktar.h>
 
@@ -71,49 +67,51 @@
 static char *makeAccessString(mode_t mode);
 
 TarArch::TarArch( ArkSettings *_settings, ArkWidgetBase *_gui,
-                  const QString & _filename)
+                  const QString & _filename, const QString & _openAsMimeType)
   : Arch(_settings, _gui, _filename), createTmpInProgress(false),
-    updateInProgress(false), deleteInProgress(false), fd(NULL)
+    updateInProgress(false), deleteInProgress(false), fd(NULL),
+    m_pTmpProc( NULL ), m_pTmpProc2( NULL ), tarptr( NULL ), failed( false )
 {
-	kdDebug(1601) << "+TarArch::TarArch" << endl;
-	m_archiver_program = m_settings->getTarCommand();
-	m_unarchiver_program = QString::null;
-	verifyUtilityIsAvailable(m_archiver_program, m_unarchiver_program);
-	
-	KMimeMagic *mimePtr = KMimeMagic::self();
-	KMimeMagicResult * mimeResultPtr = mimePtr->findFileType(_filename);
-	QString mimetype = mimeResultPtr->mimeType();
-	kdDebug(1601) << "TarArch::TarArch:  mimetype is " << mimetype << endl;
-	
-	if ( mimetype == "application/x-tar" )
-	{
-		compressed = false;
-	}
-	else
-	{
-		compressed = true;
-		QDir dir( _settings->getTmpDir() );
-		QString tarTempDir = QString::fromLatin1( "temp_tar" );
-		dir.mkdir( tarTempDir );
-		dir.cd( tarTempDir );
+    m_tmpDir = NULL;
+    m_filesToAdd = m_filesToRemove = QStringList();
+    kdDebug(1601) << "+TarArch::TarArch" << endl;
+    m_archiver_program = m_settings->getTarCommand();
+    m_unarchiver_program = QString::null;
+    verifyUtilityIsAvailable(m_archiver_program, m_unarchiver_program);
 
-		// build the temp file name
-		KTempFile *pTempFile = new KTempFile( dir.absPath() + '/',
-				QString::fromLatin1(".tar") );
+    m_fileMimeType = _openAsMimeType;
+    if ( m_fileMimeType.isNull() )
+        m_fileMimeType = KMimeType::findByPath( _filename )->name();
 
-		tmpfile = pTempFile->name();
-		delete pTempFile;
-		
-		kdDebug(1601) << "Tmpfile will be " << tmpfile << "\n" << endl;
-	}
-	kdDebug(1601) << "-TarArch::TarArch" << endl;
+    kdDebug(1601) << "TarArch::TarArch:  mimetype is " << m_fileMimeType << endl;
+
+    if ( m_fileMimeType == "application/x-tar" )
+    {
+        compressed = false;
+    }
+    else
+    {
+        compressed = true;
+        m_tmpDir = new KTempDir( _settings->getTmpDir()
+                                 + QString::fromLatin1( "temp_tar" ) );
+        m_tmpDir->setAutoDelete( true );
+        m_tmpDir->qDir()->cd( m_tmpDir->name() );
+        // build the temp file name
+        KTempFile *pTempFile = new KTempFile( m_tmpDir->name(),
+                QString::fromLatin1(".tar") );
+
+        tmpfile = pTempFile->name();
+        delete pTempFile;
+
+        kdDebug(1601) << "Tmpfile will be " << tmpfile << "\n" << endl;
+    }
+    kdDebug(1601) << "-TarArch::TarArch" << endl;
 }
 
 TarArch::~TarArch()
 {
-  QDir tarTempDir( tmpfile.left( tmpfile.findRev( '/' ) ) );
-  QFile::remove( tmpfile );
-  tarTempDir.rmdir( tarTempDir.absPath() );
+    if ( m_tmpDir )
+        delete m_tmpDir;
 }
 
 int TarArch::getEditFlag()
@@ -131,7 +129,13 @@ void TarArch::updateArch()
 
       KProcess *kp = new KProcess;
       kp->clearArguments();
-      if ( getCompressor() != QString::null )
+      KProcess::Communication flag = KProcess::AllOutput;
+      if ( getCompressor() == "lzop" )
+      {
+        kp->setUsePty( KProcess::Stdin, false );
+        flag = KProcess::Stdout;
+      }
+      if ( !getCompressor().isNull() )
           *kp << getCompressor() << "-c" << tmpfile;
       else
           *kp << "cat" << tmpfile;
@@ -145,15 +149,16 @@ void TarArch::updateArch()
       connect(kp, SIGNAL(processExited(KProcess *)),
                this, SLOT(updateFinished(KProcess *)) );
 
-      if (kp->start(KProcess::NotifyOnExit, KProcess::AllOutput) == false)
+      if ( !fd || kp->start(KProcess::NotifyOnExit, flag) == false)
         {
           KMessageBox::error(0, i18n("Trouble writing to the archive..."));
+          emit updateDone();
         }
     }
   kdDebug(1601) << "-TarArch::updateArch" << endl;
 }
 
-void TarArch::updateProgress( KProcess *, char *_buffer, int _bufflen )
+void TarArch::updateProgress( KProcess * _proc, char *_buffer, int _bufflen )
 {
   // we're trying to capture the output of a command like this
   //    gzip -c myarch.tar
@@ -162,8 +167,10 @@ void TarArch::updateProgress( KProcess *, char *_buffer, int _bufflen )
   size = fwrite(_buffer, 1, _bufflen, fd);
   if (size != _bufflen)
     {
+      _proc->kill();
       KMessageBox::error(0, i18n("Trouble writing to the archive..."));
-      exit(99);
+      kdWarning( 1601 ) << "trouble updating tar archive" << endl;
+      //kdFatal( 1601 ) << "trouble updating tar archive" << endl;
     }
 }
 
@@ -171,156 +178,158 @@ void TarArch::updateProgress( KProcess *, char *_buffer, int _bufflen )
 
 QString TarArch::getCompressor()
 {
-  QString extension = m_filename.right( m_filename.length() -
-                                       m_filename.findRev('.') );
+    if ( m_fileMimeType == "application/x-tarz" )
+        return QString( "compress" );
 
-  if( extension == ".tgz" || extension == ".gz" )
-    return QString( "gzip" );
+    if ( m_fileMimeType == "application/x-tgz" )
+        return QString( "gzip" );
 
-  if( extension == ".bz")
-    return QString( "bzip" );
+    if (  m_fileMimeType == "application/x-tbz" )
+        return QString( "bzip2" );
 
-  if( extension == ".Z" || extension == ".taz" )
-    return QString( "compress" );
+    if( m_fileMimeType == "application/x-tzo" )
+        return QString( "lzop" );
 
-  if( extension == ".bz2")
-    return QString( "bzip2" );
-
-  if( extension == ".lzo" || extension == ".tzo" )
-    return QString( "lzop" );
-
-  return QString::null;
+    return QString::null;
 }
 
-QString TarArch::getUnCompressorByExtension()
-{
-    QString extension = m_filename.right( m_filename.length() - m_filename.findRev('.') );
-
-  if( extension == ".tgz" || extension == ".gz" )
-    return QString( "gunzip" );
-
-  if( extension == ".bz")
-    return QString( "bunzip" );
-
-  if( extension == ".Z" || extension == ".taz" )
-    return QString( "uncompress" );
-
-  if( extension == ".bz2")
-    return QString( "bunzip2" );
-
-  if( extension == ".lzo" || extension == ".tzo" )
-    return QString( "lzop" );
-
-  return QString::null;
-}
 
 QString TarArch::getUnCompressor()
 {
-
-    QString fileType = KMimeMagic::self()->findFileType( m_filename )->mimeType();
-
-    if ( fileType == "application/x-compress" )
+    if ( m_fileMimeType == "application/x-tarz" )
         return QString( "uncompress" );
 
-    if ( fileType == "application/x-gzip" )
+    if ( m_fileMimeType == "application/x-tgz" )
         return QString( "gunzip" );
 
-    if ( fileType == "application/x-bzip2" )
+    if (  m_fileMimeType == "application/x-tbz" )
         return QString( "bunzip2" );
 
-    if( fileType == "application/x-zoo" )
+    if( m_fileMimeType == "application/x-tzo" )
         return QString( "lzop" );
 
-    return getUnCompressorByExtension();
+    return QString::null;
 }
 
-void 
+void
 TarArch::open()
 {
-	kdDebug(1601) << "+TarArch::open" << endl;
-	QFile::remove(tmpfile); // just to make sure
-	setHeaders();
-	
-	// might as well plunk the output of tar -tvf in the shell output window...
-	KProcess *kp = new KProcess;
-	
-	*kp << m_archiver_program;
-	
-	if ( compressed )
-	{
-		*kp << "--use-compress-program=" + getUnCompressor() ;
-	}
-	
-	*kp << "-tvf" << m_filename;
-	
-	m_buffer = "";
-	m_header_removed = false;
-	m_finished = false;
-	
-	connect(kp, SIGNAL(processExited(KProcess *)),
-			this, SLOT(slotListingDone(KProcess *)));
-	connect(kp, SIGNAL(receivedStdout(KProcess*, char*, int)),
-			this, SLOT(slotReceivedOutput( KProcess *, char *, int )));
-	connect( kp, SIGNAL(receivedStderr(KProcess*, char*, int)),
-			this, SLOT(slotReceivedOutput(KProcess*, char*, int)));
-	
-	if (kp->start(KProcess::NotifyOnExit, KProcess::AllOutput) == false)
-	{
-		KMessageBox::error( 0, i18n("Couldn't start a subprocess.") );
-   }
-	
-	// We list afterwards because we want the signals at the end
-	// This unconfuses Extract Here somewhat
-	
-	KTar *tarptr;
-	bool failed = false;
-	
-	if ( !compressed || getUnCompressor() == QString("gunzip")
-			|| getUnCompressor() == QString("bunzip2") )
-	{
-		kdDebug(1601)  << "Creating KTar from " << m_filename << 
-			" using uncompressor " << getUnCompressor() << endl;
-		tarptr = new KTar(m_filename);
-	}
-	else
-	{
-		createTmp();
-		while ( compressed && createTmpInProgress )
-			qApp->processEvents(); // wait for temp to be created;
-		tarptr = new KTar(tmpfile);
-	}
-	
-	failed = !tarptr->open( IO_ReadOnly );
-	if( failed && ( getUnCompressor() == QString("gunzip")
-				|| getUnCompressor() == QString("bunzip2") ) )
-	{
-		delete tarptr;
-		createTmp();
-		while (compressed && createTmpInProgress)
-			qApp->processEvents(); // wait for temp to be created;
-		kdDebug(1601)  << "Creating KTar from failed IO_RW " << m_filename << 
-			" using uncompressor " << getUnCompressor() << endl;
-		tarptr = new KTar(tmpfile);
-		failed = !tarptr->open(IO_ReadOnly);
-	}
-	
-	if( failed )
-	{
-		kdDebug(1601)  << "Failed to uncompress and open." << endl;
-		emit sigOpen(this, false, QString::null, 0 );
-	}
-	else
-	{
-		processDir(tarptr->directory(), "");
-		// because we aren't using the KProcess method, we have to emit this
-		// ourselves.
-		emit sigOpen(this, true, m_filename,
-				Arch::Extract | Arch::Delete | Arch::Add | Arch::View );
-	}
-	
-	delete tarptr;
+    kdDebug(1601) << "+TarArch::open" << endl;
+    if ( compressed )
+        QFile::remove(tmpfile); // just to make sure
+    setHeaders();
 
-	kdDebug(1601) << "-TarArch::open" << endl;
+    // might as well plunk the output of tar -tvf in the shell output window...
+    KProcess *kp = new KProcess;
+
+    *kp << m_archiver_program;
+
+    if ( compressed )
+    {
+        *kp << "--use-compress-program=" + getUnCompressor();
+    }
+
+    *kp << "-tvf" << m_filename;
+
+    m_buffer = "";
+    m_header_removed = false;
+    m_finished = false;
+
+    connect(kp, SIGNAL(processExited(KProcess *)),
+            this, SLOT(slotListingDone(KProcess *)));
+    connect(kp, SIGNAL(receivedStdout(KProcess*, char*, int)),
+            this, SLOT(slotReceivedOutput( KProcess *, char *, int )));
+    connect( kp, SIGNAL(receivedStderr(KProcess*, char*, int)),
+            this, SLOT(slotReceivedOutput(KProcess*, char*, int)));
+
+    if (kp->start(KProcess::NotifyOnExit, KProcess::AllOutput) == false)
+    {
+        KMessageBox::error( 0, i18n("Couldn't start a subprocess.") );
+    }
+
+    // We list afterwards because we want the signals at the end
+    // This unconfuses Extract Here somewhat
+
+    if ( m_fileMimeType == "application/x-tgz"
+            || m_fileMimeType == "application/x-tbz" )
+    {
+        QString type = ( m_fileMimeType == "application/x-tgz" )
+            ? "application/x-gzip" : "application/x-bzip2";
+        tarptr = new KTar ( m_filename, type );
+        openFirstCreateTempDone();
+    }
+    else if ( !compressed )
+    {
+        tarptr = new KTar( m_filename );
+        openFirstCreateTempDone();
+    }
+    else
+    {
+        connect( this, SIGNAL( createTempDone() ), this, SLOT( openFirstCreateTempDone() ) );
+        createTmp();
+    }
+}
+
+void TarArch::openFirstCreateTempDone()
+{
+    if ( compressed && ( m_fileMimeType != "application/x-tgz" )
+            && ( m_fileMimeType != "application/x-tbz" ) )
+    {
+        disconnect( this, SIGNAL( createTempDone() ), this, SLOT( openFirstCreateTempDone() ) );
+        tarptr = new KTar(tmpfile);
+    }
+
+    failed = !tarptr->open( IO_ReadOnly );
+    // failed is false for a tar.gz archive opened as tar.bz2 ?
+    // but one should be able to open empty archives...
+    // failed = failed || ( tarptr->directory()->entries().isEmpty();
+    if( failed && ( getUnCompressor() == QString("gunzip")
+                || getUnCompressor() == QString("bunzip2") ) )
+    {
+        delete tarptr;
+        tarptr = NULL;
+        connect( this, SIGNAL( createTempDone() ), this, SLOT( openSecondCreateTempDone() ) );
+        createTmp();
+    }
+    else
+        openSecondCreateTempDone();
+}
+
+void TarArch::openSecondCreateTempDone()
+{
+    if( failed && ( getUnCompressor() == QString("gunzip")
+                || getUnCompressor() == QString("bunzip2") ) )
+    {
+        disconnect( this, SIGNAL( createTempDone() ), this, SLOT( openSecondCreateTempDone() ) );
+        kdDebug(1601)  << "Creating KTar from failed IO_RW " << m_filename << 
+            " using uncompressor " << getUnCompressor() << endl;
+        if ( KMimeType::findByFileContent( tmpfile )->name() != "application/x-zerosize" )
+        {
+            tarptr = new KTar(tmpfile);
+            failed = !tarptr->open(IO_ReadOnly); 
+        }
+    }
+
+    // sigOpen might lead to application exit, delete tarptr before sigOpen
+    // to avoid double deletion
+    if( failed )
+    {
+        kdDebug(1601)  << "Failed to uncompress and open." << endl;
+        delete tarptr;
+        emit sigOpen(this, false, QString::null, 0 );
+    }
+    else
+    {
+        processDir(tarptr->directory(), "");
+        delete tarptr;
+        // because we aren't using the KProcess method, we have to emit this
+        // ourselves.
+        emit sigOpen(this, true, m_filename,
+                Arch::Extract | Arch::Delete | Arch::Add | Arch::View );
+    }
+
+
+    kdDebug(1601) << "-TarArch::open" << endl;
 }
 
 void TarArch::slotListingDone(KProcess *_kp)
@@ -332,8 +341,9 @@ void TarArch::processDir(const KTarDirectory *tardir, const QString & root)
   // process a KTarDirectory. Called recursively for directories within
   // directories, etc. Prepends to filename root, for relative pathnames.
 {
-  kdDebug(1601) << "+TarArch::processDir" << endl;
+  // kdDebug(1601) << "+TarArch::processDir" << endl;
   QStringList list = tardir->entries();
+
   for ( QStringList::Iterator it = list.begin(); it != list.end(); ++it )
     {
       const KTarEntry* tarEntry = tardir->entry((*it));
@@ -372,7 +382,7 @@ void TarArch::processDir(const KTarDirectory *tardir, const QString & root)
       if (!tarEntry->isFile())
         processDir( (KTarDirectory *)tarEntry, name);
     }
-  kdDebug(1601) << "-TarArch::processDir" << endl;
+  // kdDebug(1601) << "-TarArch::processDir" << endl;
 }
 
 void TarArch::create()
@@ -409,51 +419,72 @@ void TarArch::setHeaders()
   kdDebug(1601) << "-TarArch::setHeaders" << endl;
 }
 
-void 
-TarArch::createTmp()
+void TarArch::createTmp()
 {
-	kdDebug(1601) << "+TarArch::createTmp" << endl;
-	if ( compressed )
-	{
-		if ( !QFile::exists(tmpfile) )
-		{
-			// the tmpfile does not yet exist, so we create it.
-			createTmpInProgress = true;
-			fd = fopen( QFile::encodeName(tmpfile), "w" );
-			
-			KProcess *kp = new KProcess;
-			kp->clearArguments();
-			QString strUncompressor = getUnCompressor();
-			kdDebug(1601) << "Uncompressor is " << strUncompressor << endl;
-			*kp << strUncompressor;
-			if (strUncompressor == "lzop")
-			{
-				*kp << "-d" ;
-			}
-			*kp << "-c" << m_filename;
-			
-			connect(kp, SIGNAL(processExited(KProcess *)),
-					this, SLOT(createTmpFinished(KProcess *)));
-			connect(kp, SIGNAL(receivedStdout(KProcess*, char*, int)),
-					this, SLOT(createTmpProgress( KProcess *, char *, int )));
-			connect( kp, SIGNAL(receivedStderr(KProcess*, char*, int)),
-					this, SLOT(slotReceivedOutput(KProcess*, char*, int)));
+    kdDebug(1601) << "+TarArch::createTmp" << endl;
+    if ( compressed )
+    {
+        if ( !QFile::exists(tmpfile) )
+        {
+            QString strUncompressor = getUnCompressor();
+            // at least lzop doesn't want to pipe zerosize/nonexistent files
+            QFile originalFile( m_filename );
+            if ( strUncompressor != "gunzip" && strUncompressor !="bunzip2" &&
+                ( !originalFile.exists() || originalFile.size() == 0 ) )
+            {
+                QFile temp( tmpfile );
+                temp.open( IO_ReadWrite );
+                temp.close();
+                emit createTempDone();
+                return;
+            }
+            // the tmpfile does not yet exist, so we create it.
+            createTmpInProgress = true;
+            fd = fopen( QFile::encodeName(tmpfile), "w" );
 
-			if (kp->start(KProcess::NotifyOnExit, KProcess::AllOutput) == false)
-			{
-				KMessageBox::error(0, i18n("I can't fork a decompressor"));
-			}
-		}
-      else
-		{
-			kdDebug(1601) << "Temp tar already there..." << endl;
-		}
-	}
-	
-	kdDebug(1601) << "-TarArch::createTmp" << endl;
+            KProcess *kp = new KProcess;
+            kp->clearArguments();
+            kdDebug(1601) << "Uncompressor is " << strUncompressor << endl;
+            *kp << strUncompressor;
+            KProcess::Communication flag = KProcess::AllOutput;
+            if (strUncompressor == "lzop")
+            {
+                // setting up a pty for lzop, since it doesn't like stdin to
+                // be /dev/null ( "no filename allowed when reading from stdin" )
+                // - but it used to work without this ? ( Feb 13, 2003 )
+                kp->setUsePty( KProcess::Stdin, false );
+                flag = KProcess::Stdout;
+                *kp << "-d";
+            }
+            *kp << "-c" << m_filename;
+
+            connect(kp, SIGNAL(processExited(KProcess *)),
+                    this, SLOT(createTmpFinished(KProcess *)));
+            connect(kp, SIGNAL(receivedStdout(KProcess*, char*, int)),
+                    this, SLOT(createTmpProgress( KProcess *, char *, int )));
+            connect( kp, SIGNAL(receivedStderr(KProcess*, char*, int)),
+                    this, SLOT(slotReceivedOutput(KProcess*, char*, int)));
+            if (kp->start(KProcess::NotifyOnExit, flag ) == false)
+            {
+                KMessageBox::error(0, i18n("I can't fork a decompressor"));
+		emit sigOpen( this, false, QString::null, 0 );
+            }
+        }
+        else
+        {
+            emit createTempDone();
+            kdDebug(1601) << "Temp tar already there..." << endl;
+        }
+    }
+    else
+    {
+        emit createTempDone();
+    }
+
+    kdDebug(1601) << "-TarArch::createTmp" << endl;
 }
 
-void TarArch::createTmpProgress( KProcess *, char *_buffer, int _bufflen )
+void TarArch::createTmpProgress( KProcess * _proc, char *_buffer, int _bufflen )
 {
   // we're trying to capture the output of a command like this
   //    gunzip -c myarch.tar.gz
@@ -463,8 +494,11 @@ void TarArch::createTmpProgress( KProcess *, char *_buffer, int _bufflen )
   size = fwrite(_buffer, 1, _bufflen, fd);
   if (size != _bufflen)
     {
+      _proc->kill();
       KMessageBox::error(0, i18n("Trouble writing to the tempfile..."));
-      exit(99);
+      //kdFatal( 1601 ) << "Trouble writing to archive(createTmpProgress)" << endl;
+      kdWarning( 1601 ) << "Trouble writing to archive(createTmpProgress)" << endl;
+      //exit(99);
     }
 }
 
@@ -490,7 +524,7 @@ void TarArch::deleteOldFiles(QStringList *urls, bool bAddOnlyNew)
     const FileLVI * lv = m_gui->getFileLVI(str);
     if ( !lv ) // it isn't in there, so skip it.
       continue;
-    
+
     if (bAddOnlyNew)
     {
       // compare timestamps. If the file to be added is newer, delete the
@@ -524,14 +558,15 @@ void TarArch::deleteOldFiles(QStringList *urls, bool bAddOnlyNew)
   }
   if(!list.isEmpty())
     remove(&list);
+  else
+    emit removeDone();
 }
 
 
 void TarArch::addFile( QStringList* urls )
 {
-  kdDebug(1601) << "+TarArch::addFile" << endl;
-  QString file, url, tmp;
-
+  kdDebug(1601) << "+TarArch::addFile" << ( urls->first() ) << endl;
+  m_filesToAdd = *urls;
   // tar is broken. If you add a file that's already there, it gives you
   // two entries for that name, whether you --append or --update. If you
   // extract by name, it will give you
@@ -539,20 +574,28 @@ void TarArch::addFile( QStringList* urls )
   // first. So we'll first delete all the old files matching the names of
   // those in urls.
   m_bNotifyWhenDeleteFails = false;
+  connect( this, SIGNAL( removeDone() ), this, SLOT( deleteOldFilesDone() ) );
   deleteOldFiles(urls, m_settings->getAddReplaceOnlyWithNewer());
-  while (deleteInProgress)
-    qApp->processEvents(); // wait for deletion
+}
+
+void TarArch::deleteOldFilesDone()
+{
+  disconnect( this, SIGNAL( removeDone() ), this, SLOT( deleteOldFilesDone() ) );
   m_bNotifyWhenDeleteFails = true;
 
+  connect( this, SIGNAL( createTempDone() ), this, SLOT( addFileCreateTempDone() ) );
   createTmp();
-  while (compressed && createTmpInProgress)
-    qApp->processEvents(); // wait for temp to be created;
+}
 
+void TarArch::addFileCreateTempDone()
+{
+  disconnect( this, SIGNAL( createTempDone() ), this, SLOT( addFileCreateTempDone() ) );
+  QString file, url, tmp;
+  QStringList * urls = &m_filesToAdd;
   url = urls->first();
   file = KURL(url).path(-1); // remove trailing slash
 
   KProcess *kp = new KProcess;
-  kp->clearArguments();
   *kp << m_archiver_program;
 
   if( m_settings->getAddReplaceOnlyWithNewer())
@@ -581,6 +624,7 @@ void TarArch::addFile( QStringList* urls )
       file = tmp;
       QDir::setCurrent(base);
     }
+
   QStringList::Iterator it=urls->begin();
   while(1)
     {
@@ -613,10 +657,10 @@ void TarArch::addFile( QStringList* urls )
 
   connect( kp, SIGNAL(processExited(KProcess*)), this,
            SLOT(slotAddFinished(KProcess*)));
-
-  kdDebug(1601) << "Busy loop... waiting for temp tar to be created" << endl;
-  while (compressed && createTmpInProgress)
-    qApp->processEvents(); // wait for temp to be created;
+ // was this ever necessary here?
+ // kdDebug(1601) << "Busy loop... waiting for temp tar to be created" << endl;
+ // while (compressed && createTmpInProgress)
+ //   qApp->processEvents(); // wait for temp to be created;
 
   if (kp->start(KProcess::NotifyOnExit, KProcess::AllOutput) == false)
     {
@@ -638,18 +682,29 @@ void TarArch::slotAddFinished(KProcess *_kp)
 
   disconnect( _kp, SIGNAL(processExited(KProcess*)), this,
               SLOT(slotAddFinished(KProcess*)));
-  if (compressed)
-    {
-      updateArch();
-      while (updateInProgress)
-        qApp->processEvents(); // wait for update;
-    }
-  Arch::slotAddExited(_kp); // this will delete _kp
-  kdDebug(1601) << "-TarArch::slotAddFinished" << endl;
+  m_pTmpProc = _kp;
+  m_filesToAdd = QStringList();
+  if ( compressed )
+  {
+    connect( this, SIGNAL( updateDone() ), this, SLOT( addFinishedUpdateDone() ) );
+    updateArch();
+  }
+  else
+    addFinishedUpdateDone();
+}
+
+void TarArch::addFinishedUpdateDone()
+{
+  kdDebug(1601) << "+TarArch::addFinishedUpdateDone" << endl;
+  if ( compressed )
+    disconnect( this, SIGNAL( updateDone() ), this, SLOT( addFinishedUpdateDone() ) );
+  Arch::slotAddExited( m_pTmpProc ); // this will delete _kp
+  m_pTmpProc = NULL;
+  kdDebug(1601) << "-TarArch::addFinishedUpdateDone" << endl;
 }
 
 void TarArch::unarchFile(QStringList * _fileList, const QString & _destDir,
-                         bool viewFriendly)
+                         bool /* viewFriendly */)
 {
   kdDebug(1601) << "+TarArch::unarchFile" << endl;
   QString dest;
@@ -668,7 +723,7 @@ void TarArch::unarchFile(QStringList * _fileList, const QString & _destDir,
 
   *kp << m_archiver_program;
   if (compressed)
-    *kp << "--use-compress-program="+getUnCompressor() ;
+    *kp << "--use-compress-program="+getUnCompressor();
 
   QString options = "-x";
   if (!m_settings->getExtractOverwrite())
@@ -712,12 +767,16 @@ void TarArch::remove(QStringList *list)
 {
   kdDebug(1601) << "+Tar::remove" << endl;
   deleteInProgress = true;
-  QString name, tmp;
-
+  m_filesToRemove = *list;
+  connect( this, SIGNAL( createTempDone() ), this, SLOT( removeCreateTempDone() ) );
   createTmp();
-  while (compressed && createTmpInProgress)
-    qApp->processEvents(); // wait for temp to be created;
+}
 
+void TarArch::removeCreateTempDone()
+{
+  disconnect( this, SIGNAL( createTempDone() ), this, SLOT( removeCreateTempDone() ) );
+
+  QString name, tmp;
   KProcess *kp = new KProcess;
   kp->clearArguments();
   *kp << m_archiver_program << "--delete" << "-f" ;
@@ -726,11 +785,13 @@ void TarArch::remove(QStringList *list)
   else
     *kp << m_filename;
 
-  for ( QStringList::Iterator it = list->begin(); it != list->end(); ++it )
+  QStringList::Iterator it = m_filesToRemove.begin();
+  for ( ; it != m_filesToRemove.end(); ++it )
     {
       kdDebug(1601) << *it << endl;
       *kp << *it;
     }
+  m_filesToRemove = QStringList();
 
   connect( kp, SIGNAL(receivedStdout(KProcess*, char*, int)),
            this, SLOT(slotReceivedOutput(KProcess*, char*, int)));
@@ -746,16 +807,30 @@ void TarArch::remove(QStringList *list)
       emit sigDelete(false);
     }
 
-  if (compressed)
-    updateArch();
-
   kdDebug(1601) << "-Tar::remove" << endl;
 }
 
 void TarArch::slotDeleteExited(KProcess *_kp)
 {
+  m_pTmpProc2 = _kp;
+  if ( compressed )
+  {
+    connect( this, SIGNAL( updateDone() ), this, SLOT( removeUpdateDone() ) );
+    updateArch();
+  }
+  else
+    removeUpdateDone();
+}
+
+void TarArch::removeUpdateDone()
+{
+  if ( compressed )
+    disconnect( this, SIGNAL( updateDone() ), this, SLOT( removeUpdateDone() ) );
+
   deleteInProgress = false;
-  Arch::slotDeleteExited(_kp);
+  emit removeDone();
+  Arch::slotDeleteExited( m_pTmpProc2 );
+  m_pTmpProc = NULL;
 }
 
 void TarArch::addDir(const QString & _dirName)
@@ -781,9 +856,9 @@ void TarArch::createTmpFinished( KProcess *_kp )
   delete _kp;
   _kp = NULL;
 
-  // turn off busy light (when someone makes one)
 
   kdDebug(1601) << "-TarArch::createTmpFinished" << endl;
+  emit createTempDone();
 }
 
 void TarArch::updateFinished( KProcess *_kp )
@@ -795,7 +870,7 @@ void TarArch::updateFinished( KProcess *_kp )
   _kp = NULL;
 
   kdDebug(1601) << "-TarArch::updateFinished" << endl;
-
+  emit updateDone();
 }
 
 ////////////////////////////////////////////////////////////////////////
