@@ -1,8 +1,6 @@
 //  -*-C++-*-           emacs magic for .h files
 /*
 
-$Id: tar.h,v 1.31.6.1 2003/01/13 10:32:44 helio Exp $
-
 ark -- archiver for the KDE project
 
 Copyright (C)
@@ -12,6 +10,7 @@ Copyright (C)
 1999-2000: Corel Corporation (author: Emily Ezust, emilye@corel.com)
 2001: Corel Corporation (author: Michael Jarrett, michaelj@corel.com)
 2001: Roberto Selbach Teixeira <maragato@conectiva.com>
+2003: Georg Robbers <Georg.Robbers@urz.uni-hd.de>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -25,7 +24,7 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
@@ -37,10 +36,12 @@ Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 class QString;
 class QStrList;
 class KProcess;
+class KTempDir;
 class KTarDirectory;
 class ArkWidgetBase;
 class ArkSettings;
 class Arch;
+class KTar;
 
 // TarArch can read Tar files and Tar files compressed with gzip.
 // It doesn't yet know how to list Tar files compressed with other
@@ -53,7 +54,8 @@ class TarArch : public Arch
 {
   Q_OBJECT
 public:
-  TarArch( ArkSettings *_settings, ArkWidgetBase *_gui, const QString & _filename);
+  TarArch( ArkSettings *_settings, ArkWidgetBase *_gui, const QString & _filename,
+            const QString & _openAsMimeType );
   virtual ~TarArch();
 
   virtual void open();
@@ -69,7 +71,6 @@ public:
 
   QString getCompressor();
   QString getUnCompressor();
-    QString getUnCompressorByExtension();
 
  public slots:
  void updateProgress( KProcess *_kp, char *_buffer, int _bufflen );
@@ -81,26 +82,48 @@ public:
     void slotListingDone( KProcess * );
     void slotDeleteExited( KProcess * );
 
+signals:
+    void removeDone();
+    void createTempDone();
+    void updateDone();
+
+private slots:
+    void openFirstCreateTempDone();
+    void openSecondCreateTempDone();
+    void deleteOldFilesDone();
+    void addFileCreateTempDone();
+    void addFinishedUpdateDone();
+    void removeCreateTempDone();
+    void removeUpdateDone();
+
 private:  // methods
-  void updateArch();
-  void createTmp();
-  void setHeaders();
+    void updateArch();
+    void createTmp();
+    void setHeaders();
     void processDir( const KTarDirectory *tardir, const QString & root );
     void deleteOldFiles( QStringList *list, bool bAddOnlyNew );
     QString getEntry( const QString & filename );
 
 private: // data
- // if the tar is compressed, this is the temporary uncompressed tar.
-  QString tmpfile;
-  bool compressed;
+    // if the tar is compressed, this is the temporary uncompressed tar.
+    KTempDir * m_tmpDir;
+    QString tmpfile;
+    QString m_fileMimeType;
+    bool compressed;
 
-  // for use with createTmp and updateArch
-  bool createTmpInProgress;
-  bool updateInProgress;
+    // for use with createTmp and updateArch
+    bool createTmpInProgress;
+    bool updateInProgress;
 
-  // for use with deleteOldFiles
-  bool deleteInProgress;
-  FILE *fd;
+    // for use with deleteOldFiles
+    bool deleteInProgress;
+    FILE *fd;
+    QStringList m_filesToAdd;
+    QStringList m_filesToRemove;
+    KProcess * m_pTmpProc;
+    KProcess * m_pTmpProc2;
+    KTar *tarptr;
+    bool failed;
 };
 
 #endif /* TAR_H */
