@@ -1,6 +1,6 @@
 /*
 
- $Id: waitDlg.cpp,v 1.2 2001/02/23 18:46:10 mjarrett Exp $
+ $Id: waitDlg.cpp,v 1.3.4.1 2004/04/14 11:45:00 binner Exp $
 
  ark -- archiver for the KDE project
 
@@ -21,7 +21,7 @@
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
- Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
@@ -49,7 +49,7 @@ WaitDlg::WaitDlg( QWidget *_parent, const char *_name, bool _modal, WFlags _f )
 	l1->setFixedSize( l1->sizeHint() );
 	mainLayout->addWidget( l1 );
 
-	QPushButton *cancel = new QPushButton( i18n("Cancel"), this );
+	QPushButton *cancel = new KPushButton( KStdGuiItem::cancel(), this );
 	cancel->setFixedSize( cancel->sizeHint() );
 	connect( cancel, SIGNAL( clicked() ), SLOT( onCancel() ) );
 	mainLayout->addWidget( cancel );
