@@ -1,6 +1,6 @@
 /*
 
- $Id: waitDlg.h,v 1.1 1999/08/04 18:46:17 xavier Exp $
+ $Id: waitDlg.h,v 1.3 2003/03/07 22:06:46 waba Exp $
 
  ark -- archiver for the KDE project
 
@@ -21,16 +21,14 @@
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
- Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
 #ifndef WAIT_DLG_H
 #define WAIT_DLG_H
 
-// Qt includes
-#include <qdialog.h>
-
+class QDialog;
 
 class WaitDlg : public QDialog {
 	Q_OBJECT
