@@ -1,5 +1,5 @@
 /*
-    $Id: kcalctype.h,v 1.16 2002/08/16 18:16:58 waba Exp $
+    $Id: kcalctype.h,v 1.18.2.2 2004/05/09 20:16:42 adridg Exp $
 
     KCalc, a scientific calculator for the X window system using the
     Qt widget libraries, available at no cost at http://www.troll.no
@@ -19,7 +19,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
@@ -33,17 +33,7 @@
 #include <limits.h>
 #include <math.h>
 
-// The following for all the poor devels out there who don't have long double math.
-// I guess it's time to switch to LINUX guys .....
-
-// Undefine HAVE_LONG_DOUBLE for Beta 4 since RedHat 5.0 comes with a borken
-// glibc
-
-//#ifdef HAVE_LONG_DOUBLE
-//#undef HAVE_LONG_DOUBLE
-//#endif
-
-#ifdef HAVE_LONG_DOUBLE
+#if defined(HAVE_LONG_DOUBLE) && defined(HAVE_L_FUNCS)
 /* should be detected by autoconf and defined in config.h
    Be carefull when modifying these lines. HAVE_LONG_DOUBLE
    is used all over kcalc's sources to determine whether 
@@ -58,7 +48,7 @@
 
 
 
-#ifdef HAVE_LONG_DOUBLE
+#if defined(HAVE_LONG_DOUBLE) && defined(HAVE_L_FUNCS)
 	#define FABS(X)		fabsl(X)
 	#define MODF(X,Y)	modfl(X,Y)
 	#define FMOD(X,Y)	fmodl(X,Y)
@@ -76,7 +66,7 @@
 	#define ATANH(X)	atanhl(X)
 	#define EXP(X)		expl(X)
 	#define POW(X,Y)	powl(X,Y)
-	#define LOG(X)		logl(X)
+	#define LN(X)		logl(X)
 	#define LOG_TEN(X)	log10l(X)
 	#define SQRT(X)		sqrtl(X)
 	#define ISINF(X)	isinfl(X)
@@ -99,7 +89,7 @@
 	#define ATANH(X)	atanh(X)
 	#define EXP(X)		exp(X)
 	#define POW(X,Y)	pow(X,Y)
-	#define LOG(X)		log(X)
+	#define LN(X)		log(X)
 	#define LOG_TEN(X)	log10(X)
 	#define SQRT(X)		sqrt(X)
 	#define ISINF(X)	isinf(X)
@@ -113,6 +103,7 @@
 #define KCALC_ULONG_MAX	ULLONG_MAX
 #define KCALC_LONG	long long
 #define HAVE_LONG_LONG
+#define STRTOUL         strtoull
 #else
 #if defined(LONG_LONG_MAX) && defined(HAVE_LONG_DOUBLE)
 #define KCALC_LONG_MIN	LONG_LONG_MIN
@@ -120,11 +111,13 @@
 #define KCALC_ULONG_MAX	ULONG_LONG_MAX
 #define KCALC_LONG	long long
 #define HAVE_LONG_LONG
+#define STRTOUL         strtoull
 #else
 #define KCALC_LONG_MIN	LONG_MIN
 #define KCALC_LONG_MAX	LONG_MAX
 #define KCALC_ULONG_MAX	ULONG_MAX
 #define KCALC_LONG	long
+#define STRTOUL         strtoul
 #endif
 #endif
 #endif 
