@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: kdepasswd.cpp,v 1.6.2.1 2003/04/22 15:10:38 waba Exp $
+ * $Id: kdepasswd.cpp,v 1.10 2003/10/13 21:34:39 goossens Exp $
  *
  * This file is part of the KDE project, module kdesu.
  * Copyright (C) 2000 Geert Jansen <jansen@kde.org>
@@ -22,8 +22,8 @@
 
 static KCmdLineOptions options[] = 
 {
-//    { "user", I18N_NOOP("Change password of this user."), 0 },
-    { 0, 0, 0 }
+    { "+[user]", I18N_NOOP("Change password of this user."), 0 },
+    KCmdLineLastOption
 };
 
 
@@ -46,6 +46,12 @@ int main(int argc, char **argv)
     if (args->count())
 	user = args->arg(0);
 
+    if (!user.isEmpty() && !bRoot)
+    {
+        KMessageBox::sorry(0, i18n("You need to be root to change the password of other users."));
+        return 0;
+    }
+
     QCString oldpass;
     if (!bRoot)
     {
@@ -57,8 +63,6 @@ int main(int argc, char **argv)
     KDEpasswd2Dialog *dlg = new KDEpasswd2Dialog(oldpass, user);
     dlg->exec();
 
-    if (dlg->result() == KDEpasswd2Dialog::Accepted)
-	KMessageBox::information(0L, i18n("Your password has been changed."));
     return 0;
 }
 
