@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: passwd.cpp,v 1.8.4.1 2003/04/22 15:10:38 waba Exp $
+ * $Id: passwd.cpp,v 1.13 2004/01/10 11:46:57 mueller Exp $
  *
  * This file is part of the KDE project, module kdesu.
  * Copyright (C) 1999,2000 Geert Jansen <jansen@kde.org>
@@ -8,6 +8,8 @@
  * passwd.cpp: Change a user's password.
  */
 
+#include <config.h> // setenv
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -78,7 +80,7 @@ int PasswdProcess::exec(const char *oldpass, const char *newpass,
 
     // Try to set the default locale to make the parsing of the output 
     // of `passwd' easier.
-    putenv("LANG=C");
+    setenv("LANG","C", true /* override */);
 
     QCStringList args;
     if(bOtherUser)
@@ -92,9 +94,11 @@ int PasswdProcess::exec(const char *oldpass, const char *newpass,
 
     ret = ConversePasswd(oldpass, newpass, check);
     if (ret < 0)
-	kdDebug(1512) << k_lineinfo << "Conversation with passwd failed.\n";
+        kdDebug(1512) << k_lineinfo << "Conversation with passwd failed. pid = " << pid() << endl;
+
+    if ((waitForChild() != 0) && !check)
+        return PasswordNotGood;
 
-    waitForChild();
     return ret;
 }
 
@@ -222,6 +226,27 @@ int PasswdProcess::ConversePasswd(const char *oldpass, const char *newpass,
 	}
     }
 
+    // Are we ok or do we still get an error thrown at us?
+    m_Error = "";
+    state = 0;
+    while (state != 1)
+    {
+	line = readLine();
+	if (line.isNull()) 
+	{
+	    // No more input... OK
+	    return 0;
+	}
+	if (isPrompt(line, "password"))
+	{
+	   // Uh oh, another prompt. Not good!
+           kill(m_Pid, SIGKILL);
+	   waitForChild();
+	   return PasswordNotGood;
+	}
+	m_Error += line + "\n"; // Collect error message
+    }
+
     kdDebug(1512) << k_lineinfo << "Conversation ended successfully.\n";
     return 0;
 }
