@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: kdessh.cpp,v 1.8 2001/10/13 01:06:30 mueller Exp $
+ * $Id: kdessh.cpp,v 1.10 2003/10/26 11:04:12 binner Exp $
  *
  * This file is part of the KDE project, module kdesu.
  * Copyright (C) 2000 Geert Jansen <jansen@kde.org>
@@ -39,10 +39,10 @@ static KCmdLineOptions options[] =
     { "+command", I18N_NOOP("The command to run."), 0 },
     { "u <user>", I18N_NOOP("Specifies the target uid"), 0 },
     { "s <path>", I18N_NOOP("Specify remote stub location"), "kdesu_stub" },
-    { "n", I18N_NOOP("Do not keep password."), 0 },
-    { "q", I18N_NOOP("Stop the daemon (forgets all passwords)."), 0 },
-    { "t", I18N_NOOP("Enable terminal output (no password keeping)."), 0 },
-    { 0, 0, 0 }
+    { "n", I18N_NOOP("Do not keep password"), 0 },
+    { "q", I18N_NOOP("Stop the daemon (forgets all passwords)"), 0 },
+    { "t", I18N_NOOP("Enable terminal output (no password keeping)"), 0 },
+    KCmdLineLastOption
 };
 
 
