@@ -1,7 +1,7 @@
 /*
  * disklist.cpp
  *
- * $Id: disklist.cpp,v 1.27.2.4 2003/09/02 09:04:29 mlaurent Exp $
+ * $Id: disklist.cpp,v 1.34 2004/01/07 22:28:06 adridg Exp $
  *
  * Copyright (c) 1999 Michael Kropfberger <michael.kropfberger@gmx.net>
  *
@@ -20,7 +20,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
 #include <config.h>
@@ -42,48 +42,27 @@
 DiskList::DiskList(QObject *parent, const char *name)
     : QObject(parent,name)
 {
-  /*
-#ifdef _OS_LINUX_
-  kdDebug() << "_OS_LINUX_" << endl;
-#endif
-#ifdef _OS_FREEBSD_
-  kdDebug() << "_OS_FREEBSD_" << endl;
-#endif
-#ifdef _OS_SUN_
-  kdDebug() << "_OS_SUN_" << endl;
-#endif
-#ifdef _OS_SOLARIS_
-  kdDebug() << "_OS_SOLARIS_" << endl;
-#endif
-#ifdef _OS_HPUX_
-  kdDebug() << "_OS_HPUX_" << endl;
-#endif
-#ifdef _OS_UNIX_
-  kdDebug() << "_OS_UNIX_" << endl;
-#endif
-  */
- updatesDisabled = false;
+   kdDebug() << k_funcinfo << endl;
 
-if (NO_FS_TYPE)
-  kdDebug() << "df gives no FS_TYPE" << endl;
+   updatesDisabled = false;
+
+   if (NO_FS_TYPE) {
+      kdDebug() << "df gives no FS_TYPE" << endl;
+   }
 
    disks = new Disks;
    disks->setAutoDelete(TRUE);
 
    // BackgroundProcesses ****************************************
-      dfProc = new KProcess(); Q_CHECK_PTR(dfProc);
-       connect( dfProc, SIGNAL(receivedStdout(KProcess *, char *, int) ),
-           this, SLOT (receivedDFStdErrOut(KProcess *, char *, int)) );
-       //connect( dfProc, SIGNAL(receivedStderr(KProcess *, char *, int) ),
-       //  this, SLOT (receivedDFStdErrOut(KProcess *, char *, int)) );
-       connect(dfProc,SIGNAL(processExited(KProcess *) ),
-              this, SLOT(dfDone() ) );
+   dfProc = new KProcess(); Q_CHECK_PTR(dfProc);
+   connect( dfProc, SIGNAL(receivedStdout(KProcess *, char *, int) ),
+      this, SLOT (receivedDFStdErrOut(KProcess *, char *, int)) );
+   connect(dfProc,SIGNAL(processExited(KProcess *) ),
+      this, SLOT(dfDone() ) );
 
-       readingDFStdErrOut=FALSE;
-       config = kapp->config();
-       loadSettings();
-       //readFSTAB();
-       //readDF();
+   readingDFStdErrOut=FALSE;
+   config = kapp->config();
+   loadSettings();
 }
 
 
@@ -92,7 +71,7 @@ if (NO_FS_TYPE)
 **/
 DiskList::~DiskList()
 {
-		delete dfProc;
+   kdDebug() << k_funcinfo << endl;
 }
 
 /**
@@ -108,6 +87,8 @@ void DiskList::setUpdatesDisabled(bool disable)
 **/
 void DiskList::applySettings()
 {
+  kdDebug() << k_funcinfo << endl;
+
   QString oldgroup=config->group();
   config->setGroup("DiskList");
   QString key;
@@ -115,15 +96,15 @@ void DiskList::applySettings()
   for (disk=disks->first();disk!=0;disk=disks->next()) {
    key.sprintf("Mount%s%s%s%s",SEPARATOR,disk->deviceName().latin1()
                               ,SEPARATOR,disk->mountPoint().latin1());
-   config->writeEntry(key,disk->mountCommand());
+   config->writePathEntry(key,disk->mountCommand());
 
    key.sprintf("Umount%s%s%s%s",SEPARATOR,disk->deviceName().latin1()
                               ,SEPARATOR,disk->mountPoint().latin1());
-   config->writeEntry(key,disk->umountCommand());
+   config->writePathEntry(key,disk->umountCommand());
 
    key.sprintf("Icon%s%s%s%s",SEPARATOR,disk->deviceName().latin1()
                               ,SEPARATOR,disk->mountPoint().latin1());
-   config->writeEntry(key,disk->realIconName());
+   config->writePathEntry(key,disk->realIconName());
  }
  config->sync();
  config->setGroup(oldgroup);
@@ -135,21 +116,23 @@ void DiskList::applySettings()
 **/
 void DiskList::loadSettings()
 {
+  kdDebug() << k_funcinfo << endl;
+
   config->setGroup("DiskList");
   QString key;
   DiskEntry *disk;
   for (disk=disks->first();disk!=0;disk=disks->next()) {
     key.sprintf("Mount%s%s%s%s",SEPARATOR,disk->deviceName().latin1()
 		,SEPARATOR,disk->mountPoint().latin1());
-    disk->setMountCommand(config->readEntry(key,""));
+    disk->setMountCommand(config->readPathEntry(key));
 
     key.sprintf("Umount%s%s%s%s",SEPARATOR,disk->deviceName().latin1()
 		,SEPARATOR,disk->mountPoint().latin1());
-    disk->setUmountCommand(config->readEntry(key,""));
+    disk->setUmountCommand(config->readPathEntry(key));
 
     key.sprintf("Icon%s%s%s%s",SEPARATOR,disk->deviceName().latin1()
 		,SEPARATOR,disk->mountPoint().latin1());
-    QString icon=config->readEntry(key,"");
+    QString icon=config->readPathEntry(key);
     if (!icon.isEmpty()) disk->setIconName(icon);
  }
 }
@@ -157,11 +140,11 @@ void DiskList::loadSettings()
 
 static QString expandEscapes(const QString& s) {
 QString rc;
-    for (int i = 0; i < s.length(); i++) {
+    for (unsigned int i = 0; i < s.length(); i++) {
         if (s[i] == '\\') {
             i++;
             switch(s[i]) {
-            case '\\':
+            case '\\':  // backslash '\'
                rc += '\\';
                break;
             case '0': // octal 0nn
@@ -187,6 +170,8 @@ return rc;
 **/
 int DiskList::readFSTAB()
 {
+  kdDebug() << k_funcinfo << endl;
+
   if (readingDFStdErrOut || dfProc->isRunning()) return -1;
 
 QFile f(FSTAB);
@@ -248,6 +233,8 @@ QFile f(FSTAB);
 **/
 void DiskList::receivedDFStdErrOut(KProcess *, char *data, int len )
 {
+  kdDebug() << k_funcinfo << endl;
+
 
   /* ATTENTION: StdERR no longer connected to this...
    * Do we really need StdErr?? on HP-UX there was eg. a line
@@ -265,6 +252,8 @@ void DiskList::receivedDFStdErrOut(KProcess *, char *data, int len )
 **/
 int DiskList::readDF()
 {
+  kdDebug() << k_funcinfo << endl;
+
   if (readingDFStdErrOut || dfProc->isRunning()) return -1;
   setenv("LANG", "en_US", 1);
   setenv("LC_ALL", "en_US", 1);
@@ -285,6 +274,8 @@ int DiskList::readDF()
 **/
 void DiskList::dfDone()
 {
+  kdDebug() << k_funcinfo << endl;
+
   if (updatesDisabled)
       return; //Don't touch the data for now..
 	  
@@ -370,6 +361,8 @@ void DiskList::dfDone()
 
 void DiskList::deleteAllMountedAt(const QString &mountpoint)
 {
+  kdDebug() << k_funcinfo << endl;
+
 
     for ( DiskEntry *item  = disks->first(); item;  )
     {
@@ -387,6 +380,8 @@ void DiskList::deleteAllMountedAt(const QString &mountpoint)
 **/
 void DiskList::replaceDeviceEntry(DiskEntry *disk)
 {
+  kdDebug() << k_funcinfo << endl;
+
   //
   // The 'disks' may already already contain the 'disk'. If it do
   // we will replace some data. Otherwise 'disk' will be added to the list
