@@ -18,7 +18,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
 #include <qregexp.h>
@@ -96,9 +96,15 @@ int DiskEntry::mount()
   QString cmdS=mntcmd;
   if (cmdS.isEmpty()) // generate default mount cmd
     if (getuid()!=0 ) // user mountable
+      {
       cmdS="mount %d";
+      }
 	else  // root mounts with all params/options
-      cmdS="mount -t%t %d %m -o %o";
+      {
+      // FreeBSD's mount(8) is picky: -o _must_ go before
+      // the device and mountpoint.
+      cmdS=QString::fromLatin1("mount -t%t -o%o %d %m");
+      }
 
   cmdS.replace(QRegExp("%d"),this->deviceName());
   cmdS.replace(QRegExp("%m"),this->mountPoint());
@@ -223,7 +229,7 @@ int DiskEntry::sysCall(const QString & command)
   sysProc->clearArguments();
   (*sysProc) << command;
     if (!sysProc->start( KProcess::Block, KProcess::AllOutput ))
-     qFatal(i18n("could not execute [%1]").arg(command).local8Bit().data());
+     qFatal(i18n("could not execute %s").local8Bit().data(), command.local8Bit().data());
 
   if (sysProc->exitStatus()!=0) emit sysCallError(this, sysProc->exitStatus());
 
