@@ -1,5 +1,5 @@
 /*
- * $Id: kdf.cpp,v 1.25.2.1 2003/07/17 11:02:36 mueller Exp $
+ * $Id: kdf.cpp,v 1.28 2003/09/20 12:28:02 mlaurent Exp $
  *
  * kdf.cpp - KDiskFree
  *
@@ -17,7 +17,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  */
 
@@ -27,6 +27,7 @@
 #include <kaboutdata.h>
 #include <kstdaction.h>
 #include <kaction.h>
+#include <kkeydialog.h>
 
 #include "kdf.h"
 #include <kpopupmenu.h>
@@ -41,25 +42,17 @@ static const char *version = "v0.5";
 KDFTopLevel::KDFTopLevel(QWidget *, const char *name)
   : KMainWindow(0, name)
 {
-  kdf = new KDFWidget(this,"kdf",FALSE); Q_CHECK_PTR(kdf);
-
-  QPopupMenu *file = new QPopupMenu; Q_CHECK_PTR(file);
-  file->insertItem( i18n( "&Update" ), kdf, SLOT(updateDF()) );
-  file->insertSeparator();
-  KStdAction::quit(this, SLOT(close()), actionCollection())->plug(file);
-
-  QPopupMenu *option = new QPopupMenu; Q_CHECK_PTR(option);
-  KStdAction::preferences(kdf, SLOT(settingsBtnClicked()), actionCollection())->plug(option);
-
-  QPopupMenu * help = helpMenu();
-  menuBar()->insertItem( i18n("&File"), file );
-  menuBar()->insertItem( i18n("&Settings"), option );
-  menuBar()->insertSeparator();
-  menuBar()->insertItem( i18n("&Help"), help );
+  kdf = new KDFWidget(this,"kdf",FALSE);
+  Q_CHECK_PTR(kdf);
+  (void) new KAction( i18n( "&Update" ), 0, kdf, SLOT( updateDF() ), actionCollection(), "updatedf" );
 
+  KStdAction::quit(this, SLOT(close()), actionCollection());
+  KStdAction::preferences(kdf, SLOT(settingsBtnClicked()), actionCollection());
+  KStdAction::keyBindings( this, SLOT( slotConfigureKeys() ), actionCollection() );
   setCentralWidget(kdf);
   //  kdf->setMinimumSize(kdf->sizeHint());
   kdf->resize(kdf->sizeHint());
+  createGUI();
 }
 
 
@@ -70,7 +63,10 @@ bool KDFTopLevel::queryExit( void )
 }
 
 
-
+void KDFTopLevel::slotConfigureKeys()
+{
+  KKeyDialog::configure( actionCollection(), this );
+}
 
 
 /***************************************************************/
