@@ -1,7 +1,7 @@
 /*
  * kdfwidget.cpp
  *
- * $Id: kdfwidget.cpp,v 1.36.2.1 2003/07/17 11:02:36 mueller Exp $
+ * $Id: kdfwidget.cpp,v 1.40 2003/10/03 16:25:15 aacid Exp $
  *
  * Copyright (c) 1998-2001 Michael Kropfberger <michael.kropfberger@gmx.net>
  *
@@ -20,7 +20,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
 //
@@ -41,6 +41,7 @@
 #include <kcmenumngr.h>
 #include <kmessagebox.h>
 #include <kpopupmenu.h>
+#include <kprocess.h>
 
 #include "listview.h"
 #include "kdfwidget.h"
@@ -488,7 +489,8 @@ void KDFWidget::popupMenu( QListViewItem *item, const QPoint &p )
     return;
   }
 
-  mPopup = new KPopupMenu( disk->mountPoint(), 0 );
+  mPopup = new KPopupMenu( 0 );
+  mPopup->insertTitle( disk->mountPoint() );
   mPopup->insertItem( i18n("Mount Device"), 0 );
   mPopup->insertItem( i18n("Unmount Device"), 1 );
   mPopup->insertSeparator();
@@ -541,11 +543,11 @@ void KDFWidget::popupMenu( QListViewItem *item, const QPoint &p )
       int pos = cmd.find("%m");
       if( pos > 0 )
       {
-	cmd = cmd.replace( pos, 2, disk->mountPoint() ) + " &";
+	cmd = cmd.replace( pos, 2, KProcess::quote(disk->mountPoint()) ) + " &";
       }
       else
       {
-	cmd += " " + disk->mountPoint() +" &";
+	cmd += " " + KProcess::quote(disk->mountPoint()) +" &";
       }
       system( QFile::encodeName(cmd) );
     }
