@@ -1,6 +1,6 @@
   /*
 
-    $Id: kedit.cpp,v 1.165.2.7 2003/07/25 14:48:01 mlaurent Exp $
+    $Id: kedit.cpp,v 1.195.2.1 2004/04/14 11:45:01 binner Exp $
 
     Copyright (C) 1997 Bernd Johannes Wuebben
                        wuebben@math.cornell.edu
@@ -17,58 +17,57 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
     */
 
-// WABA: Needed for backupFile()
 #include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
+#include <stdlib.h>
 #include <unistd.h>
 
-#include <qdragobject.h>
+#include <qlayout.h>
 #include <qtimer.h>
-
-#include <kapplication.h>
-#include <kcursor.h>
-#include "ktextfiledlg.h"
-#include <kio/netaccess.h>
-#include <kmessagebox.h>
-#include <ktempfile.h>
-#include <kaboutdata.h>
-#include <kcmdlineargs.h>
-#include <kedittoolbar.h>
-#include <kkeydialog.h>
-#include <klocale.h>
-
-#include <qpainter.h>
-#include <qpen.h>
 #include <qpaintdevicemetrics.h>
-#include <qsimplerichtext.h>
-#include <kprinter.h>
+#include <qpainter.h>
 
+#include <kaboutdata.h>
+#include <kaction.h>
+#include <kapplication.h>
+#include <kcmdlineargs.h>
+#include <kcolorbutton.h>
+#include <kconfigdialog.h>
+#include <kcursor.h>
+#include <keditcl.h>
+#include <kedittoolbar.h>
+#include <kfileitem.h>
+#include <kfontdialog.h>
+#include <kio/netaccess.h>
+#include <kkeydialog.h>
+#include <kmessagebox.h>
+#include <kprinter.h>
+#include <ksavefile.h>
+#include <kstatusbar.h>
+#include <kspell.h>
+#include <kurldrag.h>
+
+#include "ktextfiledlg.h"
 #include "kedit.h"
-#include "mail.h"
-#include "optiondialog.h"
-#include "version.h"
+#include "misc.h"
+#include "color.h"
+#include "prefs.h"
 
 #include <kdebug.h>
 
-#include <stdlib.h>
-#include <kstatusbar.h>
 
 QPtrList<TopLevel> *TopLevel::windowList = 0;
 
 int default_open =  TopLevel::OPEN_READWRITE;
 
 TopLevel::TopLevel (QWidget *, const char *name)
-  : KMainWindow ( 0,name )
+  : KMainWindow ( 0,name ), kspellconfigOptions(0),
+  eframe(0), newWindow(false), kspell(0)
 {
-  mOptionDialog = 0;
-  kspell = 0;
-  newWindow = false;
-
+  setAutoSaveSettings();
   if (!windowList)
   {
      windowList = new QPtrList<TopLevel>;
@@ -89,7 +88,6 @@ TopLevel::TopLevel (QWidget *, const char *name)
   readSettings();
 
   setupEditWidget();
-  set_colors();
 
   setAcceptDrops(true);
 
@@ -100,51 +98,51 @@ TopLevel::TopLevel (QWidget *, const char *name)
 TopLevel::~TopLevel ()
 {
   windowList->remove( this );
-  delete mOptionDialog;
 }
 
 
-
 void TopLevel::setupEditWidget()
 {
-  eframe = new KEdit (this, "eframe");
-  eframe->setOverwriteEnabled(true);
-  KCursor::setAutoHideCursor( eframe, true );
+  if (!eframe)
+  {
+    eframe = new KEdit (this, "eframe");
+    eframe->setOverwriteEnabled(true);
+    KCursor::setAutoHideCursor( eframe, true );
 
-  connect(eframe, SIGNAL(CursorPositionChanged()),this,
-	  SLOT(statusbar_slot()));
-  connect(eframe, SIGNAL(toggle_overwrite_signal()),this,
-	  SLOT(toggle_overwrite()));
-  connect(eframe, SIGNAL(gotUrlDrop(QDropEvent*)), this,
-	  SLOT(urlDrop_slot(QDropEvent*)));
-  connect(eframe, SIGNAL(undoAvailable(bool)),undoAction,
-	  SLOT(setEnabled(bool)));
-  connect(eframe, SIGNAL(redoAvailable(bool)),redoAction,
-	  SLOT(setEnabled(bool)));
-  connect(eframe, SIGNAL(copyAvailable(bool)),cutAction,
-	  SLOT(setEnabled(bool)));
-  connect(eframe, SIGNAL(copyAvailable(bool)),copyAction,
-	  SLOT(setEnabled(bool)));
-  connect( eframe, SIGNAL(selectionChanged()),this,
-     SLOT(slotSelectionChanged()));
-  connect( eframe, SIGNAL(modificationChanged( bool)),
+    connect(eframe, SIGNAL(CursorPositionChanged()),this,
+           SLOT(statusbar_slot()));
+    connect(eframe, SIGNAL(toggle_overwrite_signal()),this,
+           SLOT(toggle_overwrite()));
+    connect(eframe, SIGNAL(gotUrlDrop(QDropEvent*)), this,
+           SLOT(urlDrop_slot(QDropEvent*)));
+    connect(eframe, SIGNAL(undoAvailable(bool)),undoAction,
+           SLOT(setEnabled(bool)));
+    connect(eframe, SIGNAL(redoAvailable(bool)),redoAction,
+           SLOT(setEnabled(bool)));
+    connect(eframe, SIGNAL(copyAvailable(bool)),cutAction,
+           SLOT(setEnabled(bool)));
+    connect(eframe, SIGNAL(copyAvailable(bool)),copyAction,
+           SLOT(setEnabled(bool)));
+    connect( eframe, SIGNAL(selectionChanged()),this,
+           SLOT(slotSelectionChanged()));
+    connect( eframe, SIGNAL(modificationChanged( bool)),
            SLOT(setFileCaption()));
 
+    undoAction->setEnabled(false);
+    redoAction->setEnabled(false);
+    cutAction->setEnabled(false);
+    copyAction->setEnabled(false);
 
-  undoAction->setEnabled(false);
-  redoAction->setEnabled(false);
-  cutAction->setEnabled(false);
-  copyAction->setEnabled(false);
+    setCentralWidget(eframe);
+    eframe->setMinimumSize(200, 100);
+  }
 
-  setCentralWidget(eframe);
-  eframe->setMinimumSize(200, 100);
-
-  if( mOptionState.misc.wrapMode == SMiscState::fixedColumnWrap )
+  if( Prefs::wrapMode() == Prefs::EnumWrapMode::FixedColumnWrap )
   {
     eframe->setWordWrap(QMultiLineEdit::FixedColumnWidth);
-    eframe->setWrapColumnOrWidth(mOptionState.misc.wrapColumn);
+    eframe->setWrapColumnOrWidth(Prefs::wrapColumn());
   }
-  else if( mOptionState.misc.wrapMode == SMiscState::softWrap )
+  else if( Prefs::wrapMode() == Prefs::EnumWrapMode::SoftWrap )
   {
     eframe->setWordWrap(QMultiLineEdit::WidgetWidth);
   }
@@ -152,21 +150,27 @@ void TopLevel::setupEditWidget()
   {
     eframe->setWordWrap(QMultiLineEdit::NoWrap);
   }
-  setFontOption( mOptionState.font );
+
+  eframe->setFont( Prefs::font() );
+  int w = eframe->fontMetrics().width("M");
+  eframe->setTabStopWidth(8*w);
+
   eframe->setModified(false);
 
   setSensitivity();
 
   eframe->setFocus();
 
+  set_colors();
+
   /*
   right_mouse_button = new QPopupMenu;
 
   right_mouse_button->insertItem (i18n("Open..."),
 				  this, 	SLOT(file_open()));
-  right_mouse_button->insertItem (i18n("Save"),
+  right_mouse_button->insertItem (SmallIcon("filesave"),i18n("Save"),
 				  this, 	SLOT(file_save()));
-  right_mouse_button->insertItem (i18n("Save as..."),
+  right_mouse_button->insertItem (SmallIcon("filesaveas"),i18n("Save As..."),
 				  this, SLOT(file_save_as()));
   right_mouse_button->insertSeparator(-1);
   right_mouse_button->insertItem(i18n("Copy"),
@@ -181,6 +185,7 @@ void TopLevel::setupEditWidget()
   */
 }
 
+
 void TopLevel::slotSelectionChanged()
 {
   bool state = eframe->hasSelectedText();
@@ -191,7 +196,6 @@ void TopLevel::slotSelectionChanged()
 
 void TopLevel::setupActions()
 {
-
     // setup File menu
     KStdAction::openNew(this, SLOT(file_new()), actionCollection());
     KStdAction::open(this, SLOT(file_open()), actionCollection());
@@ -209,7 +213,7 @@ void TopLevel::setupActions()
     redoAction = KStdAction::redo(this, SLOT(redo()), actionCollection());
     cutAction = KStdAction::cut(this, SLOT(cut()), actionCollection());
     copyAction = KStdAction::copy(this, SLOT(copy()), actionCollection());
-    KStdAction::paste(this, SLOT(paste()), actionCollection());
+    KStdAction::pasteText(this, SLOT(paste()), actionCollection());
     KStdAction::selectAll(this, SLOT(select_all()), actionCollection());
     KStdAction::find(this, SLOT(search()), actionCollection());
     KStdAction::findNext(this, SLOT(search_again()), actionCollection());
@@ -229,11 +233,10 @@ void TopLevel::setupActions()
     KStdAction::gotoLine(this, SLOT(gotoLine()), actionCollection());
 
     // setup Settings menu
-    toolbarAction = KStdAction::showToolbar(this, SLOT(toggleToolBar()), actionCollection());
-    statusbarAction = KStdAction::showStatusbar(this, SLOT(toggleStatusBar()), actionCollection());
+    createStandardStatusBarAction();
+    setStandardToolBarMenuEnabled(true);
 
-    KStdAction::saveOptions(this, SLOT(save_options()), actionCollection());
-    KStdAction::preferences(this, SLOT(customize()), actionCollection());
+    KStdAction::preferences(this, SLOT(showSettings()), actionCollection());
 
     KStdAction::keyBindings(this, SLOT(editKeys()), actionCollection());
     KStdAction::configureToolbars(this, SLOT(editToolbars()), actionCollection());
@@ -256,8 +259,6 @@ void TopLevel::setupStatusBar()
 }
 
 
-
-
 void TopLevel::saveProperties(KConfig* config)
 {
   if(m_url.isEmpty() && !eframe->isModified())
@@ -284,8 +285,8 @@ void TopLevel::saveProperties(KConfig* config)
 
 
 void TopLevel::readProperties(KConfig* config){
-    KURL url = config->readEntry("url");
-    QString filename = config->readEntry("saved_to");
+    KURL url = config->readPathEntry("url");
+    QString filename = config->readPathEntry("saved_to");
 
     QString encoding = url.fileEncoding();
     int modified = config->readNumEntry("modified",0);
@@ -346,8 +347,6 @@ void TopLevel::select_all()
 }
 
 
-
-
 void TopLevel::insertDate(){
 
   int line, column;
@@ -371,6 +370,7 @@ void TopLevel::paste(){
  statusbar_slot();
 }
 
+
 void TopLevel::cut(){
 
  eframe->cut();
@@ -379,6 +379,7 @@ void TopLevel::cut(){
 
 }
 
+
 void TopLevel::file_new()
 {
   TopLevel *t = new TopLevel ();
@@ -399,8 +400,9 @@ void TopLevel::spellcheck()
 
   statusBar()->changeItem(i18n("Spellcheck:  Started."), ID_GENERAL);
 
+  initSpellConfig();
   kspell = new KSpell(this, i18n("Spellcheck"), this,
-	SLOT( spell_started(KSpell *)), &mOptionState.spell.config);
+	SLOT( spell_started(KSpell *)), kspellconfigOptions);
 
   connect (kspell, SIGNAL ( death()),
           this, SLOT ( spell_finished( )));
@@ -415,6 +417,7 @@ void TopLevel::spellcheck()
 		 this, SLOT (spell_done(const QString&)));
 }
 
+
 void TopLevel::spell_started( KSpell *)
 {
    eframe->spellcheck_start();
@@ -422,6 +425,7 @@ void TopLevel::spell_started( KSpell *)
    kspell->check(eframe->text());
 }
 
+
 void TopLevel::spell_progress (unsigned int percent)
 {
   QString s;
@@ -430,6 +434,7 @@ void TopLevel::spell_progress (unsigned int percent)
   statusBar()->changeItem (s, ID_GENERAL);
 }
 
+
 void TopLevel::spell_done(const QString& newtext)
 {
   eframe->spellcheck_stop();
@@ -463,9 +468,11 @@ void TopLevel::spell_finished( )
   }
 }
 
+
 void TopLevel::file_open( void )
 {
-  while( 1 )
+
+    while( 1 )
   {
     KURL url = KTextFileDialog::getOpenURLwithEncoding(
 		QString::null, QString::null, this,
@@ -475,6 +482,20 @@ void TopLevel::file_open( void )
       return;
     }
 
+    KIO::UDSEntry entry;
+    KIO::NetAccess::stat(url, entry, this);
+    KFileItem fileInfo(entry, url);
+    if (fileInfo.size() > 2097152 && // 2MB large/small enough?
+        KMessageBox::warningContinueCancel(this,
+                         i18n("The file you have requested is larger than KEdit is designed for. "
+                              "Please ensure you have enough system resources available to safely load this file, "
+                              "or consider using a program that is designed to handle large files such as KWrite."),
+                        i18n("Attempting To Open Large File"),
+                        KStdGuiItem::cont(), "attemptingToOpenLargeFile") == KMessageBox::Cancel)
+    {
+        return;
+    }
+
     TopLevel *toplevel;
     if( !m_url.isEmpty() || eframe->isModified() )
     {
@@ -490,7 +511,8 @@ void TopLevel::file_open( void )
     }
 
     QString tmpfile;
-    KIO::NetAccess::download( url, tmpfile );
+    KIO::NetAccess::download( url, tmpfile, toplevel );
+
     int result = toplevel->openFile( tmpfile, 0, url.fileEncoding());
     KIO::NetAccess::removeTempFile( tmpfile );
 
@@ -515,6 +537,7 @@ void TopLevel::file_open( void )
       break;
     }
   }
+
 }
 
 void TopLevel::file_insert()
@@ -530,7 +553,7 @@ void TopLevel::file_insert()
     }
 
     QString tmpfile;
-    KIO::NetAccess::download( url, tmpfile );
+    KIO::NetAccess::download( url, tmpfile, this );
     int result = openFile( tmpfile, OPEN_INSERT, url.fileEncoding(), true );
     KIO::NetAccess::removeTempFile( tmpfile );
 
@@ -561,53 +584,57 @@ bool TopLevel::queryExit()
 
 bool TopLevel::queryClose()
 {
-    queryExit();
-    int result;
-  if( !eframe->isModified() )
-  {
+  queryExit();
+  int result;
+
+  if ( !eframe->isModified() )
      return true;
-  }
 
   QString msg = i18n(""
         "This document has been modified.\n"
         "Would you like to save it?" );
-  switch( KMessageBox::warningYesNoCancel( this, msg ) )
+  switch( KMessageBox::warningYesNoCancel( this, msg, QString::null,
+                       KStdGuiItem::save(), KStdGuiItem::discard() ) )
   {
      case KMessageBox::Yes: // Save, then exit
-                    if( m_url.isEmpty())
-                        file_save_as();
-                    else
-                        {
-	        result = saveURL(m_url);
-	        if( result == KEDIT_USER_CANCEL )
-	                return false;
-	        if( result != KEDIT_OK)
-	                {
-	                msg = i18n(""
+              if ( m_url.isEmpty())
+              {
+                 file_save_as();
+                 if ( eframe->isModified() )
+                     return false; // Still modified? Don't exit!
+              }
+              else
+              {
+                 result = saveURL(m_url);
+                 if ( result == KEDIT_USER_CANCEL )
+                    return false; // Don't exit.
+
+                 if ( result != KEDIT_OK)
+                 {
+                    msg = i18n(""
 	                "Could not save the file.\n"
 	                "Exit anyways?");
-	                switch( KMessageBox::warningYesNo( this, msg ) )
-	                        {
-	                        case KMessageBox::Yes:
-	                                return true;
-	                        case KMessageBox::No:
-                                        default:
-                                                return false;
-	                        }
-	                }
-                        }
-          return true;
+                    switch( KMessageBox::warningYesNo( this, msg ) )
+                    {
+                     case KMessageBox::Yes:
+                              return true; // Exit.
+                     case KMessageBox::No:
+                     default:
+                              return false; // Don't exit.
+                    }
+                 }
+              }
 
      case KMessageBox::No: // Don't save but exit.
           return true;
 
      case KMessageBox::Cancel: // Don't save and don't exit.
      default:
-	  break; // Don't exit...
+	  return false; // Don't exit...
   }
-  return false;
-}
 
+  return true; // Exit.
+}
 
 
 void TopLevel::openRecent(const KURL& url)
@@ -622,13 +649,15 @@ void TopLevel::openRecent(const KURL& url)
   openURL( url, OPEN_READWRITE );
 }
 
+
 void TopLevel::file_close()
 {
   if( eframe->isModified() )
   {
     QString msg = i18n("This document has been modified.\n"
                        "Would you like to save it?" );
-    switch( KMessageBox::warningYesNoCancel( this, msg ) )
+    switch( KMessageBox::warningYesNoCancel( this, msg, QString::null,
+                           KStdGuiItem::save(), KStdGuiItem::discard() ) )
     {
       case KMessageBox::Yes: // Save, then close
         file_save();
@@ -671,6 +700,7 @@ void TopLevel::file_save()
   }
 }
 
+
 void TopLevel::setGeneralStatusField(const QString &text){
 
     statusbar_timer->stop();
@@ -683,12 +713,30 @@ void TopLevel::setGeneralStatusField(const QString &text){
 
 void TopLevel::file_save_as()
 {
-  KURL u = KTextFileDialog::getSaveURLwithEncoding(
-	      m_url.url(), QString::null, this,
-	      i18n("Save File As"),
-	      m_url.fileEncoding());
-  if (u.isEmpty())
-    return;
+  KURL u;
+  while(true)
+  {
+     u = KTextFileDialog::getSaveURLwithEncoding(
+                 m_url.url(), QString::null, this,
+                 i18n("Save File As"),
+                 m_url.fileEncoding());
+
+     if (u.isEmpty())
+        return;
+
+     if ( KIO::NetAccess::exists(u, false, this) )
+     {
+        int result = KMessageBox::warningContinueCancel( this,
+           i18n( "A file named \"%1\" already exists. "
+                 "Are you sure you want to overwrite it?" ).arg( u.prettyURL() ),
+           i18n( "Overwrite File?" ),
+           i18n( "Overwrite" ) );
+
+        if (result != KMessageBox::Continue)
+           continue;
+     }
+     break;
+  }
 
   int result = saveURL(u); // error messages are handled by saveFile
 
@@ -706,52 +754,16 @@ void TopLevel::file_save_as()
 
 void TopLevel::mail()
 {
-  // TODO: add charset box to mail dlg?
+  //
+  // Default subject string
+  //
+  QString defaultsubject = name();
+  int index = defaultsubject.findRev('/');
+  if( index != -1)
+    defaultsubject = defaultsubject.right(defaultsubject.length() - index - 1 );
 
-  Mail *maildlg = new Mail(this,"maildialog");
-  if( maildlg->exec() == QDialog::Rejected )
-  {
-    delete maildlg;
-    return;
-  }
-
-  kapp->processEvents();
-  kapp->flushX();
-
-  QString cmd;
-  cmd = cmd.sprintf(mOptionState.misc.mailCommand.local8Bit().data(),
-    maildlg->getSubject().local8Bit().data(),
-    maildlg->getRecipient().local8Bit().data());
-
-  delete maildlg;
-
-  FILE* mailpipe = popen(cmd.local8Bit().data(),"w");
-  if( mailpipe == NULL )
-  {
-    QString msg = i18n(""
-      "Could not pipe the contents"
-      " of this document into:\n %1").arg(cmd);
-    KMessageBox::sorry( this, msg );
-    return;
-  }
-
-  QString enc = m_url.fileEncoding();
-  QTextStream t(mailpipe,IO_WriteOnly );
-  QTextCodec *codec;
-  if (!enc.isEmpty())
-    codec = QTextCodec::codecForName(enc.latin1());
-  else
-    codec = QTextCodec::codecForLocale();
-  t.setCodec(codec);
-
-  // t << "Content-Type: text/plain; charset=" << enc << "\n\n";
-
-  int line_count = eframe->numLines();
-
-  for(int i = 0 ; i < line_count ; i++){
-    t << eframe->textLine(i) << '\n';
-  }
-  pclose(mailpipe);
+  kapp->invokeMailer( QString::null, QString::null, QString::null,
+       defaultsubject, eframe->text() );
 }
 
 /*
@@ -795,118 +807,57 @@ void TopLevel::helpselected(){
 
 }
 
+
 void TopLevel::search(){
 
-      eframe->search();
-      statusbar_slot();
+  eframe->search();
+  statusbar_slot();
 }
 
 void TopLevel::replace(){
-
-      eframe->replace();
-      statusbar_slot();
+  eframe->replace();
+  statusbar_slot();
 }
 
 
-void TopLevel::customize( void )
-{
-  if( mOptionDialog == 0 )
-  {
-    mOptionDialog = new COptionDialog( topLevelWidget(), 0, false );
-    if( mOptionDialog == 0 ) { return; }
-    connect( mOptionDialog, SIGNAL(fontChoice(const SFontState &)),
-	     this, SLOT(setFontOption(const SFontState &)) );
-    connect( mOptionDialog, SIGNAL(colorChoice(const SColorState &)),
-	     this, SLOT(setColorOption(const SColorState &)) );
-    connect( mOptionDialog, SIGNAL(spellChoice(const SSpellState &)),
-	     this, SLOT(setSpellOption(const SSpellState &)) );
-    connect( mOptionDialog, SIGNAL(miscChoice(const SMiscState &)),
-	     this, SLOT(setMiscOption(const SMiscState &)) );
-    connect( mOptionDialog, SIGNAL(save()),
-	     this, SLOT(writeSettings()) );
-  }
-  if( mOptionDialog->isVisible() == false )
-  {
-    mOptionDialog->setState( mOptionState );
-  }
 
-  mOptionDialog->show();
+void TopLevel::showSettings()
+{
+  if(KConfigDialog::showDialog("settings"))
+    return;
+
+  initSpellConfig();
+  KConfigDialog* dialog = new SettingsDialog(this, "settings", Prefs::self(), kspellconfigOptions);
+
+  connect(dialog, SIGNAL(settingsChanged()), this, SLOT(updateSettings()));
+  dialog->show();
+}
+
+void TopLevel::initSpellConfig()
+{
+  if (!kspellconfigOptions)
+     kspellconfigOptions = new KSpellConfig(0 , "SpellingSettings", 0, false );
 }
 
 void TopLevel::editKeys()
 {
-  KKeyDialog::configureKeys(actionCollection(), xmlFile());
+  KKeyDialog::configure(actionCollection());
 }
 
+
 void TopLevel::editToolbars()
 {
+  saveMainWindowSettings(KGlobal::config(), "MainWindow");
   KEditToolbar dlg(actionCollection());
-
-  if (dlg.exec())
-    createGUI();
-}
-
-void TopLevel::setFontOption( const SFontState &font )
-{
-  mOptionState.font = font;
-  eframe->setFont( mOptionState.font.font );
-  int w = eframe->fontMetrics().width("M");
-  eframe->setTabStopWidth(8*w);
+  connect(&dlg, SIGNAL( newToolbarConfig() ), this, SLOT( slotNewToolbarConfig() ));
+  dlg.exec();
 }
 
 
-void TopLevel::setColorOption( const SColorState &color )
+void TopLevel::slotNewToolbarConfig()
 {
-  mOptionState.color = color;
-  set_colors();
-}
-
-
-void TopLevel::setSpellOption( const SSpellState &spell )
-{
-  mOptionState.spell = spell;
-}
-
-
-void TopLevel::setMiscOption( const SMiscState &misc )
-{
-  mOptionState.misc = misc;
-  if( mOptionState.misc.wrapMode == SMiscState::fixedColumnWrap )
-  {
-    eframe->setWordWrap(QMultiLineEdit::FixedColumnWidth);
-    eframe->setWrapColumnOrWidth(mOptionState.misc.wrapColumn);
-  }
-  else if( mOptionState.misc.wrapMode == SMiscState::softWrap )
-  {
-    eframe->setWordWrap(QMultiLineEdit::WidgetWidth);
-  }
-  else
-  {
-    eframe->setWordWrap(QMultiLineEdit::NoWrap);
-  }
-
-  //eframe->saveBackupCopy(mOptionState.misc.backupCheck);
-}
-
-
-
-void TopLevel::toggleToolBar()
-{
-  bool show_toolbar = toolbarAction->isChecked();
-  if (show_toolbar)
-     toolBar("mainToolBar")->show();
-  else
-     toolBar("mainToolBar")->hide();
-}
-
-
-void TopLevel::toggleStatusBar()
-{
-  bool show_statusbar = statusbarAction->isChecked();
-  if (show_statusbar)
-     statusBar()->show();
-  else
-     statusBar()->hide();
+  createGUI();
+  applyMainWindowSettings(KGlobal::config(), "MainWindow");
 }
 
 
@@ -976,13 +927,12 @@ void TopLevel::print()
     QFontMetrics headerFontMetrics(headerFont);
 
     KPrinter *printer = new KPrinter;
-    if(printer->setup(this)) {
+    if(printer->setup(this, i18n("Print %1").arg(m_caption))) {
         // set up KPrinter
         printer->setFullPage(false);
         printer->setCreator("KEdit");
-        QString docname = m_caption;
-        if ( !docname.isEmpty() )
-	    printer->setDocName(docname);
+        if ( !m_caption.isEmpty() )
+	    printer->setDocName(m_caption);
 
         QPainter *p = new QPainter;
         p->begin( printer );
@@ -999,25 +949,8 @@ void TopLevel::print()
         int lineCount = 0;
         int maxLineCount = eframe->numLines();
 
-        KDialogBase *dlg = new KDialogBase(this, "printdialog", true, i18n("Printing"), KDialogBase::Ok, KDialogBase::Ok, true);
-        dlg->setButtonOKText(i18n("Stop"), i18n("Stop printing"));
-        QLabel *dlg_lbl = new QLabel(dlg);
-        dlg->setMainWidget(dlg_lbl);
-        dlg->setInitialSize(QSize(300,120));
-        dlg->show();
 
         while(true) {
-           QString lbl_txt = i18n("Printing page %1...").arg(page);
-           dlg_lbl->setText(lbl_txt);
-           kapp->flush();
-           kapp->processEvents();
-           kapp->flush();
-           if (dlg->isHidden())
-           {
-               aborted = true;
-               printer->abort();
-               break;
-           }
            headerRight = QString("#%1").arg(page);
            dy = headerFontMetrics.lineSpacing();
            QRect body( 0, dy*2,  metrics.width(), metrics.height()-dy*2);
@@ -1056,7 +989,6 @@ void TopLevel::print()
            printer->newPage();
            page++;
         }
-        delete dlg;
 
         p->end();
         delete p;
@@ -1074,17 +1006,10 @@ void TopLevel::setSensitivity (){
 
 }
 
-void TopLevel::save_options()
-{
-  KConfig *config = kapp->config();
-  config->setGroup("MainWindow");
-  saveMainWindowSettings(config);
-  config->sync();
-}
 
 int TopLevel::saveURL( const KURL& _url )
 {
-    if ( _url.isMalformed() )
+    if ( !_url.isValid() )
     {
         KMessageBox::sorry(this, i18n("Malformed URL"));
         return KEDIT_RETRY;
@@ -1101,7 +1026,7 @@ int TopLevel::saveURL( const KURL& _url )
     eframe->setModified( true );
     saveFile( tmpFile.name(), false, _url.fileEncoding() );
 
-    if (KIO::NetAccess::upload( tmpFile.name(), _url ) == false)
+    if (KIO::NetAccess::upload( tmpFile.name(), _url, this ) == false)
     {
       KMessageBox::error(this, "Could not save remote file");
       return KEDIT_RETRY;
@@ -1110,13 +1035,14 @@ int TopLevel::saveURL( const KURL& _url )
     return true;
 }
 
-int TopLevel::openFile( const QString& _filename, int _mode, const QString &encoding,  bool _undoAction )
+
+int TopLevel::openFile( const QString& _filename, int _mode, const QString &encoding, bool _undoAction )
 {
   QFileInfo info(_filename);
 
   if(info.isDir())
   {
-     KMessageBox::sorry(this, i18n("You have specified a directory"));
+     KMessageBox::sorry(this, i18n("You have specified a folder"));
      return KEDIT_RETRY;
   }
 
@@ -1153,119 +1079,29 @@ int TopLevel::openFile( const QString& _filename, int _mode, const QString &enco
 
   eframe->insertText( &stream );
   eframe->setModified(false);
-  if ( ! _undoAction )
+
+  if ( !_undoAction)
       eframe->setUndoRedoEnabled(true);
 
   return KEDIT_OK;
 
 }
 
-static int
-write_all(int fd, const char *buf, size_t len)
-{
-   while (len > 0)
-   {
-      int written = write(fd, buf, len);
-      if (written < 0)
-      {
-          if (errno == EINTR)
-             continue;
-          return -1;
-      }
-      buf += written;
-      len -= written;
-   }
-   return 0;
-}
-
-static bool backupFile( const QString &qFilename)
-{
-   QCString cFilename = QFile::encodeName(qFilename);
-   QCString cBackup =cFilename + "~";
-   const char *filename = cFilename.data();
-   const char *backup = cBackup.data();
-
-   int fd = open( filename, O_RDONLY);
-   if (fd < 0)
-      return false;
-
-   struct stat buff;
-   if ( fstat( fd, &buff) < 0 )
-   {
-      close( fd );
-      return false;
-   }
-
-   int permissions = buff.st_mode & 07777;
-
-   if ( stat( backup, &buff) == 0)
-   {
-      if ( unlink( backup ) != 0 )
-      {
-         close(fd);
-         return false;
-      }
-   }
-
-
-   mode_t old_umask = umask(0);
-   int fd2 = open( backup, O_WRONLY | O_CREAT | O_EXCL, permissions | S_IWUSR);
-   umask(old_umask);
-
-   if ( fd2 < 0 )
-   {
-      close(fd);
-      return false;
-   }
-
-    char buffer[ 32*1024 ];
-
-    while( 1 )
-    {
-       int n = ::read( fd, buffer, 32*1024 );
-       if (n == -1)
-       {
-          if (errno == EINTR)
-              continue;
-          close(fd);
-          close(fd2);
-          return false;
-       }
-       if (n == 0)
-          break; // Finished
-
-       if (write_all( fd2, buffer, n))
-       {
-          close(fd);
-          close(fd2);
-          return false;
-       }
-    }
-
-    close( fd );
-
-    if (close(fd2))
-    {
-        return false;
-    }
-    return true;
-}
-
 
 int TopLevel::saveFile( const QString& _filename, bool backup, const QString& encoding )
 {
   QFileInfo info(_filename);
-  bool bSoftWrap = (mOptionState.misc.wrapMode == SMiscState::softWrap);
+  bool bSoftWrap = (Prefs::wrapMode() == Prefs::EnumWrapMode::SoftWrap);
 
   if(info.isDir())
   {
-     KMessageBox::sorry(this, i18n("You have specified a directory"));
+     KMessageBox::sorry(this, i18n("You have specified a folder"));
      return KEDIT_RETRY;
   }
 
-  if (backup && mOptionState.misc.backupCheck && QFile::exists(_filename))
+  if (backup && Prefs::backupCopies() && QFile::exists(_filename))
   {
-     if (!backupFile(_filename))
+     if (!KSaveFile::backupFile(_filename))
      {
         KMessageBox::sorry(this, i18n("Unable to make a backup of the original file."));
      }
@@ -1305,7 +1141,7 @@ int TopLevel::saveFile( const QString& _filename, bool backup, const QString& en
 
 void TopLevel::openURL( const KURL& _url, int _mode )
 {
-    if ( _url.isMalformed() )
+    if ( !_url.isValid() )
     {
         QString string;
         string = i18n( "Malformed URL\n%1").arg(_url.url());
@@ -1316,9 +1152,9 @@ void TopLevel::openURL( const KURL& _url, int _mode )
 
     QString target;
     int result = KEDIT_OK;
-    if (KIO::NetAccess::download(_url, target))
+    if (KIO::NetAccess::download(_url, target, this))
     {
-       result = openFile(target, _mode, _url.fileEncoding());
+        result = openFile(target, _mode, _url.fileEncoding());
     }
     else
     {
@@ -1345,26 +1181,25 @@ void TopLevel::urlDrop_slot(QDropEvent* e) {
 
 void TopLevel::dragEnterEvent(QDragEnterEvent* e)
 {
-  e->accept(QUriDrag::canDecode(e));
+  e->accept(KURLDrag::canDecode(e));
 }
 
 void TopLevel::dropEvent(QDropEvent* e)
 {
 
-    QStrList list;
+    KURL::List list;
 
     // This should never happen, but anyway...
-    if(!QUriDrag::decode(e, list))
+    if(!KURLDrag::decode(e, list))
         return;
 
-    char *s;
-
-    for ( s = list.first(); s != 0L; s = list.next() )
+    bool first = true;
+    for ( KURL::List::ConstIterator it = list.begin(); it != list.end(); ++it)
     {
 	// Load the first file in this window
-	if ( s == list.getFirst() && !eframe->isModified() )
+	if ( first && !eframe->isModified() )
 	{
-            openURL( KURL(s), OPEN_READWRITE );
+            openURL( *it, OPEN_READWRITE );
 	}
 	else
 	{
@@ -1372,9 +1207,10 @@ void TopLevel::dropEvent(QDropEvent* e)
 	    TopLevel *t = new TopLevel ();
 	    t->show ();
 	    setGeneralStatusField(i18n("New Window Created"));
-		t->openURL( KURL(s), OPEN_READWRITE );
+	    t->openURL( *it, OPEN_READWRITE );
 	    setGeneralStatusField(i18n("Load Command Done"));
 	}
+	first = false;
     }
 }
 
@@ -1385,17 +1221,16 @@ void TopLevel::timer_slot(){
 }
 
 
-
 void TopLevel::set_colors()
 {
   QPalette mypalette = (eframe->palette()).copy();
 
   QColorGroup ncgrp( mypalette.active() );
 
-  if (mOptionState.color.custom)
+  if (Prefs::customColor())
   {
-     ncgrp.setColor(QColorGroup::Text, mOptionState.color.textFg);
-     ncgrp.setColor(QColorGroup::Base, mOptionState.color.textBg);
+     ncgrp.setColor(QColorGroup::Text, Prefs::textColor());
+     ncgrp.setColor(QColorGroup::Base, Prefs::backgroundColor());
   }
   else
   {
@@ -1411,98 +1246,15 @@ void TopLevel::set_colors()
 }
 
 
-void TopLevel::readSettings( void )
+void TopLevel::updateSettings( void )
 {
-  //
-  // Default settings. The values in mOptionState is defined in
-  // optionstate.h
-  //
-
-  QString str;
-  config = kapp->config();
-
-  config->setGroup( "Text Font" );
-  mOptionState.font.font = config->readFontEntry("KEditFont",
-    &mOptionState.font.font);
-
-  recent->loadEntries( config );
-  config->setGroup("General Options");
-
-  mOptionState.misc.mailCommand = config->readEntry("MailCmd",
-    mOptionState.misc.mailCommand );
-
-  str = config->readEntry("WrapMode");
-  if( str.isNull() == false )
-    mOptionState.misc.wrapMode = str.toInt();
-
-  str = config->readEntry("WrapColumn");
-  if( str.isNull() == false )
-    mOptionState.misc.wrapColumn = str.toInt();
-
-  str = config->readEntry("BackupCopies");
-  if( str.isNull() == false )
-    mOptionState.misc.backupCheck = (bool) str.toInt();
-
-  mOptionState.color.custom = config->readBoolEntry( "CustomColor",
-	mOptionState.color.custom );
-
-  str = config->readEntry( "ForeColor" );
-  if( str.isNull() == false )
-    mOptionState.color.textFg.setNamedColor( str );
-
-  str = config->readEntry( "BackColor" );
-  if( str.isNull() == false )
-    mOptionState.color.textBg.setNamedColor( str );
-
-  ///////////////////////////////////////////////////
-
-  config->setGroup("MainWindow");
-  applyMainWindowSettings(config);
-  statusbarAction->setChecked(!statusBar()->isHidden());
-  toolbarAction->setChecked(!toolBar()->isHidden());
-
-  ///////////////////////////////////////////////////
+  readSettings();
+  setupEditWidget();
 }
 
-void TopLevel::writeSettings( void )
+void TopLevel::readSettings( void )
 {
-  config = kapp->config();
-
-  config->setGroup( "Text Font" );
-  config->writeEntry("KEditFont", mOptionState.font.font );
-
-  recent->saveEntries( config );
-
-  config->setGroup("MainWindow");
-  saveMainWindowSettings(config);
-
-  config->setGroup("General Options");
-  config->writeEntry("MailCmd", mOptionState.misc.mailCommand );
-
-  QString string;
-  string.setNum( mOptionState.misc.wrapMode );
-  config->writeEntry("WrapMode", string);
-
-  string.setNum( mOptionState.misc.wrapColumn );
-  config->writeEntry("WrapColumn", string);
-
-  string="";
-  string.setNum( (int) mOptionState.misc.backupCheck );
-  config->writeEntry("BackupCopies", string);
-
-  config->writeEntry("CustomColor", mOptionState.color.custom);
-
-  QColor &fg = mOptionState.color.textFg;
-  string.sprintf("#%02x%02x%02x", fg.red(), fg.green(), fg.blue() );
-  config->writeEntry( "ForeColor", string );
-
-  QColor &bg = mOptionState.color.textBg;
-  string.sprintf("#%02x%02x%02x", bg.red(),bg.green(), bg.blue());
-  config->writeEntry( "BackColor", string );
-
-  ////////////////////////////////////////////////////
-
-  config->sync();
+  recent->loadEntries( kapp->config() );
 }
 
 
@@ -1517,16 +1269,16 @@ void TopLevel::toggle_overwrite(){
 
 }
 
-static const char *description=I18N_NOOP("A KDE Text Editor");
+static const char description[] = I18N_NOOP("A KDE Text Editor");
 
 static const KCmdLineOptions options[] =
 {
 	{ "encoding <encoding>", I18N_NOOP("Encoding to use for the following documents"), 0 },
 	{ "+file", I18N_NOOP("File or URL to Open"), 0 },
-	{ 0, 0, 0}
+	KCmdLineLastOption
 };
 
-int main (int argc, char **argv)
+extern "C" int kdemain (int argc, char **argv)
 {
 	bool have_top_window = false;
 
@@ -1539,11 +1291,9 @@ int main (int argc, char **argv)
 
 	KApplication a;
 	//CT KIO::Job::initStatic();
-
 	if ( a.isRestored() )
 	{
 		int n = 1;
-
 		while (TopLevel::canBeRestored(n))
 		{
 			TopLevel *tl = new TopLevel();
@@ -1586,8 +1336,61 @@ int main (int argc, char **argv)
 	return a.exec ();
 }
 
+SettingsDialog::SettingsDialog(QWidget *parent, const char *name,KConfigSkeleton *config, KSpellConfig *_spellConfig)
+ : KConfigDialog(parent, name, config),
+ spellConfig(_spellConfig), spellConfigChanged(false)
+{
+  // Font
+  QWidget *font = new QWidget(0, "FontSetting");
+  QVBoxLayout *topLayout = new QVBoxLayout(font, 0, KDialog::spacingHint());
+  KFontChooser *mFontChooser = new KFontChooser(font, "kcfg_Font", false, QStringList(), false, 6);
+  topLayout->addWidget(mFontChooser);
+  addPage(font, i18n("Font"), "fonts", i18n("Editor Font"));
 
+  // Color
+  Color *color = new Color(0, "ColorSettings");
+  addPage(color, i18n("Color"), "colorize", i18n("Text Color in Editor Area"));
 
+  // Spelling
+  addPage(spellConfig, i18n("Spelling"),
+  	  "spellcheck", i18n("Spelling Checker"));
+  connect(spellConfig, SIGNAL(configChanged()), this, SLOT(slotSpellConfigChanged()));
+
+  // Miscellaneous
+  Misc *miscOptions = new Misc(0, "MiscSettings");
+  addPage(miscOptions, i18n("Miscellaneous"), "misc");
+}
+
+void SettingsDialog::updateSettings()
+{
+  spellConfig->writeGlobalSettings();
+}
+
+void SettingsDialog::updateWidgets()
+{
+  spellConfig->readGlobalSettings();
+  spellConfigChanged = false;
+}
+
+void SettingsDialog::updateWidgetsDefault()
+{
+}
+
+bool SettingsDialog::hasChanged()
+{
+  return spellConfigChanged;
+}
+
+bool SettingsDialog::isDefault()
+{
+  return true;
+}
+
+void SettingsDialog::slotSpellConfigChanged()
+{
+  spellConfigChanged = true;
+  updateButtons();
+}
 
 #include "kedit.moc"
 
