@@ -1,6 +1,6 @@
 /*
 
-    $Id: kedit.h,v 1.62.2.1 2003/07/25 14:48:01 mlaurent Exp $
+    $Id: kedit.h,v 1.73 2003/12/08 19:56:51 mueller Exp $
 
     Copyright (C) 1997 Bernd Johannes Wuebben
                        wuebben@math.cornell.edu
@@ -17,34 +17,27 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
     */
 
 #ifndef _KEDIT_H_
 #define _KEDIT_H_
 
-#include <qstring.h>
-#include <qptrlist.h>
-#include <qstringlist.h>
 #include <qtextcodec.h>
 #include <qptrdict.h>
 
-#include "optionstate.h"
 #include "version.h"
 
 #include <kmainwindow.h>
-#include <keditcl.h>
-#include <kurl.h>
-#include <kaction.h>
-#include <kstdaction.h>
 
-class COptionDialog;
+class KEdit;
 class KSpell;
+class KSpellConfig;
 class QTimer;
+class KAction;
 class KRecentFilesAction;
-class KToggleAction;
-class KURL;
+
 namespace KIO { class Job; }
 
 // StatusBar field IDs
@@ -76,7 +69,7 @@ public:
      *
      * @return KEDIT_OK on success
      */
-    int openFile( const QString& _filename, int _mode, const QString &encoding,  bool _undoAction = false );
+    int openFile( const QString& _filename, int _mode, const QString &encoding, bool _undoAction = false );
 
     /**
      * Saves the edit widget to a file.
@@ -99,7 +92,7 @@ public:
     int saveURL( const KURL& _url );
 
     /**
-     * Only show the window when the following load action is succesfull.
+     * Only show the window when the following load action is successful.
      **/
     void setNewWindow() { newWindow = true; }
 
@@ -117,13 +110,14 @@ public:
 
 protected:
     void setSensitivity();
-
-    void readSettings();
     void setupEditWidget();
     void setupStatusBar();
     void setupActions();
+    void initSpellConfig();
 
 private:
+    KSpellConfig *kspellconfigOptions;
+    
 public:  // Should not be!
     KEdit *eframe;
 private:
@@ -134,8 +128,6 @@ private:
     int statusID, toolID, indentID;
     QTimer *statusbar_timer;
     KRecentFilesAction *recent;
-    KToggleAction *statusbarAction;
-    KToggleAction *toolbarAction;
     KAction *cutAction;
     KAction *copyAction;
     KAction *undoAction;
@@ -143,8 +135,6 @@ private:
 
     int open_mode;
 
-    SOptionState mOptionState;
-
     KConfig *config;
 
     KSpell *kspell; // Current spell checking object
@@ -161,11 +151,8 @@ private:
     void saveProperties(KConfig*);
     void readProperties(KConfig*);
 
-    COptionDialog *mOptionDialog;
-
 public slots:
     void openRecent(const KURL&);
-    void set_colors();
     void gotoLine();
     void mail();
     void setGeneralStatusField(const QString &string);
@@ -179,7 +166,6 @@ public slots:
     void select_all();
     void clean_space();
     void timer_slot();
-    void save_options();
     void file_open();
     void file_new();
     void file_insert();
@@ -191,11 +177,8 @@ public slots:
     void helpselected();
     void search();
     void replace();
-    void toggleStatusBar();
-    void toggleToolBar();
     void search_again();
     void toggle_overwrite();
-    void writeSettings();
 
     void spellcheck();
     void spell_started ( KSpell *);
@@ -205,20 +188,44 @@ public slots:
 
     void urlDrop_slot(QDropEvent* e);
 
+    void set_colors();
+
 protected:
     /// Drag and Drop
     void dragEnterEvent(QDragEnterEvent* e);
     void dropEvent(QDropEvent* e);
 
 private slots:
-      void customize( void );
-      void setFontOption( const SFontState &font );
-      void setColorOption( const SColorState &color );
-      void setSpellOption( const SSpellState &spell );
-      void setMiscOption( const SMiscState &misc );
-      void editKeys();
-      void editToolbars();
+    void updateSettings();
+    void readSettings();
+    void showSettings();
+    void editKeys();
+    void editToolbars();
     void slotSelectionChanged();
+    void slotNewToolbarConfig();
 };
 
+class SettingsDialog: public KConfigDialog {
+Q_OBJECT
+
+public:
+  SettingsDialog(QWidget *parent, const char *name,KConfigSkeleton *config, KSpellConfig *_spellConfig);
+  
+protected slots:
+  void updateSettings();
+  void updateWidgets();
+  void updateWidgetsDefault();
+  void slotSpellConfigChanged();
+  
+protected:
+  bool hasChanged();
+  bool isDefault();
+
+private:
+  KSpellConfig *spellConfig;  
+  bool spellConfigChanged;
+};
+
+
 #endif
+
