@@ -1,8 +1,5 @@
-
 /*
-
-    $Id: floppy.cpp,v 1.56 2002/07/20 12:15:40 lukas Exp $
-
+    KFloppy
     Copyright (C) 1997 Bernd Johannes Wuebben
                        wuebben@math.cornell.edu
 
@@ -19,27 +16,39 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
     */
 
 
-#include "floppy.h"
-#include "floppy.moc"
-
-#include <iostream.h>
 #include <qlayout.h>
+#include <qcheckbox.h>
+#include <qlineedit.h>
+#include <qlabel.h>
+#include <qcursor.h>
+#include <qradiobutton.h>
+#include <qbuttongroup.h>
+#include <qcombobox.h>
+
+#include <kconfig.h>
 
-#include <kapplication.h>
-#include <kstandarddirs.h>
 #include <kmessagebox.h>
 #include <kdebug.h>
+#include <khelpmenu.h>
+#include <kpushbutton.h>
+#include <kpopupmenu.h>
+#include <kapplication.h>
+#include <kprogress.h>
+#include <klocale.h>
+
+#include "floppy.moc"
+#include "format.h"
 
 FloppyData::FloppyData(QWidget * parent, const char * name)
- : KDialog( parent, name )
+ : KDialog( parent, name ),
+	formatActions(0L)
 {
 
-        proc = 0L;
 	formating = false;
 	quickerase = false;
 	abort = false;
@@ -61,7 +70,7 @@ FloppyData::FloppyData(QWidget * parent, const char * name)
         g1->addWidget( label1, 0, 0, AlignLeft );
 
 
-	deviceComboBox = new QComboBox( FALSE, this, "ComboBox_1" );
+	deviceComboBox = new QComboBox( false, this, "ComboBox_1" );
 	g1->addWidget( deviceComboBox, 0, 1, AlignLeft );
 
 	deviceComboBox->insertItem(i18n("Primary"));
@@ -71,7 +80,7 @@ FloppyData::FloppyData(QWidget * parent, const char * name)
 	label2->setText(i18n("Size:"));
         g1->addWidget( label2, 1, 0, AlignLeft );
 
-	densityComboBox = new QComboBox( FALSE, this, "ComboBox_1" );
+	densityComboBox = new QComboBox( false, this, "ComboBox_1" );
 	g1->addWidget( densityComboBox, 1, 1, AlignLeft );
 
 	densityComboBox->insertItem(i18n("3.5\" 1.44MB"));
@@ -84,11 +93,16 @@ FloppyData::FloppyData(QWidget * parent, const char * name)
 	label3->setText(i18n("File system:"));
         g1->addWidget( label3, 2, 0, AlignLeft );
 
-	filesystemComboBox = new QComboBox( FALSE, this, "ComboBox_2" );
+	filesystemComboBox = new QComboBox( false, this, "ComboBox_2" );
 	g1->addWidget( filesystemComboBox, 2, 1, AlignLeft );
 
 	filesystemComboBox->insertItem(i18n("DOS"));
+#ifdef ANY_LINUX
 	filesystemComboBox->insertItem(i18n("ext2"));
+#endif
+#ifdef ANY_BSD
+	filesystemComboBox->insertItem(i18n("UFS"));
+#endif
 
         v1->addSpacing( 10 );
 
@@ -104,17 +118,17 @@ FloppyData::FloppyData(QWidget * parent, const char * name)
 
 	fullformat = new QRadioButton( buttongroup, "RadioButton_3" );
 	fullformat->setText(i18n( "Fu&ll format") );
-	fullformat->setChecked(TRUE);
+	fullformat->setChecked(true);
         v2->addWidget( fullformat, AlignLeft );
 
 	verifylabel = new QCheckBox( buttongroup, "RadioButton_4" );
 	verifylabel->setText(i18n( "&Verify integrity" ));
-	verifylabel->setChecked(TRUE);
+	verifylabel->setChecked(true);
 	v2->addWidget( verifylabel, AlignLeft );
 
 	labellabel = new QCheckBox( buttongroup, "RadioButton_4" );
 	labellabel->setText(i18n( "Volume &label:") );
-	labellabel->setChecked(TRUE);
+	labellabel->setChecked(true);
         v2->addWidget( labellabel, AlignLeft );
 
         QHBoxLayout* h2 = new QHBoxLayout( v2 );
@@ -132,7 +146,7 @@ FloppyData::FloppyData(QWidget * parent, const char * name)
 
 	formatbutton = new KPushButton( this, "PushButton_3" );
 	formatbutton->setText(i18n( "&Format") );
-	formatbutton->setAutoRepeat( FALSE );
+	formatbutton->setAutoRepeat( false );
 	connect(formatbutton,SIGNAL(clicked()),this,SLOT(format()));
         v3->addWidget( formatbutton );
 
@@ -142,12 +156,12 @@ FloppyData::FloppyData(QWidget * parent, const char * name)
 	helpMenu = new KHelpMenu(this, KGlobal::instance()->aboutData(), false);
 
 	helpbutton = new KPushButton( KStdGuiItem::help(), this );
-	helpbutton->setAutoRepeat( FALSE );
+	helpbutton->setAutoRepeat( false );
 	helpbutton->setPopup(helpMenu->menu());
 	v3->addWidget( helpbutton );
 
-	quitbutton = new KPushButton( KGuiItem( i18n( "&Quit" ), "exit" ), this );
-	quitbutton->setAutoRepeat( FALSE );
+	quitbutton = new KPushButton( KStdGuiItem::quit(), this );
+	quitbutton->setAutoRepeat( false );
 	connect(quitbutton,SIGNAL(clicked()),this,SLOT(quit()));
 	 v3->addWidget( quitbutton );
 
@@ -163,15 +177,6 @@ FloppyData::FloppyData(QWidget * parent, const char * name)
         progress->setMinimumHeight( 30 );
         ml->addWidget( progress );
 
-	mytimer = new QTimer;
-	connect(mytimer,SIGNAL(timeout()),this,SLOT(cf2done()));
-
-	fserrtimer = new QTimer;
-	connect(fserrtimer,SIGNAL(timeout()),this,SLOT(fserrslot()));
-
-	errtimer = new QTimer;
-	connect(errtimer,SIGNAL(timeout()),this,SLOT(errslot()));
-
 	readSettings();
 	setWidgets();
 
@@ -183,23 +188,23 @@ FloppyData::FloppyData(QWidget * parent, const char * name)
     deviceComboBox->setMinimumWidth( maxW );
     densityComboBox->setMinimumWidth( maxW );
     filesystemComboBox->setMinimumWidth( maxW );
+
+    setMinimumSize(minimumSizeHint());
 }
 
 
 FloppyData::~FloppyData()
 {
-  delete mytimer;
-  delete fserrtimer;
-  delete errtimer;
+  delete formatActions;
 }
 
-void FloppyData::closeEvent(QCloseEvent*){
-
+void FloppyData::closeEvent(QCloseEvent*)
+{
   quit();
-
 }
 
-void FloppyData::keyPressEvent(QKeyEvent *e) {
+void FloppyData::keyPressEvent(QKeyEvent *e)
+{
 	switch(e->key()) {
 	case Qt::Key_F1:
 		kapp->invokeHelp();
@@ -215,155 +220,125 @@ void FloppyData::show() {
   KDialog::show();
 }
 
-
 bool FloppyData::findDevice()
 {
-  if( deviceComboBox->currentText() == i18n("Primary") ){
-    if( densityComboBox->currentText() == i18n("3.5\" 1.44MB")){
-      device = "/dev/fd0H1440";
-      blocks = 1440;
-      tracks = 80;
-      if( access(QFile::encodeName(device),W_OK) < 0){
-	device = "/dev/fd0u1440";
-      }
-    }
-    else
-    if( densityComboBox->currentText() == i18n("3.5\" 720KB")){
-      device = "/dev/fd0D720";
-      blocks = 720;
-      tracks = 80;
-      if( access(QFile::encodeName(device),W_OK) < 0){
-	device = "/dev/fd0u720";
-      }
-    }
-    else
-    if( densityComboBox->currentText() == i18n("5.25\" 1.2MB")){
-      device = "/dev/fd0h1200";
-      blocks = 720;
-      tracks = 80;
-      }
-    else
-    if( densityComboBox->currentText() == i18n("5.25\" 360KB")){
-      device = "/dev/fd0h360";
-      blocks = 720;
-      tracks = 80;
-      }
-    }
-  if( deviceComboBox->currentText() == i18n("Secondary") ){
-    if( densityComboBox->currentText() == i18n("3.5\" 1.44MB")){
-      device = "/dev/fd1H1440";
-      blocks = 1440;
-      tracks = 80;
-      if( access(QFile::encodeName(device),W_OK) < 0){
-	device = "/dev/fd1u1440";
-      }
-    }
-    else
-    if( densityComboBox->currentText() == i18n("3.5\" 720KB")){
-      device = "/dev/fd1D720";
-      blocks = 720;
-      tracks = 80;
-      if( access(QFile::encodeName(device),W_OK) < 0){
-	device = "/dev/fd1u720";
-      }
-    }
-    else
-    if( densityComboBox->currentText() == i18n("5.25\" 1.2MB")){
-      device = "/dev/fd1h1200";
-      blocks = 720;
-      tracks = 80;
-      }
-    else
-    if( densityComboBox->currentText() == i18n("5.25\" 360KB")){
-      device = "/dev/fd1h360";
-      blocks = 720;
-      tracks = 80;
-      }
-    }
-
-  if( access(QFile::encodeName(device),W_OK) < 0){
-
-    QString str = i18n(
-	      "Cannot access %1\nMake sure that the device exists and that "
-	      "you have write permission to it.").arg(device);
-    KMessageBox::error(this, str);
-
-    //formatbutton->setEnabled(FALSE);
-    return false;
-
+  drive=-1;
+  if( deviceComboBox->currentText() == i18n("Primary") )
+  {
+    drive=0;
+  }
+  if( deviceComboBox->currentText() == i18n("Secondary") )
+  {
+    drive=1;
   }
 
+  blocks=-1;
+
+    if( densityComboBox->currentText() == i18n("3.5\" 1.44MB")){
+      blocks = 1440;
+    }
+    else
+    if( densityComboBox->currentText() == i18n("3.5\" 720KB")){
+      blocks = 720;
+    }
+    else
+    if( densityComboBox->currentText() == i18n("5.25\" 1.2MB")){
+      blocks = 1200;
+      }
+    else
+    if( densityComboBox->currentText() == i18n("5.25\" 360KB")){
+      blocks = 360;
+      }
+
+
   return true;
 }
 
+bool FloppyData::setInitialDevice(const QString& dev)
+{
+  int drive = -1;
+  if (dev.startsWith("/dev/fd0"))
+    drive = 0;
+  if (dev.startsWith("/dev/fd1"))
+    drive = 1;
+
+  bool ok = (drive>=0);
+  if (ok)
+    deviceComboBox->setCurrentItem(drive);
+  return ok;
+}
+
 
 void FloppyData::findExecutables()
 {
-  QString path = getenv("PATH");
-  path.append(":/usr/sbin:/sbin");
+	bool fruitful = true ;
+	fruitful &= FDFormat::runtimeCheck();
+	fruitful &= FATFilesystem::runtimeCheck();
+#ifdef ANY_BSD
+	fruitful &= UFSFilesystem::runtimeCheck();
+#else
+#ifdef ANY_LINUX
+	fruitful &= Ext2Filesystem::runtimeCheck();
+#else
+	fruitful = false;
+#endif
+#endif
 
-  fdformat = KGlobal::dirs()->findExe("fdformat", path);
-  mke2fs = KGlobal::dirs()->findExe("mke2fs", path);
-  mkdosfs = KGlobal::dirs()->findExe("mkdosfs", path);
-  QString str = "";
-  if (fdformat.isEmpty()) {
-    str = i18n("Cannot find fdformat.");
-  }
-
-  if (mke2fs.isEmpty()) {
-    str = i18n("Cannot find mke2fs");
-  }
-
-  if (mkdosfs.isEmpty()) {
-    str = i18n("Cannot find mkdosfs");
-  }
-
-  if (str != "") {
-    formatbutton->setEnabled(FALSE);
-    KMessageBox::error(this, str);
+  if (!fruitful) {
+    formatbutton->setEnabled(false);
+    KMessageBox::error(this,
+    	i18n("KFloppy cannot find the support programs needed "
+		"for sensible operation."));
   }
 }
 
 void FloppyData::quit(){
-
-  if(proc){
-    if(proc->isRunning())
-      proc->kill();
-    
-  }
+  if (formatActions) formatActions->quit();
   writeSettings();
   kapp->quit();
   delete this;
 }
 
-void FloppyData::reset(){
+void FloppyData::setEnabled(bool b)
+{
+  if (b)
+	unsetCursor();
+  else
+	setCursor(QCursor(WaitCursor));
+  label1->setEnabled(b);
+  deviceComboBox->setEnabled(b);
+  label2->setEnabled(b);
+  densityComboBox->setEnabled(b);
+  label3->setEnabled(b);
+  filesystemComboBox->setEnabled(b);
+  buttongroup->setEnabled(b);
+  quick->setEnabled(b);
+  fullformat->setEnabled(b);
+  verifylabel->setEnabled(b);
+  labellabel->setEnabled(b);
+  lineedit->setEnabled(b);
+  helpbutton->setEnabled(b);
+  quitbutton->setEnabled(b);
+  formatbutton->setEnabled(b);
+}
 
+void FloppyData::reset()
+{
+  DEBUGSETUP;
 
   formating = false;
   quickerase = false;
 
-  if(proc){
-    if(proc->isRunning())
-      proc->kill();
+  if (formatActions)
+  {
+    formatActions->quit();
+    delete formatActions;
+    formatActions = 0L;
   }
-  proc = 0L;
+
   progress->setValue(0);
-  frame->clear();
   formatbutton->setText(i18n("&Format"));
-  label1->setEnabled(true);
-  deviceComboBox->setEnabled(true);
-  label2->setEnabled(true);
-  densityComboBox->setEnabled(true);
-  label3->setEnabled(true);
-  filesystemComboBox->setEnabled(true);
-  buttongroup->setEnabled(true);
-  quick->setEnabled(true);
-  fullformat->setEnabled(true);
-  verifylabel->setEnabled(true);
-  labellabel->setEnabled(true);
-  lineedit->setEnabled(true);
-  helpbutton->setEnabled(true);
-  quitbutton->setEnabled(true);
+  setEnabled(true);
 }
 
 void FloppyData::format(){
@@ -377,90 +352,102 @@ void FloppyData::format(){
     reset();
     return;
   }
-  if (!formating) {
-        if (KMessageBox::warningContinueCancel(0, i18n("Formatting will erase all data on the disk.\n"
-        "Are you sure you wish to proceed?"), i18n("Proceed?") ) == KMessageBox::Continue)
+
+  frame->clear();
+
+  if (KMessageBox::warningContinueCancel(0,
+   i18n("Formatting will erase all data on the disk.\n"
+        "Are you sure you wish to proceed?"), i18n("Proceed?") ) !=
+	KMessageBox::Continue)
         {
+	return;
+	}
 
-  formatbutton->setText(i18n("A&bort"));
-  label1->setEnabled(false);
-  deviceComboBox->setEnabled(false);
-  label2->setEnabled(false);
-  densityComboBox->setEnabled(false);
-  label3->setEnabled(false);
-  filesystemComboBox->setEnabled(false);
-  buttongroup->setEnabled(false);
-  quick->setEnabled(false);
-  fullformat->setEnabled(false);
-  verifylabel->setEnabled(false);
-  labellabel->setEnabled(false);
-  lineedit->setEnabled(false);
-  helpbutton->setEnabled(false);
-  quitbutton->setEnabled(false);
+  // formatbutton->setText(i18n("A&bort"));
+  setEnabled(false);
+
+	if (!findDevice())
+	{
+		reset();
+		return;
+	}
+
+	if (formatActions) delete formatActions;
+	formatActions = new KFActionQueue(this);
+
+	connect(formatActions,SIGNAL(status(const QString &,int)),
+		this,SLOT(formatStatus(const QString &,int)));
+	connect(formatActions,SIGNAL(done(KFAction *,bool)),
+		this,SLOT(reset()));
+
+	if (quick->isChecked())
+	{
+		quickerase=true;
+		formating=false;
+		// No fdformat to push
+	}
+	else
+	{
+		FDFormat *f = new FDFormat(this);
+		f->configureDevice(drive,blocks);
+		f->configure(verifylabel->isChecked());
+		formatActions->queue(f);
+	}
+
+	if (filesystemComboBox->currentItem() == 0)
+	{
+		FATFilesystem *f = new FATFilesystem(this);
+		connect(f,SIGNAL(status(const QString &,int)),
+			this,SLOT(formatStatus(const QString &,int)));
+		connect(f,SIGNAL(done(KFAction *,bool)),
+			this,SLOT(reset()));
+		f->configure(verifylabel->isChecked(),
+			labellabel->isChecked(),
+			lineedit->text());
+		f->configureDevice(drive,blocks);
+		formatActions->queue(f);
+	}
+	else if (filesystemComboBox->currentItem() == 1)
+	{
+		FloppyAction *f = 0L;
+#ifdef ANY_LINUX
+		Ext2Filesystem *e2f = new Ext2Filesystem(this);
+		e2f->configure(verifylabel->isChecked(),
+			labellabel->isChecked(),
+			lineedit->text());
+		f=e2f;
+#else
+#ifdef ANY_BSD
+		f = new UFSFilesystem(this);
+#endif
+#endif
+
+		if (f)
+		{
+			connect(f,SIGNAL(status(const QString &,int)),
+				this,SLOT(formatStatus(const QString &,int)));
+			connect(f,SIGNAL(done(KFAction *,bool)),
+				this,SLOT(reset()));
+			f->configureDevice(drive,blocks);
+			formatActions->queue(f);
+		}
+	}
 
 
 
-  if(!findDevice()){
-    reset();
-    return;
-  }
-
-  if(quick->isChecked()){
-    quickerase = true;
-    formating = false;
-    createfilesystem();
-    return;
-  }
-
-  frame->setText(i18n("Formatting..."));
-  badblocks = 0;
-  abort = false;
-  formating = true;
-  progress->setRange(0, tracks*2);
-  progress->setValue(0);
-  counter = 0;
-
-  proc = new KProcess;
-  *proc << fdformat;
-  if (!verifylabel->isChecked()) {
-    *proc << "-n";
-  }
-  *proc << device;
-
-  connect(proc, SIGNAL(processExited(KProcess *)),this, SLOT(formatdone(KProcess*)));
-
-  connect(proc, SIGNAL(receivedStdout(KProcess *,char*,int)),this,
-	  SLOT(readStdout(KProcess*,char*,int)));
-
-  connect(proc, SIGNAL(receivedStderr(KProcess *,char*,int)),this,
-	  SLOT(readStderr(KProcess*,char*,int)));
-
-  bool result = proc->start(KProcess::NotifyOnExit , KProcess::All);
-
-  if(!result){
-    QString str = i18n("Cannot start a new program: fork() failed.");
-    KMessageBox::error(this, str);
-    reset();
-  }
-}
-}
+	formatActions->exec();
 }
 
-void FloppyData::formatdone(KProcess*){
-
-  if(proc){
-    if(proc->isRunning())
-      proc->kill();
-  }
-
-  delete proc;
-  proc = 0L;
-
-  if(!abort)
-    createfilesystem();
+void FloppyData::formatStatus(const QString &s,int p)
+{
+	if (!s.isEmpty())
+		frame->setText(s);
 
+	if ((0<=p) && (p<=100))
+		progress->setValue(p);
 }
 
+#if 0
 void FloppyData::readStdout(KProcess *, char *buffer, int buflen)
 {
   bool increment = true;
@@ -485,7 +472,7 @@ void FloppyData::readStdout(KProcess *, char *buffer, int buflen)
   if (increment)
   {
     counter ++;
-    progress->setValue(counter);     
+    progress->setValue(counter);
   }
 
   kdDebug(2002) << "STDOUT: " << formatstring << endl;
@@ -526,13 +513,13 @@ void FloppyData::errslot(){
 		"have selected a valid floppy drive.");
 
     KMessageBox::error(this, str);
-    
+
     reset();
     return;
 
   }
 
-  QString str = i18n("Cannot format: %1\n%2").arg(device).arg(errstring);
+  QString str = i18n("Cannot format: %1\n%2").arg(drive).arg(errstring);
 
   KMessageBox::error(this, str);
 
@@ -554,10 +541,10 @@ void FloppyData::readfsStdout(KProcess *, char *buffer, int buflen){
   fsstring += mybuffer;
   if( fsstring.find('\n') == -1)
     return;
-  
+
   QString string ;
   QString newstring = fsstring;
-  
+
 
   int i;
 
@@ -593,12 +580,12 @@ void FloppyData::readfsStdout(KProcess *, char *buffer, int buflen){
     if(findKeyWord(fsstring,"EXIT"))
       counter ++;
 
-    
+
   }
 
   fsstring = newstring;
 
-  progress->setValue(counter);     
+  progress->setValue(counter);
 
   kdDebug(2002) << "STDOUT: " << mybuffer << endl;
 }
@@ -655,7 +642,7 @@ void FloppyData::fserrslot(){
  		"have selected a valid floppy drive.");
 
     KMessageBox::sorry(this, str);
-    
+
     reset();
     return;
   }
@@ -663,7 +650,7 @@ void FloppyData::fserrslot(){
   reset();
 
   QString str = i18n("Cannot create a filesystem on: %1\n%2")
-	      .arg(device).arg(fserrstring);
+	      .arg(drive).arg(fserrstring);
 
   KMessageBox::error(this, str);
 }
@@ -671,9 +658,7 @@ void FloppyData::fserrslot(){
 
 void FloppyData::cfdone(KProcess*){
 
-    delete proc;
-    proc = 0L;
-    mytimer->start(10,TRUE);
+    mytimer->start(10,true);
 
 }
 
@@ -684,9 +669,9 @@ void FloppyData::cf2done(){
   lcquick = quickerase;
 
   mytimer->stop();
-  
+
   reset();
-  
+
   if(abort)
     return;
 
@@ -715,7 +700,7 @@ int FloppyData::findKeyWord(QString & string,const QString & word){
 
   QString wordstring = word;
   len = wordstring.length();
-    
+
   while( (index = string.find(word)) >= 0)
   {
     count++;
@@ -724,58 +709,7 @@ int FloppyData::findKeyWord(QString & string,const QString & word){
 
   return count;
 }
-
-void FloppyData::createfilesystem()
-{
-  fsstring = "";
-  fserrstring = "";
-
-  frame->setText(i18n("Creating Filesystem..."));
-
-  proc = new KProcess;
-
-  if (filesystemComboBox->currentItem() == 0){
-
-        *proc << mkdosfs;
-	if(labellabel->isChecked())
-	  *proc << "-n" <<lineedit->text();
-        if (verifylabel->isChecked()) {
-          *proc << "-c";
-        }
-	*proc << device;
-  }
-  else{
-
-    *proc << mke2fs;
-    *proc << "-q";
-    if(labellabel->isChecked())
-      *proc << "-L" <<lineedit->text();
-    if (verifylabel->isChecked()) {
-      *proc << "-c";
-    }
-    *proc << device;
-  }
-
-
-
-  connect(proc, SIGNAL(processExited(KProcess *)),this, SLOT(cfdone(KProcess*)));
-
-  connect(proc, SIGNAL(receivedStdout(KProcess *,char*,int)),this, 
-	  SLOT(readfsStdout(KProcess*,char*,int)));
-
-  connect(proc, SIGNAL(receivedStderr(KProcess *,char*,int)),this, 
-	  SLOT(readfsStderr(KProcess*,char*,int)));
-
-  bool result = proc->start(KProcess::NotifyOnExit , KProcess::All);
-
-  if(!result){
-    QString str = i18n("Cannot start a new program\nfork() failed.");
-    KMessageBox::error(this, str);
-    frame->clear();
-    proc = 0L;
-    progress->setValue(0);
-  }
-}
+#endif
 
 void FloppyData::writeSettings(){
 
@@ -789,10 +723,7 @@ void FloppyData::writeSettings(){
 	driveconfig = deviceComboBox->currentText();
 	driveconfig = driveconfig.stripWhiteSpace();
 
-	if(quick->isChecked())
-	  quickformatconfig  = 1;
-	else
-	  quickformatconfig = 0;
+	quickformatconfig = quick->isChecked();
 
 	labelnameconfig = lineedit->text();
 	labelnameconfig = labelnameconfig.stripWhiteSpace();
@@ -831,29 +762,11 @@ void FloppyData::readSettings(){
 
 void FloppyData::setWidgets(){
 
-  if(labelconfig){
-    labellabel->setChecked(TRUE);
-  }
-  else{
+  labellabel->setChecked(labelconfig);
+  verifylabel->setChecked(verifyconfig);
+  quick->setChecked(quickformatconfig);
 
-    labellabel->setChecked(FALSE);
-  }
-
-  if(verifyconfig) {
-    verifylabel->setChecked(TRUE);
-  }
-  else {
-    verifylabel->setChecked(FALSE);
-  }
-
-  if(quickformatconfig){
-    quick->setChecked(TRUE);
-    fullformat->setChecked(FALSE);
-  }
-  else{
-    quick->setChecked(FALSE);
-    fullformat->setChecked(TRUE);
-  }
+  fullformat->setChecked(!quickformatconfig);
   lineedit->setText(labelnameconfig);
 
   for(int i = 0 ; i < deviceComboBox->count(); i++){
