@@ -1,7 +1,6 @@
     /*
 
-    $Id: floppy.h,v 1.20 2002/07/12 20:28:17 granroth Exp $
-
+    KFloppy
     Copyright (C) 1997 Bernd Johannes Wuebben   
                        wuebben@math.cornell.edu
 
@@ -18,37 +17,29 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
     */
 
 #ifndef FloppyData_included
 #define FloppyData_included
 
-#include <qbuttongroup.h>
-#include <qcombobox.h>
-#include <qframe.h>
-#include <qradiobutton.h>
-#include <qlabel.h>
-#include <qdialog.h>
-#include <qprogressbar.h> 
-#include <qtimer.h>
-#include <qfileinfo.h>
-#include <qcheckbox.h>
-#include <qlineedit.h>
-
-#include <stdlib.h>
-#include <string.h>
-
-#include <kprogress.h>
-#include <kprocess.h>
-#include <klocale.h>
-#include <kconfig.h>
-#include <kapplication.h>
 #include <kdialog.h>
-#include <khelpmenu.h>
-#include <kpopupmenu.h>
-#include <kpushbutton.h>
+
+class QCheckBox;
+class QLineEdit;
+class QLabel;
+class QRadioButton;
+class QComboBox;
+class QButtonGroup;
+class QGroupBox;
+
+class KProgress;
+class KConfig;
+class KPushButton;
+class KHelpMenu;
+class KFAction;
+class KFActionQueue;
 
 class FloppyData : public KDialog
 {
@@ -58,40 +49,51 @@ public:
     FloppyData(QWidget* parent = 0, const char * name = 0);
     virtual ~FloppyData();
 
-    void addDevice(const QString & name);
+    // Need to overload normal show() in order to mangle caption
     void show();
-    void addFileSystem(const QString & name);
-    void addDensity(const QString & name);
+    // Maps combobox selection to drive and density
     bool findDevice();
+    // set default device
+    bool setInitialDevice(const QString& dev);
+    // Startup check for nescessary executables
     void findExecutables();
+    // Override closeEvent() in order to properly close
+    // the entire application.    
     void closeEvent(QCloseEvent*);
+    // Reading and writing the user-visible settings.
     void writeSettings();
     void readSettings();
+    // Map stored settings to widget status
     void setWidgets();
+    // A kind of QString::find()
     int findKeyWord(QString &, const QString &);
+    // Enable/disable all UI elements
+    void setEnabled(bool);
     
 public slots:
-      void fserrslot();
-      void errslot();
+      // void fserrslot();
+      // void errslot();
+
       void quit();
       void format();
-      void createfilesystem();
       void reset();
 
-      void formatdone(KProcess* );
-      void readStdout(KProcess *proc, char *buffer, int buflen);
-      void readStderr(KProcess *proc, char *buffer, int buflen);
+      // void formatdone(KProcess* );
+      // void readStdout(KProcess *proc, char *buffer, int buflen);
+      // void readStderr(KProcess *proc, char *buffer, int buflen);
 
-      void cfdone(KProcess* );
-      void cf2done();
-      void readfsStdout(KProcess *proc, char *buffer, int buflen);
-      void readfsStderr(KProcess *proc, char *buffer, int buflen);
+      // void cfdone(KProcess* );
+      // void cf2done();
+      // void readfsStdout(KProcess *proc, char *buffer, int buflen);
+      // void readfsStderr(KProcess *proc, char *buffer, int buflen);
 
+      void formatStatus(const QString &,int);
+      
 protected slots:
 
 private:
 
-        QString fdformat, mke2fs, mkdosfs; 
+        // QString fdformat, mke2fs, mkdosfs; 
 
         int verifyconfig;
         int labelconfig;
@@ -103,24 +105,25 @@ private:
 	//QString mdev;
 	KConfig *config;
 
+	int drive;
+	int blocks;
+	
 	QString formatstring;
 	QString fsstring;
 	QString fserrstring;
 	QString errstring;
 	int badblocks;
-	int blocks;
 	int tracks;
 	bool quickerase;
 	bool formating;
 	bool abort;
         int counter;
-        bool ver_notified;
-	QString device;
-        KProcess*     proc;
-        QTimer*	      mytimer;
-	QTimer*	      fserrtimer;
-	QTimer*	      errtimer;
-        QGroupBox*       outerframe;
+        
+	// QTimer*	      mytimer;
+	// QTimer*	      fserrtimer;
+	// QTimer*	      errtimer;
+        
+	QGroupBox*       outerframe;
         QLabel*       label1;
         QLabel*       label2;        
 	QLabel*       label3;
@@ -139,6 +142,8 @@ private:
 	QComboBox* densityComboBox;
 	KProgress* progress;
 	KHelpMenu* helpMenu;
+	
+	KFActionQueue *formatActions;
 
 protected:
 	void keyPressEvent(QKeyEvent *e);
