@@ -1,7 +1,6 @@
     /*
 
-    $Id: main.cpp,v 1.13 2002/01/09 11:30:23 winkvist Exp $
-
+    KFloppy
     Requires the Qt widget libraries, available at no cost at 
     http://www.troll.no
        
@@ -21,7 +20,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
     */
 
@@ -32,31 +31,51 @@
 #include "floppy.h"
 
 
-static const char *description = 
+static const char description[] = 
 	I18N_NOOP("KDE Floppy Disk utility");
 
-static const char *version = "2.0";
+static const char version[] = "2.2";
+
+static const KCmdLineOptions options[] =
+{
+	{ "+[device]", I18N_NOOP("Default Device"), 0 },
+	KCmdLineLastOption
+};
 
 int main( int argc, char *argv[] )
 {
-  KAboutData aboutData("kfloppy", I18N_NOOP("KFloppy"),
+  KAboutData aboutData("kfloppy", 
+	I18N_NOOP("KFloppy"),
     version, description, KAboutData::License_GPL,
     "(c) 1997, Bernd Johannes Wuebben\n"
-    "(c) 2001, Chris Howells");
+    "(c) 2001, Chris Howells\n"
+    "(c) 2002, Adriaan de Groot",
+    I18N_NOOP("KFloppy helps you format removeable media (like floppy, Zip,\n"
+	"or LS120 disks) with the filesystem of your choice.")
+    );
+
   aboutData.addAuthor("Bernd Johannes Wuebben", I18N_NOOP("Author, Maintainer"), "wuebben@kde.org");
-  aboutData.addAuthor("Chris Howells", I18N_NOOP("User interface re-design"), "howells@kde.org");
+  aboutData.addCredit("Chris Howells", I18N_NOOP("User interface re-design"), "howells@kde.org");
+  aboutData.addCredit("Adriaan de Groot", I18N_NOOP("Add BSD support"), "groot@kde.org");
+
   KCmdLineArgs::init( argc, argv, &aboutData );
+  KCmdLineArgs::addCmdLineOptions( options );
+
+  KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+  QString device;
+  if (args->count()) {
+	device = args->arg(0);
+  }
+  args->clear();
 
   KApplication a;
 
   FloppyData* floppy  = new FloppyData();
-
-  a.setTopWidget(floppy);
+  a.setMainWidget(floppy);
+  bool autoformat = floppy->setInitialDevice(device);
   floppy->show();
-  a.exec();
-
-  return 0;
+  if (autoformat)
+	floppy->format();
+  return a.exec();
 }
 
-
-
