@@ -14,7 +14,7 @@
  *
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  */
 
@@ -66,10 +66,10 @@ void CValidateLineEdit::convertText( const QString &text )
 
 
 
-CConverterDialog::CConverterDialog( QWidget *parent, const char *name, 
+CConverterDialog::CConverterDialog( QWidget *parent, const char *name,
 				    bool modal )
-  :KDialogBase( parent, name, modal, i18n("Converter"), Cancel|User2|User1, 
-		Cancel, true, i18n("C&lear"), i18n("&On Cursor") )
+  :KDialogBase( parent, name, modal, i18n("Converter"), Cancel|User2|User1,
+		Cancel, true, KStdGuiItem::clear(), i18n("&On Cursor") )
 {
   QWidget *page = new QWidget( this );
   setMainWidget( page );
@@ -120,7 +120,7 @@ CConverterDialog::~CConverterDialog( void )
 }
 
 
-void CConverterDialog::showEvent( QShowEvent *e )  
+void CConverterDialog::showEvent( QShowEvent *e )
 {
   KDialogBase::showEvent(e);
   mHexInput->setFocus();
