@@ -14,7 +14,7 @@
  *
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  */
 
@@ -22,15 +22,16 @@
 #include <iostream>
 #include <limits.h>
 
-#include <qbuttongroup.h> 
-#include <qfileinfo.h> 
-#include <qlayout.h> 
-#include <qvalidator.h> 
+#include <qbuttongroup.h>
+#include <qfileinfo.h>
+#include <qlayout.h>
+#include <qvalidator.h>
 
 #include <kfiledialog.h>
 #include <klocale.h>
-#include <kmessagebox.h> 
+#include <kmessagebox.h>
 #include <kseparator.h>
+#include <kstdguiitem.h>
 
 #include "dialog.h"
 #include <qpushbutton.h>
@@ -53,7 +54,7 @@ CGotoDialog::CGotoDialog( QWidget *parent, const char *name, bool modal )
   mComboBox = new QComboBox( true, plainPage() );
   if( mComboBox == 0 ) { return; }
   mComboBox->setMaxCount( 10 );
-  mComboBox->setInsertionPolicy( QComboBox::AtTop );  
+  mComboBox->setInsertionPolicy( QComboBox::AtTop );
   mComboBox->setMinimumWidth( fontMetrics().maxWidth()*17 );
 
   QLabel *label = new QLabel( mComboBox, i18n("O&ffset:"), plainPage() );
@@ -139,7 +140,7 @@ void CGotoDialog::slotOk( void )
   // Skip any whitespaces in front of string
   //
   for( ; *p != 0 && isspace( *p ) ; p++ );
-  
+
   uint offset, bit;
   int match;
   if( strncmp( p, "0x", 2 ) == 0 || strncmp( p, "0X", 2 ) == 0 )
@@ -183,13 +184,13 @@ CFindDialog::CFindDialog( QWidget *parent, const char *name, bool modal )
   QVBoxLayout *vbox = new QVBoxLayout();
   if( vbox == 0 ) { return; }
   topLayout->addLayout( vbox );
-  
+
   mSelector = new QComboBox( false, plainPage() );
   if( mSelector == 0 ) { return; }
   mSelector->setMinimumWidth( fontMetrics().maxWidth()*17 );
   mSelector->insertStringList( formatStrings() );
   connect( mSelector, SIGNAL(activated(int)), SLOT(selectorChanged(int)) );
- 
+
   QLabel *label = new QLabel( mSelector, i18n("Fo&rmat:"), plainPage() );
   if( label == 0 ) { return; }
 
@@ -199,7 +200,7 @@ CFindDialog::CFindDialog( QWidget *parent, const char *name, bool modal )
   mInput = new QLineEdit( plainPage() );
   if( mInput == 0 ) { return; }
   mInput->setMinimumWidth( fontMetrics().maxWidth()*17 );
-  connect( mInput, SIGNAL(textChanged(const QString&)), 
+  connect( mInput, SIGNAL(textChanged(const QString&)),
 	   SLOT(inputChanged(const QString&)) );
   mFindValidator = new CHexValidator( this, CHexValidator::regularText );
   if( mFindValidator == 0 ) { return; }
@@ -229,7 +230,7 @@ CFindDialog::CFindDialog( QWidget *parent, const char *name, bool modal )
   gbox->addWidget( mCheckUseNavigator, 2, 1 );
   mCheckIgnoreCase = new QCheckBox( i18n("Ignore c&ase"),group);
   gbox->addWidget( mCheckIgnoreCase, 3, 0 );
-  gbox->setRowStretch( 4, 10 ); 
+  gbox->setRowStretch( 4, 10 );
 
   KConfig &config = *kapp->config();
   config.setGroup("Find Dialog");
@@ -270,7 +271,7 @@ void CFindDialog::selectorChanged( int index )
 void CFindDialog::inputChanged( const QString &text )
 {
   mFindString[ mSelector->currentItem() ] = text;
-  mFindValidator->convert( mFindData, 
+  mFindValidator->convert( mFindData,
     mFindString[ mSelector->currentItem() ] );
   enableButtonOK(!text.isEmpty());
 }
@@ -284,7 +285,7 @@ void CFindDialog::showEvent( QShowEvent *e )
 
 
 bool CFindDialog::isEmpty( void )
-{ 
+{
   return( mFindData.isEmpty() );
 }
 
@@ -303,14 +304,7 @@ void CFindDialog::slotOk( void )
   sc.fromCursor = mCheckFromCursor->isChecked();
   sc.inSelection = mCheckInSelection->isChecked();
   sc.forward = mCheckBackward->isChecked() == true ? false : true;
-  if( mCheckBackward->isEnabled() == true )
-  {
-    sc.ignoreCase = mCheckIgnoreCase->isChecked();
-  }
-  else
-  {
-    sc.ignoreCase = false;
-  }
+  sc.ignoreCase = mCheckIgnoreCase->isEnabled() && mCheckIgnoreCase->isChecked();
 
   hide();
   emit findData( sc, Find_First, mCheckUseNavigator->isChecked() );
@@ -329,6 +323,7 @@ void CFindDialog::findAgain( EOperation operation )
   sc.key = mFindData;
   sc.fromCursor = true;
   sc.inSelection = mCheckInSelection->isChecked();
+  sc.ignoreCase = mCheckIgnoreCase->isEnabled() && mCheckIgnoreCase->isChecked();
   if( operation == find_Next )
   {
     sc.forward = true;
@@ -367,7 +362,7 @@ CFindNavigatorDialog::CFindNavigatorDialog( QWidget *parent, const char *name,
   text = i18n("Searching for:");
   QLabel *label = new QLabel( text, plainPage() );
   hbox->addWidget( label );
- 
+
   mKey = new QLineEdit( plainPage() );
   mKey->setMinimumWidth( fontMetrics().width("M") * 20 );
   mKey->setFocusPolicy( QWidget::NoFocus );
@@ -442,13 +437,13 @@ void CFindNavigatorDialog::defineData( SSearchControl &sc )
 }
 
 
-void CFindNavigatorDialog::slotUser3( void ) // Previous 
+void CFindNavigatorDialog::slotUser3( void ) // Previous
 {
   done( repPrevious );
 }
 
 
-void CFindNavigatorDialog::slotUser2( void ) // Next 
+void CFindNavigatorDialog::slotUser2( void ) // Next
 {
   done( repNext );
 }
@@ -460,13 +455,13 @@ void CFindNavigatorDialog::slotUser1( void ) // New key
 }
 
 
-void CFindNavigatorDialog::slotClose( void ) 
+void CFindNavigatorDialog::slotClose( void )
 {
   done( repClose );
 }
 
 
-void CFindNavigatorDialog::done( int resultCode ) 
+void CFindNavigatorDialog::done( int resultCode )
 {
   setResult( resultCode );
   if( resultCode == repClose || resultCode == repNewKey )
@@ -487,7 +482,7 @@ void CFindNavigatorDialog::done( int resultCode )
 
 
 CReplaceDialog::CReplaceDialog( QWidget *parent, const char *name, bool modal )
-  :KDialogBase( Plain, i18n("Find and Replace"), Ok|Cancel, Ok,
+  :KDialogBase( Plain, i18n("Find & Replace"), Ok|Cancel, Ok,
 		parent, name, modal )
 {
   QString text;
@@ -503,9 +498,9 @@ CReplaceDialog::CReplaceDialog( QWidget *parent, const char *name, bool modal )
   if( mFindSelector == 0 ) { return; }
   mFindSelector->setMinimumWidth( fontMetrics().maxWidth()*17 );
   mFindSelector->insertStringList( formatStrings() );
-  connect( mFindSelector, SIGNAL(activated(int)), 
+  connect( mFindSelector, SIGNAL(activated(int)),
 	   SLOT(findSelectorChanged(int)) );
-  
+
   text = i18n("Fo&rmat (find):");
   QLabel *label = new QLabel( mFindSelector, text, plainPage() );
   if( label == 0 ) { return; }
@@ -519,7 +514,7 @@ CReplaceDialog::CReplaceDialog( QWidget *parent, const char *name, bool modal )
   mFindValidator = new CHexValidator( this, CHexValidator::regularText );
   if( mFindValidator == 0 ) { return; }
   mFindInput->setValidator( mFindValidator );
-  connect( mFindInput, SIGNAL(textChanged(const QString&)), 
+  connect( mFindInput, SIGNAL(textChanged(const QString&)),
 	   SLOT(findInputChanged(const QString&)) );
 
   label = new QLabel( mFindInput, i18n("F&ind:"), plainPage() );
@@ -532,7 +527,7 @@ CReplaceDialog::CReplaceDialog( QWidget *parent, const char *name, bool modal )
   if( mReplaceSelector == 0 ) { return; }
   mReplaceSelector->setMinimumWidth( fontMetrics().maxWidth()*17 );
   mReplaceSelector->insertStringList( formatStrings() );
-  connect( mReplaceSelector, SIGNAL(activated(int)), 
+  connect( mReplaceSelector, SIGNAL(activated(int)),
 	   SLOT(replaceSelectorChanged(int)) );
 
   text = i18n("For&mat (replace):");
@@ -549,7 +544,7 @@ CReplaceDialog::CReplaceDialog( QWidget *parent, const char *name, bool modal )
   mReplaceValidator = new CHexValidator( this, CHexValidator::regularText );
   if( mReplaceValidator == 0 ) { return; }
   mReplaceInput->setValidator( mReplaceValidator );
-  connect( mReplaceInput, SIGNAL(textChanged(const QString&)), 
+  connect( mReplaceInput, SIGNAL(textChanged(const QString&)),
 	   SLOT(replaceInputChanged(const QString&)) );
 
   label = new QLabel( mReplaceInput, i18n("Rep&lace:"), plainPage() );
@@ -576,7 +571,7 @@ CReplaceDialog::CReplaceDialog( QWidget *parent, const char *name, bool modal )
   gbox->addWidget( mCheckPrompt, 2, 1 );
   mCheckIgnoreCase = new QCheckBox( i18n("Ignore c&ase"), group );
   gbox->addWidget( mCheckIgnoreCase, 3, 0 );
-  gbox->setRowStretch( 4, 10 ); 
+  gbox->setRowStretch( 4, 10 );
 
   KConfig &config = *kapp->config();
   config.setGroup("Replace Dialog");
@@ -621,7 +616,7 @@ void CReplaceDialog::findSelectorChanged( int index )
 void CReplaceDialog::findInputChanged( const QString &text )
 {
   mFindString[ mFindSelector->currentItem() ] = text;
-  mFindValidator->convert( mFindData, 
+  mFindValidator->convert( mFindData,
     mFindString[ mFindSelector->currentItem() ] );
   enableButtonOK(!text.isEmpty());
 }
@@ -637,7 +632,7 @@ void CReplaceDialog::replaceSelectorChanged( int index )
 void CReplaceDialog::replaceInputChanged( const QString &text )
 {
   mReplaceString[ mReplaceSelector->currentItem() ] = text;
-  mReplaceValidator->convert( mReplaceData, 
+  mReplaceValidator->convert( mReplaceData,
     mReplaceString[ mReplaceSelector->currentItem() ] );
 }
 
@@ -672,23 +667,9 @@ void CReplaceDialog::slotOk( void )
   sc.inSelection = mCheckInSelection->isChecked();
   sc.forward = mCheckBackward->isChecked() == true ? false : true;
 
-  if( mCheckBackward->isEnabled() == true )
-  {
-    sc.ignoreCase = mCheckIgnoreCase->isChecked();
-  }
-  else
-  {
-    sc.ignoreCase = false;
-  }
+  sc.ignoreCase = mCheckIgnoreCase->isEnabled() && mCheckIgnoreCase->isChecked();
 
-  if( mCheckPrompt->isChecked() == true )
-  {
-    emit replaceData( sc, Replace_First );
-  }
-  else
-  {
-    emit replaceData( sc, Replace_AllInit );
-  }
+  emit replaceData( sc, mCheckPrompt->isChecked() ? Replace_First: Replace_AllInit );
 }
 
 
@@ -697,9 +678,9 @@ void CReplaceDialog::slotOk( void )
 
 CReplacePromptDialog::CReplacePromptDialog( QWidget *parent, const char *name,
 					     bool modal )
-  :KDialogBase( Plain, i18n("Find and Replace"), User3|User2|User1|Close,
-		User2, parent, name, modal, true, i18n("&All"), 
-		i18n("&No"), i18n("&Yes") )
+  :KDialogBase( Plain, i18n("Find & Replace"), User3|User2|User1|Close,
+		User2, parent, name, modal, true, i18n("&All"),
+		KStdGuiItem::no(), KStdGuiItem::yes() )
 {
   QString text;
   QBoxLayout *topLayout = new QVBoxLayout( plainPage(), 0, spacingHint() );
@@ -729,31 +710,31 @@ void CReplacePromptDialog::defineData( SSearchControl &sc )
 }
 
 
-void CReplacePromptDialog::slotUser3( void ) 
+void CReplacePromptDialog::slotUser3( void )
 {
   done( repYes );
 }
 
 
-void CReplacePromptDialog::slotUser2( void ) 
+void CReplacePromptDialog::slotUser2( void )
 {
   done( repNo );
 }
 
 
-void CReplacePromptDialog::slotUser1( void ) 
+void CReplacePromptDialog::slotUser1( void )
 {
   done( repAll );
 }
 
 
-void CReplacePromptDialog::slotClose( void ) 
+void CReplacePromptDialog::slotClose( void )
 {
   done( repClose );
 }
 
 
-void CReplacePromptDialog::done( int returnCode ) 
+void CReplacePromptDialog::done( int returnCode )
 {
   if( returnCode == repClose )
   {
@@ -793,7 +774,7 @@ CFilterDialog::CFilterDialog( QWidget *parent, const char *name, bool modal )
   if( mOperationSelector == 0 ) { return; }
   mOperationSelector->setMinimumWidth( fontMetrics().maxWidth()*17 );
   mOperationSelector->insertStringList( operationStrings() );
-  connect( mOperationSelector, SIGNAL(activated(int)), 
+  connect( mOperationSelector, SIGNAL(activated(int)),
 	   SLOT(operationSelectorChanged(int)) );
 
   text = i18n("O&peration:");
@@ -806,7 +787,7 @@ CFilterDialog::CFilterDialog( QWidget *parent, const char *name, bool modal )
   KSeparator *separator = new KSeparator( plainPage() );
   separator->setOrientation( QFrame::HLine );
   vbox->addWidget( separator );
- 
+
 
   mWidgetStack = new QWidgetStack( plainPage(), "pagestack" );
   if( mWidgetStack == 0 ) { return; }
@@ -868,7 +849,7 @@ void CFilterDialog::makeOperandLayout( void )
   mOperandSelector->setFixedHeight( mOperandSelector->sizeHint().height());
   mOperandSelector->setMinimumWidth( fontMetrics().width("M")*20 );
   mOperandSelector->insertStringList( formatStrings() );
-  connect( mOperandSelector, SIGNAL(activated(int)), 
+  connect( mOperandSelector, SIGNAL(activated(int)),
 	   SLOT(operandSelectorChanged(int)) );
 
   text = i18n("Fo&rmat (operand):");
@@ -918,7 +899,7 @@ void CFilterDialog::makeBitSwapLayout( void )
 
   QHBoxLayout *hbox = new QHBoxLayout( 0 );
   vbox->addLayout( hbox );
-  
+
   text = i18n("&Reset");
   QPushButton *resetButton = new QPushButton( text, page );
   resetButton->setFixedHeight( resetButton->sizeHint().height() );
@@ -943,12 +924,12 @@ void CFilterDialog::makeRotateLayout( void )
   mGroupSpin = new QSpinBox( page );
   if( mGroupSpin == 0 ) { return; }
   mGroupSpin->setMinimumWidth( fontMetrics().width("M")*20 );
-  mGroupSpin->setRange(1, INT_MAX );  
+  mGroupSpin->setRange(1, INT_MAX );
 
   text = i18n("&Group size [bytes]");
   QLabel *label = new QLabel( mGroupSpin, text, page );
   if( label == 0 ) { return; }
- 
+
   vbox->addWidget( label );
   vbox->addWidget( mGroupSpin );
 
@@ -960,7 +941,7 @@ void CFilterDialog::makeRotateLayout( void )
   text = i18n("S&hift size [bits]");
   label = new QLabel( mBitSpin, text, page );
   if( label == 0 ) { return; }
-  
+
   vbox->addWidget( label );
   vbox->addWidget( mBitSpin );
 }
@@ -1053,7 +1034,7 @@ void CFilterDialog::operandSelectorChanged( int index )
 void CFilterDialog::operandInputChanged( const QString &text )
 {
   mOperandString[ mOperandSelector->currentItem() ] = text;
-  mOperandValidator->convert( mOperandData, 
+  mOperandValidator->convert( mOperandData,
     mOperandString[ mOperandSelector->currentItem() ] );
 }
 
@@ -1162,7 +1143,7 @@ CInsertDialog::CInsertDialog( QWidget *parent, const char *name, bool modal )
   mCheckOnCursor = new QCheckBox( i18n("&Insert on cursor position"), group );
   gbox->addWidget( mCheckOnCursor, 2, 0 );
   connect( mCheckOnCursor, SIGNAL(clicked()), SLOT(cursorCheck()) );
-  gbox->setRowStretch( 3, 10 ); 
+  gbox->setRowStretch( 3, 10 );
 
   KConfig &config = *kapp->config();
   config.setGroup("Insert Pattern Dialog");
@@ -1171,7 +1152,7 @@ CInsertDialog::CInsertDialog( QWidget *parent, const char *name, bool modal )
   cursorCheck();
   uint val = config.readUnsignedNumEntry( "Format", 0 );
   mPatternSelector->setCurrentItem( QMIN(4,val) );
-  patternSelectorChanged( mPatternSelector->currentItem() );  
+  patternSelectorChanged( mPatternSelector->currentItem() );
 }
 
 
@@ -1203,7 +1184,7 @@ void CInsertDialog::patternSelectorChanged( int index )
 void CInsertDialog::patternInputChanged( const QString &text )
 {
   mPatternString[ mPatternSelector->currentItem() ] = text;
-  mPatternValidator->convert( mPatternData, 
+  mPatternValidator->convert( mPatternData,
     mPatternString[ mPatternSelector->currentItem() ] );
 }
 
@@ -1248,7 +1229,7 @@ void CInsertDialog::cursorCheck( void )
 
 
 void centerDialog( QWidget *widget, QWidget *centerParent )
-{ 
+{
   if( centerParent == 0 || widget == 0 )
   {
     return;
@@ -1256,15 +1237,15 @@ void centerDialog( QWidget *widget, QWidget *centerParent )
 
   QPoint point = centerParent->mapToGlobal( QPoint(0,0) );
   QRect pos    = centerParent->geometry();
- 
+
   widget->setGeometry( point.x() + pos.width()/2  - widget->width()/2,
-		       point.y() + pos.height()/2 - widget->height()/2, 
+		       point.y() + pos.height()/2 - widget->height()/2,
 		       widget->width(), widget->height() );
 }
 
 
 void centerDialogBottom( QWidget *widget, QWidget *centerParent )
-{ 
+{
   if( centerParent == 0 || widget == 0 )
   {
     return;
@@ -1274,7 +1255,7 @@ void centerDialogBottom( QWidget *widget, QWidget *centerParent )
   QRect pos    = centerParent->geometry();
 
   widget->setGeometry( point.x() + pos.width()/2  - widget->width()/2,
-		       point.y() + pos.height() - widget->height(), 
+		       point.y() + pos.height() - widget->height(),
 		       widget->width(), widget->height() );
 }
 
@@ -1283,13 +1264,13 @@ void comboMatchText( QComboBox *combo, const QString &text )
 {
   for( int i=0; i < combo->count(); i++ )
   {
-    if( combo->text(i) == text ) 
-    { 
-      combo->setCurrentItem(i); 
+    if( combo->text(i) == text )
+    {
+      combo->setCurrentItem(i);
       return;
     }
   }
-  combo->setCurrentItem(0); 
+  combo->setCurrentItem(0);
 }
 
 
@@ -1313,7 +1294,7 @@ void showEntryFailure( QWidget *parent, const QString &msg )
 }
 
 
-bool verifyFileDestnation( QWidget *parent, const QString &title, 
+bool verifyFileDestnation( QWidget *parent, const QString &title,
 			   const QString &path )
 {
   if( path.isEmpty() == true )
@@ -1322,18 +1303,18 @@ bool verifyFileDestnation( QWidget *parent, const QString &title,
     KMessageBox::sorry( parent, msg, title );
     return( false );
   }
-    
+
   QFileInfo info( path );
   if( info.exists() == true )
   {
-    if( info.isDir() == true ) 
+    if( info.isDir() == true )
     {
-      QString msg = i18n("You have specified an existing directory.");
+      QString msg = i18n("You have specified an existing folder.");
       KMessageBox::sorry( parent, msg, title );
       return( false );
     }
-      
-    if( info.isWritable() == false ) 
+
+    if( info.isWritable() == false )
     {
       QString msg = i18n("You do not have write permission to this file.");
       KMessageBox::sorry( parent, msg, title );
@@ -1368,9 +1349,9 @@ bool stringToOffset( const QString & text, uint &offset )
   // Skip any whitespaces in front of string
   //
   for( ; *p != 0 && isspace( *p ) ; p++ );
-  
+
   int match = 0;
-  bool space = false; 
+  bool space = false;
   if( strncmp( p, "0x", 2 ) == 0 || strncmp( p, "0X", 2 ) == 0 )
   {
     for( const char *q = p+2; *q != 0; q++ )
@@ -1406,7 +1387,7 @@ bool stringToOffset( const QString & text, uint &offset )
   {
     return( false );
   }
-  
+
   return( true );
 }
 
