@@ -14,7 +14,7 @@
  *
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  */
 
@@ -204,7 +204,7 @@ void CFileInfoDialog::setStatistics( SStatisticControl &sc )
 
   for( i=size=0; i<256; i++ )
   {
-    if( sc.occurence[i] > size ) { size = sc.occurence[i]; }
+    if( sc.occurrence[i] > size ) { size = sc.occurrence[i]; }
   }
   for( pre = 1; size > 0 ; pre++ )
   {
@@ -218,14 +218,14 @@ void CFileInfoDialog::setStatistics( SStatisticControl &sc )
     o.sprintf("%03o", i );
     b.sprintf("%s", printBin(i) );
 
-    n = QString("%1").arg( sc.occurence[i], pre );
+    n = QString("%1").arg( sc.occurrence[i], pre );
     if( sc.documentSize == 0 )
     {
       p.sprintf("0.00" );
     }
     else
     {
-      double val = 100.0*((double)sc.occurence[i]/(double)sc.documentSize);
+      double val = 100.0*((double)sc.occurrence[i]/(double)sc.documentSize);
       p = QString("%1").arg( val, 6, 'f', 2 );
     }
 
