@@ -14,7 +14,7 @@
  *
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  */
 
@@ -170,12 +170,12 @@ struct SStatisticControl
 {
   SStatisticControl( void )
   {
-    memset( occurence, 0, sizeof(occurence) );
+    memset( occurrence, 0, sizeof(occurrence) );
     documentSize = 0;
   }
 
   uint documentSize;
-  uint occurence[256];
+  uint occurrence[256];
   QString documentName;
 };
 
