@@ -14,7 +14,7 @@
  *
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  */
 
@@ -30,7 +30,7 @@
 
 static const uchar *base64EncodeTable( void )
 {
-  static uchar table[64] = 
+  static uchar table[64] =
   {
     'A','B','C','D','E','F','G','H','I','J','K','L','M','N','O','P',
     'Q','R','S','T','U','V','W','X','Y','Z','a','b','c','d','e','f',
@@ -52,11 +52,11 @@ static const uchar *base64DecodeTable( void )
     for( i = 'A'; i <= 'Z'; i++ ) { table[i] = 0 + (i - 'A'); }
     for( i = 'a'; i <= 'z'; i++ ) { table[i] = 26 + (i - 'a'); }
     for( i = '0'; i <= '9'; i++ ) { table[i] = 52 + (i - '0'); }
-    table['+'] = 62;
-    table['/'] = 63;
-    table['='] = 0;
+    table[(uchar)'+'] = 62;
+    table[(uchar)'/'] = 63;
+    table[(uchar)'='] = 0;
     init  = true;
-  } 
+  }
   return( table );
 }
 
@@ -202,7 +202,7 @@ bool CHexClipboard::decode( QByteArray &dst, QString &src )
 	dst.truncate( sumElement );
 	return( j > 0 ? false : true );
       }
-      
+
       int c = src[i++].latin1();
       if( c <= ' ' )
       {
