@@ -14,7 +14,7 @@
  *
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  */
 
@@ -26,9 +26,10 @@
 
 #include <kfiledialog.h>
 #include <kglobalsettings.h>
-#include <kio/job.h>
+#include <kio/netaccess.h>
 #include <klocale.h>
 #include <kmessagebox.h>
+#include <ktempfile.h>
 
 #include "chartabledialog.h"
 #include "converterdialog.h"
@@ -649,7 +650,7 @@ void CHexEditorWidget::open()
     return;
 
   int errCode = readURL( url, false );
-  if( errCode != Err_Success && errCode != Err_KioInProgress )
+  if( errCode != Err_Success )
   {
     emit errorLoadFile( url );
     removeBuffer();
@@ -690,7 +691,7 @@ void CHexEditorWidget::open( const QString &url, bool reloadWhenChanged,
   }
 
   int errCode = readURL( url, false );
-  if( errCode != Err_Success && errCode != Err_KioInProgress )
+  if( errCode != Err_Success )
   {
     emit errorLoadFile( url );
     removeBuffer();
@@ -822,7 +823,7 @@ bool CHexEditorWidget::closeAll( void )
     for( buf = mDocumentList.first(); buf != 0; buf = mDocumentList.next() )
     {
       //
-      // We select the buffer we are about to close becuase it will
+      // We select the buffer we are about to close because it will
       // the become visible, and because 'close()' works on the current
       // buffer.
       //
@@ -933,7 +934,7 @@ bool CHexEditorWidget::save( void )
 	return( reply == KMessageBox::No ? true : false );
       }
     }
-	
+
     if( mDisplayState.misc.makeBackup == true )
     {
       backup();
@@ -1054,16 +1055,15 @@ void CHexEditorWidget::reload( void )
 void CHexEditorWidget::print( void )
 {
   CHexPrinter prt;
+
   prt.addDialogPage( new LayoutDialogPage() );
+
   prt.setPageSelection( KPrinter::SystemSide );
+  prt.setFullPage( true ); // I use my own marings
 
-  if (prt.setup(topLevelWidget()))
+  // FIXME: Make a better header for the printingdialog
+  if (prt.setup(topLevelWidget(), i18n("Print Hex-Document")))
   {
-     prt.setAsText( false  );
-     prt.setFullPage( true ); // I use my own marings
-     prt.setPrintBackWhite( false );
-     prt.setScaleToFit( true );
-
      prt.setTopMarginMM( prt.option("kde-khexedit-topmarginmm").toInt() );
      prt.setBottomMarginMM( prt.option("kde-khexedit-bottommarginmm").toInt() );
      prt.setLeftMarginMM( prt.option("kde-khexedit-leftmarginmm").toInt() );
@@ -1081,11 +1081,6 @@ void CHexEditorWidget::print( void )
 			  prt.option("kde-khexedit-footercombo2").toInt(),
 			  prt.option("kde-khexedit-footercombo3").toInt() );
 
-     prt.setAll( true );
-     prt.setSelection( false );
-     prt.setRange( false );
-     prt.setFromTo( prt.minPage(), prt.maxPage() );
-
      printPostscript(prt);
   }
 
@@ -1132,7 +1127,10 @@ bool CHexEditorWidget::confirmPrintPageNumber( CHexPrinter &printer )
   if( mDisplayState.misc.confirmThreshold == true )
   {
     uint numPage = mHexView->numPage( printer );
-    if( numPage > mDisplayState.misc.thresholdValue )
+    printer.setMinMax( 1, numPage );
+    uint numPageSelected = printer.pageList().count();
+
+    if( numPageSelected > mDisplayState.misc.thresholdValue )
     {
       QString msg = i18n(
         "<qt>Print threshold exceeded.<br>"
@@ -1141,7 +1139,7 @@ bool CHexEditorWidget::confirmPrintPageNumber( CHexPrinter &printer )
         "<qt>Print threshold exceeded.<br>"
         "You are about to print %n pages.<br>"
 	"Proceed?</qt>",
-	numPage );
+	numPageSelected );
       int reply = KMessageBox::warningYesNo( topLevelWidget(), msg,
 					     i18n("Print") );
       if( reply != KMessageBox::Yes )
@@ -1330,6 +1328,11 @@ void CHexEditorWidget::toggleOffsetUppercase( void )
   mHexView->setLayout( layout() );
 }
 
+void CHexEditorWidget::toggleInsertMode( void )
+{
+  mHexView->setInsertMode( !mHexView->insertMode() );
+}
+
 void CHexEditorWidget::benchmark( void )
 {
   mHexView->benchmark();
@@ -1501,7 +1504,7 @@ void CHexEditorWidget::findData( SSearchControl &sc, uint mode, bool navigator)
 
     if( errCode == Err_WrapBuffer && i == 0 )
     {
-      bool reply = askWrap( sc.forward, QString(i18n("Find")) );
+      bool reply = askWrap( sc.forward, i18n("Find") );
       if( reply == false )
       {
 	return;
@@ -1686,7 +1689,7 @@ void CHexEditorWidget::replaceData( SSearchControl &sc, uint mode )
       break;
     }
 
-    bool reply = askWrap( sc.forward, QString(i18n("Find and Replace")) );
+    bool reply = askWrap( sc.forward, i18n("Find and Replace") );
     if( reply == false )
     {
       break;
@@ -1754,13 +1757,13 @@ void CHexEditorWidget::replaceResult( SSearchControl &sc )
     {
       msg += i18n( "Search key not found in document." );
     }
-    KMessageBox::information( topLevelWidget(), msg, i18n("Find and Replace"));
+    KMessageBox::information( topLevelWidget(), msg, i18n("Find & Replace"));
   }
   else
   {
     QString msg( i18n( "Operation complete.\n\n" ) );
     msg += i18n( "One replacement was made.","%n replacements were made.",sc.numReplace);
-    KMessageBox::information( topLevelWidget(), msg, i18n("Find and Replace"));
+    KMessageBox::information( topLevelWidget(), msg, i18n("Find & Replace"));
   }
 }
 
@@ -1967,7 +1970,7 @@ int CHexEditorWidget::readURL( const QString &url, bool insert )
   // current directory.
   //
   KURL kurl( url );
-  if( kurl.isMalformed() == true )
+  if( !kurl.isValid() )
   {
     QString tmp( "file:" );
     if( url.find( '/' ) != 0 ) // The '/' is not the first character
@@ -1977,7 +1980,7 @@ int CHexEditorWidget::readURL( const QString &url, bool insert )
     tmp += url;
     kurl = tmp;
 
-    if( kurl.isMalformed() == true )
+    if( !kurl.isValid() )
     {
       QString msg = i18n("Malformed URL\n%1").arg( kurl.url() );
       KMessageBox::sorry( topLevelWidget(), msg, i18n("Read URL") );
@@ -1989,132 +1992,39 @@ int CHexEditorWidget::readURL( const QString &url, bool insert )
   // 3) Load the file. Since this is an url we check if this is a local
   // or a "remote" file. The local file can be opened as a regular file.
   //
-  if( kurl.isLocalFile() == true )
-  {
-    QString symbolicName( kurl.url() );
-//    KURL::decode( symbolicName );
-
-    kurl.setProtocol( QString::null );
-    bool success = readFile( KURL::decode_string( kurl.url() ), symbolicName, insert );
-    return( success == true ? Err_Success : Err_ReadFailed );
-  }
-  else
-  {
-    QString tmpFileName = createTemporaryFileName();
-    KIO::Job *job = KIO::copy( kurl, tmpFileName );
-    if( job == 0 )
-    {
-      QString msg = i18n("Could not create kio job.\n");
-      msg += hexError(Err_NoMemory);
-      KMessageBox::error( topLevelWidget(), msg, i18n("Read URL") );
-      return( Err_NoMemory );
-    }
-    //job->setGUImode ( KIOJob::NONE );
-    mKioRemote.insert( job, new QString(kurl.url()) );
-    mKioLocal.insert( job, new QString(tmpFileName) );
-    mKioFlag.insert( job, new bool(insert) );
-
-    connect( job, SIGNAL(result(KIO::Job *)), SLOT(slotReadFinished(KIO::Job *)) );
-    return( Err_KioInProgress );
+  QString tmpfile;
+  if ( !kurl.isLocalFile() ) {
+      if ( !KIO::NetAccess::download( kurl, tmpfile, this ) )
+          return Err_ReadFailed;
+      kurl = tmpfile;
   }
 
-  return( Err_Success );
+  bool success = readFile( kurl.path(), kurl.url(), insert );
+
+  if ( !tmpfile.isNull() )
+      KIO::NetAccess::removeTempFile( tmpfile );
+
+  return( success == true ? Err_Success : Err_ReadFailed );
 }
 
 
 void CHexEditorWidget::writeURL( QString &url )
 {
   KURL kurl( url );
-  if( kurl.isLocalFile() == true )
-  {
-    QString path( kurl.path() );
-    writeFile( path );
+  QString tempfile;
+  KTempFile tf;
+  if( !kurl.isLocalFile() ) {
+      tempfile = tf.name();
+      tf.setAutoDelete( true );
+      writeFile( tempfile );
   }
-  else
-  {
-    QString tmpFileName = createTemporaryFileName();
-    KIO::Job *job = KIO::copy( tmpFileName, kurl );
-    if( job == 0 )
-    {
-      QString msg = i18n("Could not create kio job.\n");
-      msg += hexError(Err_NoMemory);
-      KMessageBox::error( topLevelWidget(), msg, i18n("Write URL") );
-      return;
-    }
-    //job->setGUImode ( KIOJob::NONE );
+  else 
+      writeFile( KURL( url ).path() );
 
-    mKioRemote.insert( job, new QString(kurl.url()) );
-    mKioLocal.insert( job, new QString(tmpFileName) );
-
-    connect( job, SIGNAL(result(KIO::Job *)), SLOT(slotWriteFinished(KIO::Job *)) );
-  }
+  if ( !tempfile.isNull() )
+      KIO::NetAccess::upload( tempfile, url, 0 );
 }
 
-
-void CHexEditorWidget::kioReadFinished( KIO::Job * job )
-{
-  if (job->error())
-    job->showErrorDialog();
-
-  QString *tmpFileName = mKioLocal.find( job );
-  QString *url = mKioRemote.find( job );
-  bool *insert =  mKioFlag.find( job );
-
-  if( tmpFileName != 0 && url != 0 && insert != 0 )
-  {
-    QString symbolicName( *url );
-//    KURL::decode( symbolicName );
-    bool success = !job->error() &&
-              readFile( *tmpFileName, symbolicName, *insert );
-    if( success == true )
-    {
-      if( *insert == false )
-      {
-	defaultWriteProtection();
-      }
-    }
-    else
-    {
-      emit errorLoadFile( symbolicName );
-      removeBuffer();
-    }
-  }
-
-  //
-  // Remove temporary file and destroy kio variables
-  //
-  if( tmpFileName != 0 )
-  {
-    unlink( tmpFileName->latin1() );
-  }
-  mKioRemote.remove( job );
-  mKioLocal.remove( job );
-  mKioFlag.remove( job );
-}
-
-
-void CHexEditorWidget::kioWriteFinished( KIO::Job * job )
-{
-  if (job->error())
-    job->showErrorDialog();
-
-  QString *tmpFileName = mKioLocal.find( job );
-  if( tmpFileName != 0 )
-  {
-    unlink( tmpFileName->latin1() );
-  }
-  mKioRemote.remove( job );
-  mKioLocal.remove( job );
-  mKioFlag.remove( job );
-}
-
-
-QString CHexEditorWidget::createTemporaryFileName( void )
-{
-  return( QString("file:/tmp/khexedit.%1.%2").arg(getpid()).arg(time(0)) );
-}
-
-
 bool CHexEditorWidget::modifiedByAlien( const QString &url )
 {
   KURL kurl( url );
@@ -2154,7 +2064,7 @@ bool CHexEditorWidget::readFile( const QString &diskPath, const QString &url,
 
   if( info.isDir() == true )
   {
-    QString msg = i18n("You have specified a directory.");
+    QString msg = i18n("You have specified a folder.");
     msg += "\n" + diskPath;
     KMessageBox::sorry( topLevelWidget(), msg, i18n("Read") );
     return( false );
@@ -2171,7 +2081,7 @@ bool CHexEditorWidget::readFile( const QString &diskPath, const QString &url,
   QFile file( diskPath );
   if( file.open( IO_ReadOnly | IO_Raw ) == false )
   {
-    QString msg = i18n("An error occured while trying to open the file.");
+    QString msg = i18n("An error occurred while trying to open the file.");
     msg += "\n" + diskPath;
     KMessageBox::sorry( topLevelWidget(), msg, i18n("Read") );
     return( false );
@@ -2213,14 +2123,14 @@ bool CHexEditorWidget::readFile( const QString &diskPath, const QString &url,
 
 
 
-bool CHexEditorWidget::writeFile( QString &diskPath )
+bool CHexEditorWidget::writeFile( const QString &diskPath )
 {
   QFileInfo info( diskPath );
   if( info.exists() == true )
   {
     if( info.isDir() == true )
     {
-      QString msg = i18n("You have specified a directory.");
+      QString msg = i18n("You have specified a folder.");
       KMessageBox::sorry( topLevelWidget(), msg, i18n("Write Failure") );
       return( false );
     }
@@ -2236,7 +2146,7 @@ bool CHexEditorWidget::writeFile( QString &diskPath )
   QFile file( diskPath );
   if( file.open( IO_WriteOnly | IO_Raw | IO_Truncate ) == false )
   {
-    QString msg = i18n("An error occured while trying to open the file.");
+    QString msg = i18n("An error occurred while trying to open the file.");
     KMessageBox::sorry( topLevelWidget(), msg, i18n("Write Failure") );
     return( false );
   }
