@@ -14,7 +14,7 @@
  *
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  */
 
@@ -28,6 +28,7 @@
 #include <klocale.h>
 #include <kpopupmenu.h>
 #include <kdebug.h>
+#include <kurldrag.h>
 
 #include "hexdrag.h"
 #include "hexerror.h"
@@ -1097,7 +1098,8 @@ int CHexViewWidget::bookmarkMenu( const QString &title )
   }
 
   QString text;
-  KPopupMenu *popup = new KPopupMenu( title, 0 );
+  KPopupMenu *popup = new KPopupMenu(  0 );
+  popup->insertTitle( title );
   for( uint i=0; i < list.count(); i++ )
   {
     const SCursorOffset *p = list.at( i );
@@ -1130,7 +1132,7 @@ void CHexViewWidget::removeBookmark( bool all )
   }
   else
   {
-    int position = bookmarkMenu( QString(i18n("Remove Bookmark")) );
+    int position = bookmarkMenu( i18n("Remove Bookmark") );
     if( position < 0 )
     {
       return;
@@ -1160,7 +1162,7 @@ void CHexViewWidget::replaceBookmark( void )
     return;
   }
 
-  int position = bookmarkMenu( QString(i18n("Replace Bookmark")) );
+  int position = bookmarkMenu( i18n("Replace Bookmark") );
   if( position < 0 )
   {
     return;
@@ -1625,7 +1627,7 @@ void CHexViewWidget::wheelEvent( QWheelEvent *e )
 void CHexViewWidget::dragEnterEvent( QDragEnterEvent *e )
 {
   if( QTextDrag::canDecode(e) || CHexDrag::canDecode(e) ||
-      QUriDrag::canDecode(e))
+      KURLDrag::canDecode(e))
   {
     e->accept();
     setDropHighlight( true );
@@ -1644,11 +1646,11 @@ void CHexViewWidget::dragMoveEvent( QDragMoveEvent *e )
   //
   // Move the cursor if we are dragging (readable) text or binary
   // data. Note: the QTextDrag::canDecode() will return true if we
-  // are dragging a file so we have to test for QUriDrag::canDecode()
+  // are dragging a file so we have to test for KURLDrag::canDecode()
   // first.
   //
 
-  if( QUriDrag::canDecode(e) == true )
+  if( KURLDrag::canDecode(e) == true )
   {
     return;
   }
@@ -1672,16 +1674,16 @@ void CHexViewWidget::dropEvent( QDropEvent *e )
   QMimeSource &m = *(QDropEvent*)e;
   setDropHighlight( false );
 
-  QStringList list;
-  if( QUriDrag::decodeToUnicodeUris( &m, list ) == true )
+  KURL::List list;
+  if( KURLDrag::decode( &m, list ) == true )
   {
     //
     // This widget can not itself open a file so it will simply pass
     // the request to a parent that can (hopefully) do this
     //
-    for( QStringList::Iterator it = list.begin(); it != list.end(); it++ )
+    for( KURL::List::ConstIterator it = list.begin(); it != list.end(); it++ )
     {
-      emit pleaseOpenFile( *it, true, 0 );
+      emit pleaseOpenFile( (*it).url(), true, 0 );
     }
     return;
   }
