@@ -14,7 +14,7 @@
  *
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  */
 
@@ -39,7 +39,7 @@ static KCmdLineOptions option[] =
 {
    { "offset <offset>", I18N_NOOP("Jump to 'offset'"), 0 },
    { "+[file(s)]", I18N_NOOP("File(s) to open"), 0 },
-   { 0, 0, 0 }
+   KCmdLineLastOption
 };
 
 static uint parseDecimalOrHexadecimal( char *buf );
