@@ -14,7 +14,7 @@
  *
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  */
 
@@ -64,6 +64,8 @@ class CColorListBox : public KListBox
   private:
     int mCurrentOnDragEnter;
 
+  signals:
+    void dataChanged();
 };
 
 
@@ -131,7 +133,7 @@ class COptionDialog : public KDialogBase
     virtual void slotDefault( void );
     virtual void slotOk( void );
     virtual void slotApply( void );
-
+    void slotChanged();
 
   private:
     struct SLayoutWidgets
@@ -249,7 +251,7 @@ class COptionDialog : public KDialogBase
     SFontWidgets   mFont;
     SFileWidgets   mFile;
     SMiscWidgets   mMisc;
-
+    bool configChanged;
 
 };
 
