@@ -14,25 +14,28 @@
  *
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  */
 
 #include <iostream>
 
+#include <qptrlist.h>
+#include <qsignalmapper.h>
 #include <qtimer.h>
 #include <qtooltip.h>
 
 #include <kaction.h>
 #include <kiconloader.h>
 #include <klocale.h>
-#include <kmenubar.h>
 #include <kmessagebox.h>
 #include <kstatusbar.h>
 #include <kpopupmenu.h>
 #include <kstdaction.h>
 #include <ktoolbarbutton.h>
 #include <kdebug.h>
+#include <kurldrag.h>
+#include <kkeydialog.h>
 
 #include "dialog.h"
 #include "draglabel.h"
@@ -56,8 +59,8 @@ KHexEdit::KHexEdit( void )
 
   //
   // I use an eventfilter to catch all drag/drop events for the
-  // area outside the editor window. It will only accept QUriDrag.
-  // (The editor window will catch QUriDrag, QTextDrag and CHexDrag)
+  // area outside the editor window. It will only accept KURLDrag.
+  // (The editor window will catch KURLDrag, QTextDrag and CHexDrag)
   //
   installEventFilter( this );
   setAcceptDrops(true);
@@ -65,6 +68,8 @@ KHexEdit::KHexEdit( void )
   //
   // Prepare menus and status bar
   //
+  mAction.bookmarkMapper = new QSignalMapper(this);
+  connect(mAction.bookmarkMapper, SIGNAL(mapped(int)), editor(), SLOT(gotoBookmark(int)));
   setupActions();
   setupStatusBar();
 
@@ -113,16 +118,19 @@ KHexEdit::KHexEdit( void )
 
 KHexEdit::~KHexEdit( void )
 {
+  delete mAction.bookmarkMapper;
   delete mManager;
 }
 
 
 void KHexEdit::setupActions( void )
 {
-  mAction.newFile    = KStdAction::openNew( editor(), SLOT(newFile()), actionCollection() );
-  mAction.open       = KStdAction::open( editor(), SLOT(open()), actionCollection() );
-  mAction.insert     = new KAction( i18n("&Insert..."), 0,
-    editor(), SLOT(insertFile()), actionCollection() );
+  KStdAction::openNew( editor(), SLOT(newFile()), actionCollection() );
+  KStdAction::open( editor(), SLOT(open()), actionCollection() );
+  KStdAction::keyBindings( this, SLOT( slotConfigureKeys() ), actionCollection() );
+
+  mAction.insert     = new KAction( i18n("&Insert..."), CTRL+Key_I,
+    editor(), SLOT(insertFile()), actionCollection(), "insert_file" );
   mAction.openRecent = KStdAction::openRecent(0, 0, actionCollection() );
   connect( mAction.openRecent->popupMenu(), SIGNAL(activated(int )),
      this, SLOT( recentFile(int) ) );
@@ -135,17 +143,17 @@ void KHexEdit::setupActions( void )
   mAction.close      = KStdAction::close( editor(), SLOT(close()), actionCollection() );
   mAction.print      = KStdAction::print( editor(), SLOT(print()), actionCollection() );
   mAction.exportData = new KAction( i18n("E&xport..."), 0,
-    editor(), SLOT(exportDialog()), actionCollection() );
+    editor(), SLOT(exportDialog()), actionCollection(), "export" );
   mAction.cancel     = new KAction( i18n("&Cancel Operation"),
-    "stop", 0, editor(), SLOT(stop()), actionCollection() );
+    "stop", 0, editor(), SLOT(stop()), actionCollection(), "cancel" );
   mAction.readOnly   = new KToggleAction( i18n("&Read Only"),
-    0, editor(), SLOT(toggleWriteProtection()),actionCollection() );
+    0, editor(), SLOT(toggleWriteProtection()),actionCollection(), "read_only" );
   mAction.resizeLock = new KToggleAction( i18n("&Allow Resize"),
-   0, editor(), SLOT(toggleResizeLock()),actionCollection() );
+   0, editor(), SLOT(toggleResizeLock()),actionCollection(), "resize_lock" );
   mAction.newWindow  = new KAction( i18n("N&ew Window"),
-    0, this, SLOT(newWindow()),actionCollection() );
+    0, this, SLOT(newWindow()),actionCollection(), "new_window" );
   mAction.closeWindow= new KAction( i18n("Close &Window"),
-    0, this, SLOT(closeWindow()),actionCollection() );
+    0, this, SLOT(closeWindow()),actionCollection(), "close_window" );
   mAction.quit       = KStdAction::quit( this, SLOT(closeProgram()), actionCollection() );
 
   mAction.undo       = KStdAction::undo(  editor(), SLOT(undo()), actionCollection() );
@@ -154,38 +162,33 @@ void KHexEdit::setupActions( void )
   mAction.copy       = KStdAction::copy(  editor(), SLOT(copy()), actionCollection() );
   mAction.paste      = KStdAction::paste(  editor(), SLOT(paste()), actionCollection() );
   mAction.selectAll  = KStdAction::selectAll(editor(), SLOT(selectAll()),actionCollection() );
-  mAction.unselect   = new KAction( i18n("&Unselect"), 0,
-    editor(), SLOT(unselect()), actionCollection() );
+  mAction.unselect   = KStdAction::deselect(editor(), SLOT(unselect()), actionCollection());
   mAction.find       = KStdAction::find( editor(), SLOT(find()), actionCollection() );
   mAction.findNext   = KStdAction::findNext(editor(), SLOT(findNext()), actionCollection() );
   mAction.findPrev = KStdAction::findPrev(editor(),SLOT(findPrevious()),actionCollection() );
   mAction.replace    = KStdAction::replace( editor(), SLOT(replace()), actionCollection() );
-  mAction.gotoOffset = new KAction( i18n("&Goto Offset..."), 0,
-    editor(), SLOT(gotoOffset()),actionCollection() );
-  mAction.insertPattern = new KAction( i18n("&Insert Pattern..."), 0,
-    editor(), SLOT(insertPattern()), actionCollection() );
+  mAction.gotoOffset = new KAction( i18n("&Goto Offset..."), CTRL+Key_G,
+    editor(), SLOT(gotoOffset()),actionCollection(), "goto_offset" );
+  mAction.insertPattern = new KAction( i18n("&Insert Pattern..."), CTRL+Key_Insert,
+    editor(), SLOT(insertPattern()), actionCollection(), "insert_pattern" );
 
   mAction.copyAsText = new KAction( i18n("Copy as &Text"), 0,
-    editor(), SLOT(copyText()), actionCollection() );
+    editor(), SLOT(copyText()), actionCollection(), "copy_as_text" );
   mAction.pasteToNewFile = new KAction( i18n("Paste into New &File"), 0,
-    editor(), SLOT(pasteNewFile()), actionCollection() );
+    editor(), SLOT(pasteNewFile()), actionCollection(), "paste_into_new_file" );
   mAction.pasteToNewWindow = new KAction( i18n("Paste into New &Window"), 0,
-    this, SLOT(pasteNewWindow()), actionCollection() );
-
-  mAction.insert->setAccel( CTRL+Key_I );
-  mAction.gotoOffset->setAccel( CTRL+Key_G );
-  mAction.insertPattern->setAccel( CTRL+Key_Insert );
+    this, SLOT(pasteNewWindow()), actionCollection(), "paste_into_new_window" );
 
   mAction.hexadecimal = new KRadioAction( i18n("&Hexadecimal"),
-    0, this, SLOT(setDisplayMode()), this, "mode" );
+    0, this, SLOT(setDisplayMode()), actionCollection(), "mode_hex" );
   mAction.decimal     = new KRadioAction( i18n("&Decimal"),
-    0, this, SLOT(setDisplayMode()),this, "mode" );
+    0, this, SLOT(setDisplayMode()), actionCollection(), "mode_dec" );
   mAction.octal       = new KRadioAction( i18n("&Octal"),
-    0, this, SLOT(setDisplayMode()),this, "mode" );
+    0, this, SLOT(setDisplayMode()), actionCollection(), "mode_oct" );
   mAction.binary      = new KRadioAction( i18n("&Binary"),
-    0, this, SLOT(setDisplayMode()),this, "mode" );
+    0, this, SLOT(setDisplayMode()), actionCollection(), "mode_bin" );
   mAction.textOnly    = new KRadioAction( i18n("&Text"),
-    0, this, SLOT(setDisplayMode()),this, "mode" );
+    0, this, SLOT(setDisplayMode()), actionCollection(), "mode_text" );
   mAction.hexadecimal->setExclusiveGroup( "displayMode" );
   mAction.decimal->setExclusiveGroup( "displayMode" );
   mAction.octal->setExclusiveGroup( "displayMode" );
@@ -193,40 +196,40 @@ void KHexEdit::setupActions( void )
   mAction.textOnly->setExclusiveGroup( "displayMode" );
 
   mAction.showOffsetColumn = new KToggleAction( i18n("Show O&ffset Column"),
-    0, editor(), SLOT(toggleOffsetColumnVisibility()),actionCollection() );
+    0, editor(), SLOT(toggleOffsetColumnVisibility()),actionCollection(), "show_offset_column" );
   mAction.showTextColumn = new KToggleAction( i18n("Show Te&xt Field"),
-    0, editor(), SLOT(toggleTextColumnVisibility()),actionCollection() );
+    0, editor(), SLOT(toggleTextColumnVisibility()),actionCollection(), "show_text_field" );
   mAction.offsetAsDecimal = new KToggleAction( i18n("Off&set as Decimal"),
-    0, editor(), SLOT(toggleOffsetAsDecimal()),actionCollection() );
+    0, editor(), SLOT(toggleOffsetAsDecimal()),actionCollection(), "offset_as_decimal" );
   mAction.dataUppercase = new KToggleAction( i18n("&Upper Case (Data)"),
-    0, editor(), SLOT(toggleDataUppercase()),actionCollection() );
+    0, editor(), SLOT(toggleDataUppercase()),actionCollection(), "upper_case_data" );
   mAction.offsetUppercase = new KToggleAction( i18n("Upper &Case (Offset)"),
-    0, editor(), SLOT(toggleOffsetUppercase()),actionCollection() );
+    0, editor(), SLOT(toggleOffsetUppercase()),actionCollection(), "upper_case_offset" );
 
   mAction.defaultEncoding = new KRadioAction( i18n("&Default encoding", "&Default"),
-    0, this, SLOT( setEncoding()), actionCollection() );
+    0, this, SLOT( setEncoding()), actionCollection(), "enc_default" );
   mAction.usAsciiEncoding = new KRadioAction( i18n("US-&ASCII (7 bit)"),
-    0, this, SLOT( setEncoding()), actionCollection() );
+    0, this, SLOT( setEncoding()), actionCollection(), "enc_ascii");
   mAction.ebcdicEncoding  = new KRadioAction( i18n("&EBCDIC"),
-    0, this, SLOT( setEncoding()), actionCollection() );
-  mAction.customEncoding  = new KAction( i18n("&Custom..."),
-    0, editor(), SLOT( encoding()), actionCollection() );
+    0, this, SLOT( setEncoding()), actionCollection(), "enc_ebcdic" );
+//   mAction.customEncoding  = new KAction( i18n("&Custom..."),
+//     0, editor(), SLOT( encoding()), actionCollection(), "enc_custom" );
   mAction.defaultEncoding->setExclusiveGroup( "encodingMode" );
   mAction.usAsciiEncoding->setExclusiveGroup( "encodingMode" );
   mAction.ebcdicEncoding->setExclusiveGroup( "encodingMode" );
 
   mAction.strings = new KAction( i18n("&Extract Strings..."), 0,
-    editor(), SLOT(strings()), actionCollection() );
-  mAction.recordViewer = new KAction( i18n("&Record Viewer"), 0,
-    editor(), SLOT(recordView()), actionCollection() );
+    editor(), SLOT(strings()), actionCollection(), "extract_strings" );
+//   mAction.recordViewer = new KAction( i18n("&Record Viewer"), 0,
+//     editor(), SLOT(recordView()), actionCollection(), "record_viewer" );
   mAction.filter = new KAction( i18n("&Binary Filter..."), 0,
-    editor(), SLOT(filter()), actionCollection() );
+    editor(), SLOT(filter()), actionCollection(), "binary_filter" );
   mAction.characterTable = new KAction( i18n("&Character Table"), 0,
-    editor(), SLOT(chart()), actionCollection() );
+    editor(), SLOT(chart()), actionCollection(), "char_table" );
   mAction.converter = new KAction( i18n("C&onverter"), 0,
-    editor(), SLOT(converter()), actionCollection() );
+    editor(), SLOT(converter()), actionCollection(), "converter" );
   mAction.statistics = new KAction( i18n("&Statistics"), 0,
-    editor(), SLOT(statistics()), actionCollection() );
+    editor(), SLOT(statistics()), actionCollection(), "statistics" );
 
   mAction.addBookmark = KStdAction::addBookmark( editor(),
     SLOT(addBookmark()), actionCollection() );
@@ -235,7 +238,7 @@ void KHexEdit::setupActions( void )
   mAction.removeBookmark = new KAction( i18n("R&emove Bookmark"), CTRL+Key_U,
     editor(), SLOT(removeBookmark()), actionCollection(), "remove_bookmark" );
   mAction.removeAllBookmark = new KAction( i18n("Re&move All"), 0,
-    editor(), SLOT(removeAllBookmark()), actionCollection() );
+    editor(), SLOT(removeAllBookmark()), actionCollection(), "remove_all_bookmarks" );
   mAction.nextBookmark = new KAction( i18n("Goto &Next Bookmark"),
 				      ALT+Key_Down, editor(),
 				      SLOT(gotoNextBookmark()), actionCollection(), "next_bookmark" );
@@ -243,258 +246,59 @@ void KHexEdit::setupActions( void )
 				      ALT+Key_Up, editor(),
 				      SLOT(gotoPrevBookmark()), actionCollection(), "prev_bookmark" );
 
-  mAction.showToolBar = KStdAction::showToolbar( this, SLOT(showToolBar()),
-    actionCollection() );
-  mAction.showStatusBar = KStdAction::showStatusbar(this,SLOT(showStatusBar()),
-    actionCollection() );
+  createStandardStatusBarAction();
+  setStandardToolBarMenuEnabled(true);
   mAction.showFullPath  = new KToggleAction( i18n("Show F&ull Path"),
-    0, this, SLOT(showFullPath()), actionCollection() );
+    0, this, SLOT(showFullPath()), actionCollection(), "show_full_path" );
 
   mAction.tabHide = new KRadioAction( i18n("&Hide"),
-    0, this, SLOT(showDocumentTabs()), actionCollection() );
+    0, this, SLOT(showDocumentTabs()), actionCollection(), "doctab_hide" );
   mAction.tabShowAboveEditor = new KRadioAction( i18n("&Above Editor"),
-    0, this, SLOT(showDocumentTabs()), actionCollection() );
+    0, this, SLOT(showDocumentTabs()), actionCollection(), "doctab_above" );
   mAction.tabShowBelowEditor = new KRadioAction( i18n("&Below Editor"),
-    0, this, SLOT(showDocumentTabs()), actionCollection() );
+    0, this, SLOT(showDocumentTabs()), actionCollection(), "doctab_below" );
   mAction.tabHide->setExclusiveGroup( "editorTab" );
   mAction.tabShowAboveEditor->setExclusiveGroup( "editorTab" );
   mAction.tabShowBelowEditor->setExclusiveGroup( "editorTab" );
 
   mAction.conversionHide  = new KRadioAction( i18n("&Hide"),
-    0, this, SLOT(showConversionField()), actionCollection() );
+    0, this, SLOT(showConversionField()), actionCollection(), "conversion_field_hide");
   mAction.conversionFloat = new KRadioAction( i18n("&Floating"),
-    0, this, SLOT(showConversionField()), actionCollection() );
+    0, this, SLOT(showConversionField()), actionCollection(), "conversion_field_float");
   mAction.conversionEmbed = new KRadioAction( i18n("&Embed in Main Window"),
-    0, this, SLOT(showConversionField()), actionCollection() );
+    0, this, SLOT(showConversionField()), actionCollection(), "conversion_field_embed");
   mAction.conversionHide->setExclusiveGroup( "conversionField" );
   mAction.conversionFloat->setExclusiveGroup( "conversionField" );
   mAction.conversionEmbed->setExclusiveGroup( "conversionField" );
 
   mAction.searchHide = new KRadioAction( i18n("&Hide"),
-    0, this, SLOT(showSearchBar()), actionCollection() );
+    0, this, SLOT(showSearchBar()), actionCollection(), "searchbar_hide" );
   mAction.searchShowAboveEditor = new KRadioAction( i18n("&Above Editor"),
-    0, this, SLOT(showSearchBar()), actionCollection() );
+    Key_F5, this, SLOT(showSearchBar()), actionCollection(), "searchbar_above" );
   mAction.searchShowBelowEditor = new KRadioAction( i18n("&Below Editor"),
-    0, this, SLOT(showSearchBar()), actionCollection() );
+    Key_F6, this, SLOT(showSearchBar()), actionCollection(), "searchbar_below" );
   mAction.searchHide->setExclusiveGroup( "searchBar" );
   mAction.searchShowAboveEditor->setExclusiveGroup( "searchBar" );
   mAction.searchShowBelowEditor->setExclusiveGroup( "searchBar" );
-  mAction.searchShowAboveEditor->setAccel( Key_F5 );
-  mAction.searchShowBelowEditor->setAccel( Key_F6 );
 
-  mAction.writeConfiguration =  new KAction( i18n("&Save Options"), 0,
-    this, SLOT(writeConfiguration()), actionCollection() );
-  mAction.preferences = KStdAction::preferences(editor(),SLOT(options()),actionCollection() );
-  mAction.favorites = new KAction( i18n("P&rofiles..."), 0,
-    editor(), SLOT(favorites()), actionCollection() );
+  KStdAction::saveOptions(this, SLOT(writeConfiguration()), actionCollection());
+  KStdAction::preferences(editor(),SLOT(options()),actionCollection() );
+//   mAction.favorites = new KAction( i18n("P&rofiles..."), 0,
+//     editor(), SLOT(favorites()), actionCollection(), "favorites" );
 
-  mAction.help = KStdAction::help( this, SLOT(appHelpActivated()), actionCollection() );
-  mAction.separator = new KActionSeparator( this );
+  KStdAction::help( this, SLOT(appHelpActivated()), actionCollection() );
 
-  //
-  // Make the menu entries.
-  //
-  mAction.permissionMenu   = new KActionMenu( i18n("Per&missions"), actionCollection() );
-  mAction.editSpecialMenu  = new KActionMenu( i18n("Spec&ial"), actionCollection() );
-  mAction.encodingMenu     = new KActionMenu( i18n("Document &Encoding"),actionCollection() );
-  mAction.conversionMenu   = new KActionMenu( i18n("Conversion &Field"),actionCollection() );
-  mAction.documentTabsMenu = new KActionMenu( i18n("&Document Tabs"), actionCollection() );
-  mAction.searchBarMenu    = new KActionMenu( i18n("Searc&hbar"), actionCollection() );
-  mAction.fileMenu      = new KActionMenu( i18n("&File"), actionCollection() );
-  mAction.editMenu      = new KActionMenu( i18n("&Edit"), actionCollection() );
-  mAction.viewMenu      = new KActionMenu( i18n("&View"), actionCollection() );
-  mAction.bookmarkMenu  = new KActionMenu( i18n("&Bookmarks"), actionCollection() );
-  mAction.toolsMenu     = new KActionMenu( i18n("&Tools"), actionCollection() );
-  mAction.documentsMenu = new KActionMenu( i18n("&Documents"), actionCollection() );
-  mAction.settingsMenu  = new KActionMenu( i18n("&Settings"), actionCollection() );
-  mAction.filePopup     = new KActionMenu( "", actionCollection() );
-  mAction.bookmarkPopup = new KActionMenu( i18n("&Bookmarks"), actionCollection() );
-
-
-  // Editor popup menu
-  mAction.filePopup->insert( mAction.open );
-  mAction.filePopup->insert( mAction.save );
-  mAction.filePopup->insert( mAction.saveAs );
-  mAction.filePopup->insert( mAction.separator );
-  mAction.filePopup->insert( mAction.bookmarkPopup );
-  mAction.filePopup->insert( mAction.separator );
-  mAction.filePopup->insert( mAction.hexadecimal );
-  mAction.filePopup->insert( mAction.decimal );
-  mAction.filePopup->insert( mAction.octal );
-  mAction.filePopup->insert( mAction.binary );
-  mAction.filePopup->insert( mAction.textOnly );
-  mAction.filePopup->insert( mAction.separator );
-  mAction.filePopup->insert( mAction.readOnly );
-  mAction.filePopup->insert( mAction.resizeLock );
-
-  hexView()->setPopupMenu( mAction.filePopup->popupMenu() );
-  hexView()->setDocumentMenu( mAction.documentsMenu->popupMenu() );
-
-  // File menu
-  mAction.fileMenu->insert( mAction.newFile );
-  mAction.fileMenu->insert( mAction.open );
-  mAction.fileMenu->insert( mAction.insert );
-  mAction.fileMenu->insert( mAction.openRecent );
-  mAction.fileMenu->insert( mAction.revert );
-  mAction.fileMenu->insert( mAction.separator );
-  mAction.fileMenu->insert( mAction.save );
-  mAction.fileMenu->insert( mAction.saveAs );
-  mAction.fileMenu->insert( mAction.close );
-  mAction.fileMenu->insert( mAction.separator );
-  mAction.fileMenu->insert( mAction.print );
-  mAction.fileMenu->insert( mAction.exportData );
-  mAction.fileMenu->insert( mAction.separator );
-  mAction.fileMenu->insert( mAction.cancel );
-  // File-Permissions-Start
-  mAction.permissionMenu->insert( mAction.readOnly );
-  mAction.permissionMenu->insert( mAction.resizeLock );
-  // File-Permissions-Stop
-  mAction.fileMenu->insert( mAction.permissionMenu );
-  mAction.fileMenu->insert( mAction.separator );
-  mAction.fileMenu->insert( mAction.newWindow );
-  mAction.fileMenu->insert( mAction.closeWindow );
-  mAction.fileMenu->insert( mAction.separator );
-  mAction.fileMenu->insert( mAction.quit );
-
-  // Edit menu
-  mAction.editMenu->insert( mAction.undo );
-  mAction.editMenu->insert( mAction.redo );
-  mAction.editMenu->insert( mAction.separator );
-  mAction.editMenu->insert( mAction.cut );
-  mAction.editMenu->insert( mAction.copy );
-  mAction.editMenu->insert( mAction.paste );
-  // Edit-special-Start
-  mAction.editSpecialMenu->insert( mAction.copyAsText );
-  mAction.editSpecialMenu->insert( mAction.separator );
-  mAction.editSpecialMenu->insert( mAction.pasteToNewFile );
-  mAction.editSpecialMenu->insert( mAction.pasteToNewWindow );
-  // Edit-special-Stop
-  mAction.editMenu->insert( mAction.editSpecialMenu );
-  mAction.editMenu->insert( mAction.separator );
-  mAction.editMenu->insert( mAction.selectAll );
-  mAction.editMenu->insert( mAction.unselect );
-  mAction.editMenu->insert( mAction.separator );
-  mAction.editMenu->insert( mAction.find );
-  mAction.editMenu->insert( mAction.findNext );
-  mAction.editMenu->insert( mAction.findPrev );
-  mAction.editMenu->insert( mAction.replace );
-  mAction.editMenu->insert( mAction.separator );
-  mAction.editMenu->insert( mAction.gotoOffset );
-  mAction.editMenu->insert( mAction.insertPattern );
-
-  // View menu
-  mAction.viewMenu->insert( mAction.hexadecimal );
-  mAction.viewMenu->insert( mAction.decimal );
-  mAction.viewMenu->insert( mAction.octal );
-  mAction.viewMenu->insert( mAction.binary );
-  mAction.viewMenu->insert( mAction.textOnly );
-  mAction.viewMenu->insert( mAction.separator );
-  mAction.viewMenu->insert( mAction.showOffsetColumn );
-  mAction.viewMenu->insert( mAction.showTextColumn );
-  mAction.viewMenu->insert( mAction.separator );
-  mAction.viewMenu->insert( mAction.offsetAsDecimal );
-  mAction.viewMenu->insert( mAction.separator );
-  mAction.viewMenu->insert( mAction.dataUppercase );
-  mAction.viewMenu->insert( mAction.offsetUppercase );
-  mAction.viewMenu->insert( mAction.separator );
-  // View-encoding-Start
-  mAction.encodingMenu->insert( mAction.defaultEncoding );
-  mAction.encodingMenu->insert( mAction.usAsciiEncoding );
-  mAction.encodingMenu->insert( mAction.ebcdicEncoding );
-//  mAction.encodingMenu->insert( mAction.separator );
-//  mAction.encodingMenu->insert( mAction.customEncoding );
-  // View-encoding-Stop
-  mAction.viewMenu->insert( mAction.encodingMenu );
-
-  // Tools menu
-  mAction.toolsMenu->insert( mAction.strings );
-  //mAction.toolsMenu->insert( mAction.recordViewer );
-  mAction.toolsMenu->insert( mAction.filter );
-  mAction.toolsMenu->insert( mAction.characterTable );
-  mAction.toolsMenu->insert( mAction.converter );
-  mAction.toolsMenu->insert( mAction.separator );
-  mAction.toolsMenu->insert( mAction.statistics );
-
-  // Bookmark menu
-  mAction.bookmarkMenu->insert( mAction.addBookmark );
-  mAction.bookmarkMenu->insert( mAction.replaceBookmark );
-  mAction.bookmarkMenu->insert( mAction.removeBookmark );
-  mAction.bookmarkMenu->insert( mAction.removeAllBookmark );
-  mAction.bookmarkMenu->insert( mAction.separator );
-  mAction.bookmarkMenu->insert( mAction.nextBookmark );
-  mAction.bookmarkMenu->insert( mAction.prevBookmark );
-
-  // Documents menu
-  connect( mAction.documentsMenu->popupMenu(), SIGNAL(activated(int)),
-	   SLOT(documentMenuCB(int)) );
-
-  mAction.settingsMenu->insert( mAction.showToolBar );
-  mAction.settingsMenu->insert( mAction.showStatusBar );
-  mAction.settingsMenu->insert( mAction.showFullPath );
-  mAction.settingsMenu->insert( mAction.separator );
-  // Options-DocumentTabs-Start
-  mAction.documentTabsMenu->insert( mAction.tabHide );
-  mAction.documentTabsMenu->insert( mAction.tabShowAboveEditor );
-  mAction.documentTabsMenu->insert( mAction.tabShowBelowEditor );
-  // Options-DocumentTabs-Stop
-  mAction.settingsMenu->insert( mAction.documentTabsMenu );
-  // Options-Conversion-Start
-  mAction.conversionMenu->insert( mAction.conversionHide );
-  mAction.conversionMenu->insert( mAction.conversionFloat );
-  mAction.conversionMenu->insert( mAction.conversionEmbed );
-  // Options-Conversion-Stop
-  mAction.settingsMenu->insert( mAction.conversionMenu );
-  // Options-SearchBar-Start
-  mAction.searchBarMenu->insert( mAction.searchHide );
-  mAction.searchBarMenu->insert( mAction.searchShowAboveEditor );
-  mAction.searchBarMenu->insert( mAction.searchShowBelowEditor );
-  // Options-SearchBar-Stop
-  mAction.settingsMenu->insert( mAction.searchBarMenu );
-
-  mAction.settingsMenu->insert( mAction.writeConfiguration );
-  mAction.settingsMenu->insert( mAction.separator );
-  mAction.settingsMenu->insert( mAction.preferences );
-  //mAction.settingsMenu->insert( mAction.favorites );
-
-  //
-  // Make the menubar.
-  //
-  mAction.fileMenu->plug( menuBar() );
-  mAction.editMenu->plug( menuBar() );
-  mAction.viewMenu->plug( menuBar() );
-  mAction.bookmarkMenu->plug( menuBar() );
-  mAction.toolsMenu->plug( menuBar() );
-  mAction.documentsMenu->plug( menuBar() );
-  mAction.settingsMenu->plug( menuBar() );
-  mAction.separator->plug( menuBar() );
-  menuBar()->insertItem( i18n("&Help"), helpMenu(0, false) );
-
-  //
-  // Make the toolbar
-  //
-  toolBar(0)->setFullSize();
-  mDragLabel = new CDragLabel( toolBar(0) );
+  mDragLabel = new CDragLabel(this);
   mDragLabel->setPixmap( UserIcon( "hexdrag" ) );
   mDragLabel->setDragMask( UserIcon( "hexmask" ) );
   mDragLabel->setEnabled( false ); // Enabled once we open a document
   QToolTip::add( mDragLabel, i18n("Drag document") );
-  toolBar(0)->insertWidget( -1, 22, mDragLabel );
+ (void) new KWidgetAction(mDragLabel, i18n("Drag Document"), 0, editor(), SLOT(options()), actionCollection(), "drag_document");
 
-  mAction.newFile->plug( toolBar(0) );
-  mAction.open->plug( toolBar(0) );
-  mAction.revert->plug( toolBar(0) );
-  mAction.save->plug( toolBar(0) );
-  mAction.print->plug( toolBar(0) );
-  mAction.find->plug( toolBar(0) );
-  mAction.findNext->plug( toolBar(0) );
-  mAction.findPrev->plug( toolBar(0) );
-  mAction.cut->plug( toolBar(0) );
-  mAction.copy->plug( toolBar(0) );
-  mAction.paste->plug( toolBar(0) );
-  mAction.undo->plug( toolBar(0) );
-  mAction.redo->plug( toolBar(0) );
-  mAction.cancel->plug( toolBar(0) );
-  mAction.help->plug( toolBar(0) );
+  createGUI("khexeditui.rc", false);
+
+  QPopupMenu *popup = (QPopupMenu *)factory()->container("editor_popup", this);
+  hexView()->setPopupMenu( popup );
 
   int id = 100;
   toolBar(0)->insertButton( MainBarIcon("lock"), id, SIGNAL(clicked()),
@@ -502,6 +306,16 @@ void KHexEdit::setupActions( void )
     i18n("Toggle write protection") );
   toolBar(0)->alignItemRight( id );
   mWriteProtectButton = toolBar(0)->getButton(id);
+
+  QPopupMenu *documentMenu = (QPopupMenu *)factory()->container("documents", this);
+  hexView()->setDocumentMenu(documentMenu);
+  connect(documentMenu, SIGNAL(activated(int)), SLOT(documentMenuCB(int)));
+}
+
+
+void KHexEdit::slotConfigureKeys()
+{
+  KKeyDialog::configure( actionCollection(), this );
 }
 
 
@@ -564,11 +378,7 @@ void KHexEdit::initialize( bool openFiles )
 
   editor()->initialize();
 
-  mAction.showToolBar->setChecked( mShowToolBar );
-  mAction.showStatusBar->setChecked( mShowStatusBar );
   mAction.showFullPath->setChecked( mShowFullPath );
-  showToolBar();
-  showStatusBar();
   showFullPath();
 
 
@@ -629,6 +439,10 @@ void KHexEdit::statusBarPressed( int id )
   {
     editor()->toggleWriteProtection();
   }
+  else if( id == status_Ovr )
+  {
+    editor()->toggleInsertMode();
+  }
   else if( id == status_Offset )
   {
     editor()->toggleOffsetAsDecimal();
@@ -836,7 +650,7 @@ void KHexEdit::closeProgram( void )
 	QString msg = i18n(""
 	  "There are windows with unsaved modified documents. "
 	  "If you quit now, these modifications will be lost.");
-	int reply = KMessageBox::warningContinueCancel( topLevelWidget(), msg, QString::null, i18n("&Quit") );
+	int reply = KMessageBox::warningContinueCancel( topLevelWidget(), msg, QString::null, KStdGuiItem::quit() );
 	if( reply == KMessageBox::Continue )
 	{
 	  break;
@@ -963,11 +777,10 @@ void KHexEdit::writeConfiguration( void )
 
 void KHexEdit::writeConfiguration( KConfig &config )
 {
+    saveMainWindowSettings(& config, "General Options");
   config.setGroup("General Options" );
   config.writeEntry("Width", width() );
   config.writeEntry("Height", height() );
-  config.writeEntry("ShowToolBar", mShowToolBar );
-  config.writeEntry("ShowStatusBar", mShowStatusBar );
   config.writeEntry("ShowFullPath",  mShowFullPath );
   config.writeEntry("ConversionPosition", (int)mManager->conversionPosition());
   config.writeEntry("TabBarPosition", (int)mManager->tabBarPosition());
@@ -975,7 +788,7 @@ void KHexEdit::writeConfiguration( KConfig &config )
 
   for( uint i=0; i < mExitFileList.count(); i++ )
   {
-    config.writeEntry( QString("Recent%1").arg(i+1), *mExitFileList.at(i) );
+    config.writePathEntry( QString("Recent%1").arg(i+1), *mExitFileList.at(i) );
   }
   config.writeEntry( QString("Offset"), mExitOffsetList );
 
@@ -988,9 +801,9 @@ void KHexEdit::writeConfiguration( KConfig &config )
 
 void KHexEdit::readConfiguration( KConfig &config )
 {
-  config.setGroup("General Options");
-  mShowToolBar    = config.readBoolEntry( "ShowToolBar", true );
-  mShowStatusBar  = config.readBoolEntry( "ShowStatusBar", true );
+    applyMainWindowSettings(& config, "General Options");
+
+    config.setGroup("General Options");
   mShowFullPath   = config.readBoolEntry( "ShowFullPath", true );
   int position    = config.readNumEntry( "ConversionPosition",
 					 CHexManagerWidget::Embed );
@@ -1042,7 +855,7 @@ void KHexEdit::readConfiguration( KConfig &config )
 
   for( uint i = 0; i < 5; i++ )
   {
-    QString fileName = config.readEntry( QString("Recent%1").arg(i+1) );
+    QString fileName = config.readPathEntry( QString("Recent%1").arg(i+1) );
     if( fileName.isEmpty() == false )
     {
       int pos = mAction.openRecent->popupMenu()->count();
@@ -1243,30 +1056,16 @@ void KHexEdit::inputModeChanged( const SDisplayInputMode &mode )
 
 void KHexEdit::bookmarkChanged( QPtrList<SCursorOffset> &list )
 {
-  QPopupMenu *menu  = mAction.bookmarkMenu->popupMenu();
-  QPopupMenu *popup = mAction.bookmarkPopup->popupMenu();
-
-  if( menu->count() == 4 && list.count() == 0 )
-  {
-    return;
-  }
-
-  menu->clear();
-  popup->clear();
-
-  mAction.bookmarkMenu->insert( mAction.addBookmark );
-  mAction.bookmarkMenu->insert( mAction.replaceBookmark );
-  mAction.bookmarkMenu->insert( mAction.removeBookmark );
-  mAction.bookmarkMenu->insert( mAction.removeAllBookmark );
-  mAction.bookmarkMenu->insert( mAction.separator );
-  mAction.bookmarkMenu->insert( mAction.nextBookmark );
-  mAction.bookmarkMenu->insert( mAction.prevBookmark );
+  unplugActionList("bookmark_list");
+  mAction.bookmarkList.setAutoDelete(true);
+  mAction.bookmarkList.clear();
 
   if( list.count() == 0 )
   {
     return;
   }
-  mAction.bookmarkMenu->insert( mAction.separator );
+
+  mAction.bookmarkList.append(new KActionSeparator());
 
   QString text, offset;
   int i=0;
@@ -1275,31 +1074,29 @@ void KHexEdit::bookmarkChanged( QPtrList<SCursorOffset> &list )
   {
     offset.sprintf("%04X:%04X", p->offset>>16, p->offset&0x0000FFFF );
     text = i18n("Offset: %1").arg(offset);
-
-    menu->insertItem( text, i );
-    menu->connectItem( i, editor(), SLOT(gotoBookmark(int)) );
+    KAction *action = new KAction(text, 0, mAction.bookmarkMapper, SLOT(map()), this, text.latin1());
     int key = acceleratorNumKey( i );
     if( key > 0 )
     {
-      menu->setAccel( ALT+key, i );
+      action->setShortcut(KShortcut(ALT+key));
     }
-
-    popup->insertItem( QString("[%1] %2").arg(i+1).arg(text), i );
-    popup->connectItem( i, editor(), SLOT(gotoBookmark(int)) );
+    mAction.bookmarkMapper->setMapping(action, i);
+    mAction.bookmarkList.append(action);
   }
+  plugActionList("bookmark_list", mAction.bookmarkList);
 }
 
 
 void KHexEdit::setupCaption( const QString &url )
 {
+  KURL u(url);
   if( mShowFullPath == true )
   {
-    setCaption( url, hexView()->modified() );
+    setCaption( u.prettyURL(), hexView()->modified() );
   }
   else
   {
-    QString n = url;
-    setCaption( n.right(n.length()-n.findRev('/')-1), hexView()->modified() );
+    setCaption( u.fileName(), hexView()->modified() );
   }
 }
 
@@ -1412,34 +1209,6 @@ void KHexEdit::setDisplayMode( void )
 }
 
 
-void KHexEdit::showToolBar( void )
-{
-  mShowToolBar = mAction.showToolBar->isChecked();
-  if( mShowToolBar == true )
-  {
-    toolBar()->show();
-  }
-  else
-  {
-    toolBar()->hide();
-  }
-}
-
-
-void KHexEdit::showStatusBar( void )
-{
-  mShowStatusBar = mAction.showStatusBar->isChecked();
-  if( mShowStatusBar == true )
-  {
-    statusBar()->show();
-  }
-  else
-  {
-    statusBar()->hide();
-  }
-}
-
-
 void KHexEdit::showFullPath( void )
 {
   mShowFullPath = mAction.showFullPath->isChecked();
@@ -1595,7 +1364,7 @@ void KHexEdit::addDocument( const QString &fileName )
 
   mDocumentList.append( fileName );
 
-  QPopupMenu *documentMenu = mAction.documentsMenu->popupMenu();
+  QPopupMenu *documentMenu = (QPopupMenu *)factory()->container("documents", this);
   documentMenu->insertItem( fileName, documentCount, documentCount );
   int key = acceleratorNumKey( documentCount );
   if( key > 0 )
@@ -1612,7 +1381,7 @@ void KHexEdit::removeDocument( const QString &fileName )
   {
     if( *it == fileName )
     {
-      QPopupMenu *documentMenu = mAction.documentsMenu->popupMenu();
+      QPopupMenu *documentMenu = (QPopupMenu *)factory()->container("documents", this);
 
       documentMenu->removeItemAt( mDocumentList.findIndex(*it) );
       mDocumentList.remove( it );
@@ -1640,7 +1409,7 @@ void KHexEdit::renameDocument( const QString &curName, const QString &newName )
   {
     if( *it == curName )
     {
-      QPopupMenu *documentMenu = mAction.documentsMenu->popupMenu();
+      QPopupMenu *documentMenu = (QPopupMenu *)factory()->container("documents", this);
       documentMenu->changeItem( newName, mDocumentList.findIndex(*it) );
       mDocumentList.insert( it, newName );
       mDocumentList.remove( it );
@@ -1653,7 +1422,7 @@ void KHexEdit::renameDocument( const QString &curName, const QString &newName )
 void KHexEdit::setTickedDocument( const QString &fileName )
 {
   uint documentCount = mDocumentList.count();
-  QPopupMenu *documentMenu = mAction.documentsMenu->popupMenu();
+  QPopupMenu *documentMenu = (QPopupMenu *)factory()->container("documents", this);
   for( uint i=0; i < documentCount; i++ )
   {
     documentMenu->setItemChecked( i, fileName == mDocumentList[i] );
@@ -1678,7 +1447,7 @@ bool KHexEdit::eventFilter( QObject *o, QEvent *event )
   if( event->type() == QEvent::DragEnter )
   {
     QDragEnterEvent *e = (QDragEnterEvent*)event;
-    if( QUriDrag::canDecode(e) )
+    if( KURLDrag::canDecode(e) )
     {
       e->accept();
       hexView()->setDropHighlight( true );
@@ -1690,10 +1459,12 @@ bool KHexEdit::eventFilter( QObject *o, QEvent *event )
     QMimeSource &m = *(QDropEvent*)event;
     hexView()->setDropHighlight( false );
 
-    QStringList list, offset;
-    if( QUriDrag::decodeToUnicodeUris( &m, list ) == true )
+    KURL::List list;
+    if( KURLDrag::decode( &m, list ) == true )
     {
-      open( list, offset );
+      QStringList offset;
+      QStringList urlList = list.toStringList();
+      open( urlList, offset );
       return( true );
     }
     return( true );
