@@ -14,7 +14,7 @@
  *
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  */
 
@@ -25,6 +25,7 @@
 #include <config.h>
 #endif
 
+#include <qptrlist.h>
 #include <kapplication.h>
 #include <kstdaccel.h>
 #include <kmainwindow.h>
@@ -33,9 +34,8 @@
 #include "hexmanagerwidget.h"
 #include "statusbarprogress.h"
 
+class QSignalMapper;
 class KAction;
-class KActionMenu;
-class KActionSeparator;
 class KRecentFilesAction;
 class KRadioAction;
 class KSelectAction;
@@ -62,24 +62,6 @@ class KHexEdit : public KMainWindow
 
   struct SActionList
   {
-    KActionMenu *permissionMenu;
-    KActionMenu *editSpecialMenu;
-    KActionMenu *encodingMenu;
-    KActionMenu *conversionMenu;
-    KActionMenu *documentTabsMenu;
-    KActionMenu *searchBarMenu;
-    KActionMenu *fileMenu;
-    KActionMenu *editMenu;
-    KActionMenu *viewMenu;
-    KActionMenu *bookmarkMenu;
-    KActionMenu *toolsMenu;
-    KActionMenu *documentsMenu;
-    KActionMenu *settingsMenu;
-    KActionMenu *filePopup;
-    KActionMenu *bookmarkPopup;
-
-    KAction *newFile;
-    KAction *open;
     KAction *insert;
     KRecentFilesAction *openRecent;
     KAction *save;
@@ -123,10 +105,10 @@ class KHexEdit : public KMainWindow
     KRadioAction *defaultEncoding;
     KRadioAction *usAsciiEncoding;
     KRadioAction *ebcdicEncoding;
-    KAction *customEncoding;
+//     KAction *customEncoding;
 
     KAction *strings;
-    KAction *recordViewer;
+//     KAction *recordViewer;
     KAction *filter;
     KAction *characterTable;
     KAction *converter;
@@ -139,8 +121,6 @@ class KHexEdit : public KMainWindow
     KAction *nextBookmark;
     KAction *prevBookmark;
 
-    KToggleAction *showToolBar;
-    KToggleAction *showStatusBar;
     KToggleAction *showFullPath;
     KRadioAction *tabHide;
     KRadioAction *tabShowBelowEditor;
@@ -152,12 +132,10 @@ class KHexEdit : public KMainWindow
     KRadioAction *searchShowAboveEditor;
     KRadioAction *searchShowBelowEditor;
 
-    KAction *writeConfiguration;
-    KAction *preferences;
-    KAction *favorites;
+//     KAction *favorites;
 
-    KAction *help;
-    KActionSeparator *separator;
+    QPtrList< KAction > bookmarkList;
+    QSignalMapper *bookmarkMapper;
   };
 
   public:
@@ -195,8 +173,6 @@ class KHexEdit : public KMainWindow
     void textWidth( uint width );
 
     void setDisplayMode( void );
-    void showToolBar( void );
-    void showStatusBar( void );
     void showFullPath( void );
     void showDocumentTabs( void );
     void showConversionField( void );
@@ -204,8 +180,9 @@ class KHexEdit : public KMainWindow
 
     void setEncoding( void );
     void documentMenuCB( int id );
-   
-  protected:
+    void slotConfigureKeys();
+
+protected:
     virtual bool queryExit( void );
     virtual bool queryClose( void );
 
@@ -242,29 +219,27 @@ class KHexEdit : public KMainWindow
     inline CHexEditorWidget *editor( void );
     inline CHexToolWidget *converter( void );
     inline CHexViewWidget *hexView( void );
-    
+
   private:
     static QPtrList<KHexEdit> mWindowList;
     CHexManagerWidget *mManager;
     QStringList mDocumentList;
- 
+
     QStringList mStartupFileList;   // Files to automatically open on startup
     QStringList mStartupOffsetList; // Start offset for those files.
 
     QStringList mExitFileList;      // Stores "Recent" file order on exit.
-    QStringList mExitOffsetList;    // Stores "Recent" file offset on exit. 
+    QStringList mExitOffsetList;    // Stores "Recent" file offset on exit.
 
     QStringList mRecentOffsetList;  // Values read from config. file
     uint        mStartupOffset;     // Value read from commandline
 
     SActionList mAction;
-    
+
     CDragLabel     *mDragLabel;
     KToolBarButton *mWriteProtectButton;
 
     bool mIsModified;
-    bool mShowToolBar;
-    bool mShowStatusBar;
     bool mShowFullPath;
     bool mSelectionAsHexadecimal;
     uint mSelectionOffset;
