@@ -18,7 +18,7 @@
 //
 //  You should have received a copy of the GNU General Public License
 //  along with this program; if not, write to the Free Software
-//  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 //
 
 #ifdef HAVE_CONFIG_H
@@ -27,8 +27,6 @@
 
 #include <stdlib.h>
 #include <kuniqueapplication.h>
-#include <kiconloader.h>
-#include <klocale.h>
 #include <kcmdlineargs.h>
 #include <kconfig.h>
 #include <kaboutdata.h>
@@ -36,17 +34,9 @@
 #include "KJotsMain.h"
 
 
-static const char *description = 
-	I18N_NOOP("KDE Note taking utility");
+static const char description[] = I18N_NOOP("KDE Note taking utility");
 
-static const char *version = "v0.4"; 
-
-
-KJotsMain *main_widget;
-KIconLoader *global_pix_loader;
-
-QString exec_http;
-QString exec_ftp;
+static const char version[] = "v0.5";
 
 
 int main( int argc, char **argv )
@@ -55,49 +45,52 @@ int main( int argc, char **argv )
     version, description, KAboutData::License_GPL,
     "(c) 1997-2002, Christoph Neerfeld");
   aboutData.addAuthor("Aaron J. Seigo", I18N_NOOP("Current maintainer"), "aseigo@olympusproject.org");
+  aboutData.addAuthor("Stanislav Kljuhhin", 0, "crz@starman.ee");
   aboutData.addAuthor("Christoph Neerfeld", I18N_NOOP("Original author"), "chris@kde.org");
   KCmdLineArgs::init(argc, argv, &aboutData);
   KUniqueApplication::addCmdLineOptions();
-  
-  if (!KUniqueApplication::start()) 
+
+  if (!KUniqueApplication::start())
   {
      fprintf(stderr, "kjots is already running!\n");
      exit(0);
-  }  
-  
+  }
+
   KUniqueApplication a;
 
-  QString temp1, temp2;
+  // backwards compatibility code to convert "old" user font settings
+  // to the new config settings
   KConfig *config = a.config();
   config->setGroup("kjots");
-  if( !config->hasKey("execHttp") )
-    config->writeEntry("execHttp", "kfmclient openURL %u");
-  if( !config->hasKey("execFtp") )
-    config->writeEntry("execFtp", "kfmclient openURL %u");
-  if( !config->hasKey("EFontFamily") )
-    config->writeEntry("EFontFamily", "helvetica");
-  if( !config->hasKey("EFontSize") )
-    config->writeEntry("EFontSize", 12);
-  if( !config->hasKey("EFontWeight") )
-    config->writeEntry("EFontWeight", 0);
-  if( !config->hasKey("EFontItalic") )
-    config->writeEntry("EFontItalic", 0);
-  if( !config->hasKey("EFontCharset") )
-    config->writeEntry("EFontCharset", 0);
-  config->sync();
-  global_pix_loader = new KIconLoader();
+  if (config->hasKey("EFontFamily")) {
+    // read old font and create it
+    QFont font( config->readEntry("EFontFamily"),
+                config->readNumEntry("EFontSize", 12),
+                config->readNumEntry("EFontWeight", 0),
+                config->readNumEntry("EFontItalic", 0));
+    // delete old entries
+    config->deleteEntry("EFontFamily");
+    config->deleteEntry("EFontSize");
+    config->deleteEntry("EFontWeight");
+    config->deleteEntry("EFontItalic");
+    config->deleteEntry("EFontCharset");
+    // write new "converted" entry
+    config->writeEntry("Font", font);
+  }
+
   KJotsMain *jots = new KJotsMain;
   if( a.isRestored() )
+  {
+    if( KJotsMain::canBeRestored(1) )
     {
-      if( KJotsMain::canBeRestored(1) )
-	{
-          jots->restore(1);
-	}
+      jots->restore(1);
     }
-  main_widget = jots;
+  }
+
   a.setMainWidget( (QWidget *) jots );
   jots->show();
   jots->resize(jots->size());
   return a.exec();
 }
 
+/* ex: set tabstop=4 softtabstop=4 shiftwidth=4 expandtab: */
