@@ -6,7 +6,7 @@
  *
  * This file contains the docked widget for the laptop battery monitor
  *
- * $Id: daemondock.h,v 1.10 2002/09/25 13:07:22 cumming Exp $
+ * $Id: daemondock.h,v 1.19 2003/03/07 22:06:50 waba Exp $
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
 
@@ -31,6 +31,9 @@ class laptop_daemon;
 class KPCMCIA;
 class KPCMCIACard;
 class QPopupMenu;
+class QVBox;
+class QSlider;
+class KPopupMenu;
 
 #include <qmap.h>
 
@@ -46,9 +49,12 @@ public:
   void mousePressEvent( QMouseEvent * ); 
   void mouseReleaseEvent( QMouseEvent * ); 
   void showEvent( QShowEvent * );  
+  void reload_icon();
 
   inline void setPCMCIA(KPCMCIA *p) { _pcmcia = p; }
 
+  void SetupPopup();
+
 private slots:
   void invokeStandby();
   void invokeSuspend();
@@ -56,7 +62,8 @@ private slots:
   void invokeHibernation();
   void invokeLockHibernation();
   void invokeSetup();
-  void noop();
+  void invokeBrightness();
+  void invokeBrightnessSlider(int v);
 
   void slotEjectAction(int id);
   void slotResumeAction(int id);
@@ -65,13 +72,24 @@ private slots:
   void slotResetAction(int id);
   void slotDisplayAction(int id);
 
+  void activate_throttle(int ind);
+  void fill_throttle();
+  void activate_performance(int ind);
+  void fill_performance();
+
+
   void rootExited(KProcess *p);
   void slotGoRoot(int id);
   void slotQuit();
+  void slotHide();
 
 private:
+  int brightness;
+  QVBox *brightness_widget;
+  QSlider *brightness_slider;
   laptop_daemon *pdaemon;
   QPixmap	pm;
+  QPopupMenu	*performance_popup, *throttle_popup;
   int	 	current_code;
   KPCMCIA       *_pcmcia;
   QMap<int,KPCMCIACard *> _ejectActions,
@@ -81,6 +99,9 @@ private:
                           _displayActions,
                           _insertActions;
 
+  KInstance 	*instance; 	// handle so we get our pretty icons right
+  KPopupMenu 	*rightPopup;
+
 }; 
 #endif 
 
