@@ -1,32 +1,57 @@
+/*
+ *  Copyright (c) 2002-2003 Jesper K. Pedersen <blackie@kde.org>
+ *
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Library General Public
+ *  License version 2 as published by the Free Software Foundation.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Library General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Library General Public License
+ *  along with this library; see the file COPYING.LIB.  If not, write to
+ *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ *  Boston, MA 02111-1307, USA.
+ **/
+
+#ifdef QT_ONLY
+#include "compat.h"
+#else
+#include <klocale.h>
+#include "charselector.moc"
+#endif
+
 #include "charselector.h"
 #include <qwidgetstack.h>
 #include <limitedcharlineedit.h>
-#include <klocale.h>
 #include <qcombobox.h>
 #include <qstringlist.h>
+#include "regexpconverter.h"
 
 /**
    In the class CharSelector, three LimitedCharLineEdit are used.
    These widgets are all used in a QWidgetStack. The LimitedCharLineEdit
-   class is basicly a QLineEdit, which is limited to a certain
+   class is basically a QLineEdit, which is limited to a certain
    number of characters. This conflicts with the QWidgetStack, as this
    class expects the widgets on the stack to take up all space.
    StackContainer fills in this gab.
 */
 class StackContainer :public QWidget
 {
- public:
-  StackContainer( QWidget* child, QWidget* parent ) : QWidget( parent )
-    {
-      QHBoxLayout* layout = new QHBoxLayout( this );
-      child->reparent( this, QPoint(0,0), false );
-      layout->addWidget( child );
-      layout->addStretch( 1 );
-    }
+public:
+    StackContainer( QWidget* child, QWidget* parent ) : QWidget( parent )
+        {
+            QHBoxLayout* layout = new QHBoxLayout( this );
+            child->reparent( this, QPoint(0,0), false );
+            layout->addWidget( child );
+            layout->addStretch( 1 );
+        }
 };
 
 CharSelector::CharSelector( QWidget* parent, const char* name )
-  :QWidget( parent, name ), _oldIndex(0)
+    :QWidget( parent, name ), _oldIndex(0)
 {
   QStringList items;
   QHBoxLayout* layout = new QHBoxLayout( this, 0, 6 );
@@ -44,32 +69,32 @@ CharSelector::CharSelector( QWidget* parent, const char* name )
         << i18n("The Vertical Tab Character (\\v)");
   _type->insertStringList( items );
   layout->addWidget( _type );
-  
+
   _stack = new QWidgetStack( this, "_stack" );
   layout->addWidget( _stack );
 
   _normal = new LimitedCharLineEdit( LimitedCharLineEdit::NORMAL, 0, "_normal" );
   _stack->addWidget( new StackContainer( _normal, _stack ), 0 );
-  
+
   _hex = new LimitedCharLineEdit( LimitedCharLineEdit::HEX, _stack, "_hex" );
   _stack->addWidget( new StackContainer( _hex, _stack ), 1 );
-  
+
   _oct = new LimitedCharLineEdit( LimitedCharLineEdit::OCT, _stack, "_oct" );
   _stack->addWidget( new StackContainer( _oct, _stack ), 2 );
 
   _stack->raiseWidget( 0 );
-  
+
   connect( _type, SIGNAL( activated( int ) ), this, SLOT(slotNewItem( int ) ) );
 }
 
-void CharSelector::slotNewItem( int which ) 
+void CharSelector::slotNewItem( int which )
 {
   _type->setCurrentItem( which );
   if ( which <= 2 ) {
     _stack->raiseWidget( which );
     _normal->setEnabled( true );
     _hex->setEnabled( true );
-    _oct->setEnabled( true );    
+    _oct->setEnabled( true );
   }
   else if ( which == 3 ) {
     _type->setCurrentItem( _oldIndex );
@@ -79,14 +104,21 @@ void CharSelector::slotNewItem( int which )
   else {
     _normal->setEnabled( false );
     _hex->setEnabled( false );
-    _oct->setEnabled( false );    
+    _oct->setEnabled( false );
   }
 
-  _oldIndex = which;
+    _oldIndex = which;
 }
 
 void CharSelector::setText( QString text )
 {
+    // This is the best I can do about missing character range features, unless all of
+    // textrangeregexp is to be reworked. The problem is that textrangeregexp only allows to
+    // get the characters, which would be something like \a, but \a does not work with say Emacs
+    // style regexps -- ko28 Sep. 2003 10:55 -- Jesper K. Pedersen
+    bool enabled = ( RegExpConverter::current()->features() & RegExpConverter::ExtRange );
+    _type->setEnabled( enabled );
+
   if ( text.at(0) == QChar('\\') ) {
     if ( text.at(1) == QChar('x') ) {
       _hex->setText(text.mid(2));
@@ -148,8 +180,6 @@ QString CharSelector::text() const
     return QString::fromLatin1("\\t");
   case 9:
     return QString::fromLatin1("\\v");
-  }    
+  }
   return QString::null;
 }
-
-#include "charselector.moc"
