@@ -1,17 +1,40 @@
+/*
+ *  Copyright (c) 2002-2003 Jesper K. Pedersen <blackie@kde.org>
+ *
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Library General Public
+ *  License version 2 as published by the Free Software Foundation.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Library General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Library General Public License
+ *  along with this library; see the file COPYING.LIB.  If not, write to
+ *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ *  Boston, MA 02111-1307, USA.
+ **/
+#ifdef QT_ONLY
+  #include "compat.h"
+#else
+  #include <klineeditdlg.h>
+  #include <klocale.h>
+  #include <kmessagebox.h>
+  #include <kstandarddirs.h>
+  #include <kdebug.h>
+  #include "userdefinedregexps.moc"
+#endif
+
 #include "userdefinedregexps.h"
 #include <qheader.h>
 #include <qpopupmenu.h>
-#include <klineeditdlg.h>
 #include "regexp.h"
-#include <kmessagebox.h>
 #include <qdir.h>
-#include <klocale.h>
 #include "widgetfactory.h"
-#include <kstandarddirs.h>
 #include <qtooltip.h>
 #include <qwhatsthis.h>
 #include "compoundregexp.h"
-#include <kdebug.h>
 #include <qlayout.h>
 #include <qlabel.h>
 
@@ -23,7 +46,7 @@ UserDefinedRegExps::UserDefinedRegExps( QWidget *parent, const char *name )
   lay->setAutoAdd( true );
 
   QLabel* label = new QLabel( i18n("Compound regular expression:"), top );
-  
+
   // This is to avoid that the label set the minimum width for the window.
   label->setMinimumSize(1,0);
 
@@ -33,7 +56,7 @@ UserDefinedRegExps::UserDefinedRegExps( QWidget *parent, const char *name )
   //  _userDefined->setRootIsDecorated( true );
   setWidget( top );
   slotPopulateUserRegexps();
-  
+
   connect( _userDefined, SIGNAL(clicked(QListViewItem*)), this, SLOT(slotLoad(QListViewItem*)) );
   connect( _userDefined, SIGNAL(rightButtonPressed(QListViewItem*,const QPoint&, int )),
            this, SLOT( slotEdit( QListViewItem*, const QPoint& ) ) );
@@ -45,8 +68,14 @@ void UserDefinedRegExps::slotPopulateUserRegexps()
   _regExps.clear();
 
   createItems( i18n("User Defined"), WidgetWinItem::path(), true );
-  
+
+#ifdef QT_ONLY
+  QStringList dirs;
+  dirs << QString::fromLatin1( "predefined" );
+#else
   QStringList dirs = KGlobal::dirs()->findDirs( "data", QString::fromLocal8Bit("kregexpeditor/predefined/") );
+#endif
+
   for ( QStringList::iterator it1 = dirs.begin(); it1 != dirs.end(); ++it1 ) {
     QDir dir( *it1, QString::null, QDir::Name, QDir::Dirs );
     QStringList subdirs = dir.entryList();
@@ -56,10 +85,10 @@ void UserDefinedRegExps::slotPopulateUserRegexps()
       createItems( *it2, *it1 + QString::fromLocal8Bit("/") + *it2, false );
     }
   }
-  
+
 }
 
-void UserDefinedRegExps::createItems( const QString& _title, const QString& dir, bool usersRegExp ) 
+void UserDefinedRegExps::createItems( const QString& _title, const QString& dir, bool usersRegExp )
 {
   QString title = _title;
   if (_title == QString::fromLatin1("general"))
@@ -67,7 +96,7 @@ void UserDefinedRegExps::createItems( const QString& _title, const QString& dir,
 
   QListViewItem* lvItem = new QListViewItem( _userDefined, title );
   lvItem->setOpen( true );
-  
+
   QDir directory( dir );
   QStringList files = directory.entryList( QString::fromLocal8Bit("*.regexp") );
   for ( QStringList::Iterator it = files.begin(); it != files.end(); ++it ) {
@@ -94,13 +123,13 @@ void UserDefinedRegExps::createItems( const QString& _title, const QString& dir,
     // Inserth the regexp into the list of compound regexps
     if ( regexp->type() == RegExp::COMPOUND ) {
       CompoundRegExp* cregexp = dynamic_cast<CompoundRegExp*>( regexp );
-      if ( cregexp->allowReplace() )
+      if ( cregexp && cregexp->allowReplace() )
         _regExps.append( cregexp );
     }
   }
 }
 
-const QPtrList<CompoundRegExp> UserDefinedRegExps::regExps() const 
+const QPtrList<CompoundRegExp> UserDefinedRegExps::regExps() const
 {
   return _regExps;
 }
@@ -117,16 +146,18 @@ void UserDefinedRegExps::slotLoad(QListViewItem* item)
     // Mouse pressed outside a widget.
     return;
   }
-  
-  RegExp* regexp = dynamic_cast<WidgetWinItem*>(item)->regExp();
-  emit load( regexp );
+
+  WidgetWinItem* wwi = dynamic_cast<WidgetWinItem*>(item);
+  if (wwi) {
+    emit load( wwi->regExp() );
+  }
 }
 
 void UserDefinedRegExps::slotEdit( QListViewItem* item, const QPoint& pos )
 {
   QPopupMenu* menu = new QPopupMenu( this );
   menu->insertItem(i18n("Delete"), 1 );
-  menu->insertItem(i18n("Rename"), 2 );
+  menu->insertItem(i18n("Rename..."), 2 );
   if ( !item || ! dynamic_cast<WidgetWinItem*>( item ) ) {
     // menu not selected on an item
     menu->setItemEnabled( 1, false );
@@ -135,14 +166,14 @@ void UserDefinedRegExps::slotEdit( QListViewItem* item, const QPoint& pos )
   else {
     // Only allow rename and delete of users own regexps.
     WidgetWinItem* winItem = dynamic_cast<WidgetWinItem*>( item );
-    if ( ! winItem->isUsersRegExp() ) {
+    if ( winItem && ! winItem->isUsersRegExp() ) {
       menu->setItemEnabled( 1, false );
       menu->setItemEnabled( 2, false );
     }
   }
-  
+
   int which = menu->exec( pos );
-  
+
   if ( which == 1 ) { // Delete
     WidgetWinItem* winItem = dynamic_cast<WidgetWinItem*>( item );
     Q_ASSERT( winItem );
@@ -155,18 +186,24 @@ void UserDefinedRegExps::slotEdit( QListViewItem* item, const QPoint& pos )
     WidgetWinItem* winItem = dynamic_cast<WidgetWinItem*>( item );
     Q_ASSERT( winItem );
 
-    bool ok = false;
     QString oldFile = winItem->fileName();
     QString oldName = winItem->name();
 
+    QString txt;
+#ifdef QT_ONLY
+    txt = QInputDialog::getText( tr("Rename Regular Expression"), tr("New name:") );
+#else
     KLineEditDlg dlg(i18n("New name:"), oldName, this);
     dlg.setCaption(i18n("Rename Item"));
-
-    if ( dlg.exec() && oldName != dlg.text() ) {
-      QString fileName = WidgetWinItem::path() + QString::fromLocal8Bit("/") + dlg.text() + QString::fromLocal8Bit(".regexp");
+    bool ok = dlg.exec();
+    if ( ok )
+        txt = dlg.text();
+#endif
+    if ( !txt.isNull() && oldName != txt ) {
+      QString fileName = WidgetWinItem::path() + QString::fromLocal8Bit("/") + txt + QString::fromLocal8Bit(".regexp");
       QFileInfo finfo( fileName );
       if ( finfo.exists() ) {
-        int answer = KMessageBox::warningYesNo( this, i18n("<p>Overwrite named regular expression <b>%1</b>?</p>").arg(dlg.text()) );
+        int answer = KMessageBox::warningYesNo( this, i18n("<p>Overwrite named regular expression <b>%1</b>?</p>").arg(txt) );
         if ( answer != KMessageBox::Yes )
           return;
 
@@ -174,7 +211,7 @@ void UserDefinedRegExps::slotEdit( QListViewItem* item, const QPoint& pos )
         delete winItem;
       }
       else
-        winItem->setName( dlg.text() );
+        winItem->setName( txt );
       QDir dir;
       dir.rename( oldFile, fileName  );
     }
@@ -189,7 +226,7 @@ void UserDefinedRegExps::slotSelectNewAction()
   slotUnSelect();
 }
 
-WidgetWinItem::WidgetWinItem( QString fileName, RegExp* regexp, bool usersRegExp, QListViewItem* parent ) 
+WidgetWinItem::WidgetWinItem( QString fileName, RegExp* regexp, bool usersRegExp, QListViewItem* parent )
   :QListViewItem( parent ), _regexp( regexp ), _usersRegExp ( usersRegExp )
 {
   int index = fileName.findRev(QString::fromLocal8Bit(".regexp"));
@@ -198,7 +235,7 @@ WidgetWinItem::WidgetWinItem( QString fileName, RegExp* regexp, bool usersRegExp
   setText( 0, _name );
 }
 
-QString WidgetWinItem::fileName() const 
+QString WidgetWinItem::fileName() const
 {
   return path() + QString::fromLocal8Bit("/") +_name + QString::fromLocal8Bit(".regexp");
 }
@@ -208,22 +245,25 @@ RegExp* WidgetWinItem::regExp() const
   return _regexp;
 }
 
-QString WidgetWinItem::name() const 
+QString WidgetWinItem::name() const
 {
   return _name;
 }
 
-void WidgetWinItem::setName( const QString& nm ) 
+void WidgetWinItem::setName( const QString& nm )
 {
   _name = nm;
   setText( 0, nm );
 }
 
-QString WidgetWinItem::path() 
+QString WidgetWinItem::path()
 {
+#ifdef QT_ONLY
+    return QString::fromLatin1( "predefined" );
+#else
   return locateLocal("data", QString::fromLocal8Bit("KRegExpEditor/"));
+#endif
 }
 
 
 
-#include "userdefinedregexps.moc"
