@@ -1,3 +1,26 @@
+/*
+ *  Copyright (c) 2002-2003 Jesper K. Pedersen <blackie@kde.org>
+ *
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Library General Public
+ *  License version 2 as published by the Free Software Foundation.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Library General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Library General Public License
+ *  along with this library; see the file COPYING.LIB.  If not, write to
+ *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ *  Boston, MA 02111-1307, USA.
+ **/
+#ifdef QT_ONLY
+  #include "compat.h"
+#else
+  #include <kmessagebox.h>
+#endif
+
 #include "widgetfactory.h"
 #include "regexpwidget.h"
 #include "dragaccepter.h"
@@ -23,28 +46,27 @@
 #include "dotregexp.h"
 #include "compoundregexp.h"
 #include "kregexpeditorgui.h"
-#include <kmessagebox.h>
 
 bool WidgetFactory::isContainer( RegExpType tp )
 {
   return ( tp == REPEAT || tp == ALTN || tp == COMPOUND );
 }
 
-RegExpWidget* WidgetFactory::createWidget( RegExpEditorWindow* win, QWidget* parent, 
+RegExpWidget* WidgetFactory::createWidget( RegExpEditorWindow* win, QWidget* parent,
                                            RegExpType type )
 {
   RegExpWidget* widget = 0;
-  
+
   switch (type) {
-  case TEXT: 
+  case TEXT:
     return new TextWidget( win, parent ); break;
-  case ALTN: 
+  case ALTN:
     return  new AltnWidget( win, parent ); break;
-  case DOT: 
+  case DOT:
     return  new AnyCharWidget( win, parent ); break;
-  case BEGLINE: 
+  case BEGLINE:
     return new BegLineWidget( win, parent ); break;
-  case ENDLINE: 
+  case ENDLINE:
     return new EndLineWidget( win, parent ); break;
   case WORDBOUNDARY:
     return new WordBoundaryWidget( win, parent ); break;
@@ -53,11 +75,11 @@ RegExpWidget* WidgetFactory::createWidget( RegExpEditorWindow* win, QWidget* par
   case POSLOOKAHEAD:
   case NEGLOOKAHEAD:
     return new LookAheadWidget( win, type, parent ); break;
-  case REPEAT: 
+  case REPEAT:
     widget = new RepeatWidget( win, parent ); break;
-  case CHARSET: 
+  case CHARSET:
     widget = new CharactersWidget( win, parent ); break;
-  case COMPOUND: 
+  case COMPOUND:
     widget = new CompoundWidget( win, parent ); break;
   default:
     qFatal("It should not be possible to get here!");
@@ -96,16 +118,16 @@ RegExpWidget* WidgetFactory::createWidget( RegExp* regexp, RegExpEditorWindow* e
   else if ( PositionRegExp* reg = dynamic_cast<PositionRegExp*>( regexp ) ) {
     switch ( reg->position() ) {
     case PositionRegExp::BEGLINE:
-      return new BegLineWidget( editorWindow, parent );      
+      return new BegLineWidget( editorWindow, parent );
     case PositionRegExp::ENDLINE:
       return new EndLineWidget( editorWindow, parent );
     case PositionRegExp::WORDBOUNDARY:
-      return new WordBoundaryWidget( editorWindow, parent );      
+      return new WordBoundaryWidget( editorWindow, parent );
     case PositionRegExp::NONWORDBOUNDARY:
       return new NonWordBoundaryWidget( editorWindow, parent );
     }
   }
-  else if ( dynamic_cast<DotRegExp*>( regexp ) ) 
+  else if ( dynamic_cast<DotRegExp*>( regexp ) )
     return new AnyCharWidget( editorWindow, parent );
   else if ( CompoundRegExp* reg = dynamic_cast<CompoundRegExp*>( regexp ) )
     return new CompoundWidget( reg, editorWindow, parent );
@@ -120,38 +142,38 @@ RegExp* WidgetFactory::createRegExp( QDomElement node, const QString& version )
   QString tag = node.tagName();
   RegExp* regexp;
   if ( tag == QString::fromLocal8Bit( "TextRange" ) )
-    regexp = new TextRangeRegExp();
-  else if ( tag == QString::fromLocal8Bit( "Text" ) ) 
-    regexp = new TextRegExp();
+    regexp = new TextRangeRegExp( false );
+  else if ( tag == QString::fromLocal8Bit( "Text" ) )
+    regexp = new TextRegExp( false );
   else if ( tag == QString::fromLocal8Bit( "Concatenation" ) )
-    regexp = new ConcRegExp();
+    regexp = new ConcRegExp( false );
   else if ( tag == QString::fromLocal8Bit( "Alternatives" ) )
-    regexp = new AltnRegExp();
+    regexp = new AltnRegExp( false );
   else if ( tag == QString::fromLocal8Bit( "BegLine" ) )
-    regexp = new PositionRegExp( PositionRegExp::BEGLINE );
+    regexp = new PositionRegExp( false, PositionRegExp::BEGLINE );
   else if ( tag == QString::fromLocal8Bit( "EndLine" ) )
-    regexp = new PositionRegExp( PositionRegExp::ENDLINE );
+    regexp = new PositionRegExp( false, PositionRegExp::ENDLINE );
   else if ( tag == QString::fromLocal8Bit( "WordBoundary" ) )
-    regexp = new PositionRegExp( PositionRegExp::WORDBOUNDARY );
+    regexp = new PositionRegExp( false, PositionRegExp::WORDBOUNDARY );
   else if ( tag == QString::fromLocal8Bit( "NonWordBoundary" ) )
-    regexp = new PositionRegExp( PositionRegExp::NONWORDBOUNDARY );
+    regexp = new PositionRegExp( false, PositionRegExp::NONWORDBOUNDARY );
   else if ( tag == QString::fromLocal8Bit( "PositiveLookAhead" ) )
-    regexp = new LookAheadRegExp( LookAheadRegExp::POSITIVE );
+    regexp = new LookAheadRegExp( false, LookAheadRegExp::POSITIVE );
   else if ( tag == QString::fromLocal8Bit( "NegativeLookAhead" ) )
-    regexp = new LookAheadRegExp( LookAheadRegExp::NEGATIVE );
+    regexp = new LookAheadRegExp( false, LookAheadRegExp::NEGATIVE );
   else if ( tag == QString::fromLocal8Bit( "Compound" ) )
-    regexp = new CompoundRegExp();
+    regexp = new CompoundRegExp( false );
   else if ( tag == QString::fromLocal8Bit( "AnyChar" ) )
-    regexp = new DotRegExp();
+    regexp = new DotRegExp( false );
   else if ( tag == QString::fromLocal8Bit( "Repeat" ) )
-    regexp = new RepeatRegExp();
+    regexp = new RepeatRegExp( false );
   else {
     KMessageBox::sorry( 0, i18n("<p>Unknown tag while reading XML. Tag was <b>%1</b></p>").arg(tag),
                         i18n("Error While Loading From XML File") ) ;
 
     return 0;
   }
-  
+
   bool ok = regexp->load( node, version );
   if (ok)
     return regexp;
@@ -170,7 +192,7 @@ RegExp* WidgetFactory::createRegExp( QString str )
     KMessageBox::sorry( 0, i18n("Error while loading regular expression from XML. Most probably the regular expression had unmatched tags."),
                         i18n("Error While Loading Regular Expression From XML") ) ;
   }
-  
+
 
   // Read the RegularExpression element, and extract the version.
   QDomElement top = doc.documentElement();
