@@ -14,53 +14,53 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston,  
+ *  MA  02111-1307, USA.
  */
 
-#ifndef KSIM_H
-#define KSIM_H
+#ifndef KSIMEXTENSION_H
+#define KSIMEXTENSION_H
 
-#include <kmainwindow.h>
-#include <kurl.h>
+#include <kpanelextension.h>
 
-class QPopupMenu;
+class QBoxLayout;
+class KAboutData;
+class KInstance;
+class DCOPClient;
 
 namespace KSim
 {
   class MainView;
-  class Dock;
 
-  class MainWindow : public KMainWindow
+  class PanelExtension : public KPanelExtension
   {
     Q_OBJECT
     public:
-      MainWindow(const KURL::List &urlList = KURL::List(),
-          QWidget *parent = 0, const char *name = 0);
-      ~MainWindow();
+      PanelExtension( const QString & configFile, Type type,
+         int actions, QWidget * parent, const char * name);
+
+      ~PanelExtension();
+
+      QSize sizeHint( Position, QSize maxSize ) const;
+      Position preferedPosition() const;
 
-    public slots:
-      void loadPlugins(const KURL::List &);
-      void contextMenu();
-      virtual void show();
       void reparse();
 
-    protected:
-      bool queryClose();
+    public slots:
+      void show();
 
-    private slots:
-      void showDock();
+    protected:
+      void about();
+      void help();
+      void preferences();
+      void reportBug();
+      void positionChange( Position );
 
     private:
-      void windowMenu(int);
-      void initWidget(const KURL::List &urlList);
-
-      KSim::MainView *m_view;
-      KSim::Dock *m_dock;
-      QPopupMenu *m_mainMenu;
-      QPopupMenu *m_winMenu;
-      int m_ontopItem;
-      int m_desktopItem;
-      int m_shownBefore;
+      KSim::MainView * m_view;
+      QBoxLayout * m_layout;
+      KAboutData * m_aboutData;
+      DCOPClient * m_dcopClient;
   };
 }
-#endif // KSIM_H
+#endif
