@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
 #ifndef KSIMVIEW_H
@@ -36,7 +36,7 @@ namespace KSim
   class Plugin;
   class Label;
   class Frame;
-  class MainWindow;
+  class PanelExtension;
   class ConfigDialog;
   class ChangedPluginList;
 
@@ -46,15 +46,16 @@ namespace KSim
     K_DCOP
     public:
       MainView(KConfig *config, bool loadPlugins,
-         QWidget *parent, const char *name=0);
+         KSim::PanelExtension *topLevel,
+         const char *name);
+
       ~MainView();
 
       virtual void show();
       void cleanup();
 
       KSim::Config *config() const;
-      QPopupMenu *pluginMenu() const;
-      bool makeDirs() const;
+      void makeDirs();
 
     k_dcop:
       const QString &hostname() const;
@@ -66,17 +67,13 @@ namespace KSim
     public slots:
       void reparseConfig(bool, const KSim::ChangedPluginList &);
       void addPlugins();
-      void addPlugin(const KDesktopFile &, bool force = false);
+      void addPlugin(const QString&, bool force = false);
       void removePlugin(const KDesktopFile &);
-      void createPluginMenu();
       void addMonitor(const KSim::Plugin &);
       void runCommand(const QCString &);
       void preferences();
-      
+
     protected:
-      virtual void mouseMoveEvent(QMouseEvent *);
-      virtual void mouseReleaseEvent(QMouseEvent *);
-      virtual bool eventFilter(QObject *, QEvent *);
       virtual void resizeEvent(QResizeEvent *);
       virtual void paletteChange(const QPalette &);
 
@@ -90,15 +87,13 @@ namespace KSim
       KSim::Frame *m_rightFrame;
       KSim::Frame *m_topFrame;
       KSim::Frame *m_bottomFrame;
-      KSim::MainWindow *m_topLevel;
+      KSim::PanelExtension *m_topLevel;
       KSim::Config *m_config;
       KSim::ConfigDialog *m_prefDialog;
-      QPopupMenu *m_pluginMenu;
       QHBoxLayout *m_sizeLayout;
       QVBoxLayout *m_subLayout;
       QVBoxLayout *m_pluginLayout;
       QPoint m_mousePoint;
-      bool m_moving;
       int m_oldLocation;
   };
 }
