@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
 #include "themeloader.h"
@@ -45,8 +45,8 @@ class KSim::Theme::Private
        const QStringList &list) : fileNames(names),
        imageTypes(list) {}
 
-    KSimpleConfig *reader;
-    KSimpleConfig *dReader;
+    QStringList file;
+    QStringList dFile;
     KConfig *globalReader;
     QString altTheme;
     QString location;
@@ -55,6 +55,38 @@ class KSim::Theme::Private
     int alternative;
     int font;
     bool recolour;
+
+    QString readOption(const QString &entry,
+       bool useGlobal = true,
+       const QString &defValue = QString::null)
+    {
+      QString text;
+      QStringList::ConstIterator it;
+      for (it = file.begin(); it != file.end(); ++it) {
+        if ((*it).find(entry) != -1) {
+          text = QStringList::split("=", (*it))[1].stripWhiteSpace();
+        }
+      }
+
+      if (!text.isEmpty() || dFile.isEmpty())
+        return text;
+
+      QStringList::ConstIterator it2;
+      for (it2 = dFile.begin(); it2 != dFile.end(); ++it) {
+        if ((*it2).find(entry) != -1) {
+          text = QStringList::split("=", (*it2))[1].stripWhiteSpace();
+        }
+      }
+
+      if (!text.isEmpty())
+        return text;
+
+      if (!globalReader || !useGlobal)
+        return defValue;
+
+      text = globalReader->readEntry(entry, defValue);
+      return text;
+    }
 };
 
 class KSim::ThemeLoader::Private
@@ -89,8 +121,6 @@ KSim::Theme &KSim::Theme::operator=(const KSim::Theme &rhs)
 
 KSim::Theme::~Theme()
 {
-  delete d->reader;
-  delete d->dReader;
   delete d;
 }
 
@@ -110,10 +140,7 @@ QString KSim::Theme::name() const
 
 QString KSim::Theme::author() const
 {
-  QString author(d->reader->readEntry("author",
-     d->dReader ? d->dReader->readEntry("author")
-     : QString::null));
-
+  QString author(d->readOption("author", false));
   return author.replace(QRegExp("\""), QString::null);
 }
 
@@ -129,8 +156,7 @@ int KSim::Theme::alternative() const
 
 int KSim::Theme::alternatives() const
 {
-  return d->reader->readNumEntry("theme_alternatives",
-     d->dReader ? d->dReader->readNumEntry("theme_alternatives") : 0);
+  return d->readOption("theme_alternatives").toInt();
 }
 
 int KSim::Theme::chartWidthRef(int defValue) const
@@ -547,19 +573,19 @@ QValueList<QPixmap> KSim::Theme::pixmapToList(PixmapType type,
       xOffset = readIntEntry("StylePanel", "*.krell_x_hot");
       yOffset = readIntEntry("StylePanel", "*.krell_yoff");
       image.load(krellPanelPixmap(useDefault));
-      kdDebug() << "KSim::Theme: type = KrellPanel" << endl;
+      kdDebug(2003) << "KSim::Theme: type = KrellPanel" << endl;
       break;
     case KrellMeter:
       depth = readIntEntry("StyleMeter", "*.krell_depth");
       xOffset = readIntEntry("StyleMeter", "*.krell_x_hot");
       yOffset = readIntEntry("StyleMeter", "*.krell_yoff");
       image.load(krellMeterPixmap(useDefault));
-      kdDebug() << "KSim::Theme: type = KrellMeter" << endl;
+      kdDebug(2003) << "KSim::Theme: type = KrellMeter" << endl;
       break;
     case KrellSlider:
       depth = krellSliderDepth();
       image.load(krellSliderPixmap(useDefault));
-      kdDebug() << "KSim::Theme: type = KrellSlider" << endl;
+      kdDebug(2003) << "KSim::Theme: type = KrellSlider" << endl;
       break;
     default:
       return QValueList<QPixmap>();
@@ -597,10 +623,10 @@ QValueList<QPixmap> KSim::Theme::pixmapToList(PixmapType type,
       break;
   }
 
-  kdDebug() << "KSim::Theme: size = " << size << endl;
-  kdDebug() << "KSim::Theme: depth = " << depth << endl;
-  kdDebug() << "KSim::Theme: xOffset = " << xOffset << endl;
-  kdDebug() << "KSim::Theme: yOffset = " <<  xOffset << endl;
+  kdDebug(2003) << "KSim::Theme: size = " << size << endl;
+  kdDebug(2003) << "KSim::Theme: depth = " << depth << endl;
+  kdDebug(2003) << "KSim::Theme: xOffset = " << xOffset << endl;
+  kdDebug(2003) << "KSim::Theme: yOffset = " <<  xOffset << endl;
 
   return list;
 }
@@ -663,11 +689,11 @@ QString KSim::Theme::readEntry(const QString &itemType,
 QString KSim::Theme::readColourEntry(const QString &itemType,
    const QString &entry, int row) const
 {
-  QString colour = readEntry(itemType, entry);
-  if (colour.isEmpty())
-    colour = QString::fromLatin1("#ffffff #ffffff");
+  QString color = readEntry(itemType, entry);
+  if (color.isEmpty())
+    color = QString::fromLatin1("#ffffff #ffffff");
 
-  return QStringList::split(' ', colour)[row];
+  return QStringList::split(' ', color)[row];
 }
 
 QFont KSim::Theme::readFontEntry(const QString &itemType,
@@ -761,23 +787,14 @@ void KSim::Theme::init(const QString &url, const QString &fileName, int alt)
   d->alternative = alt;
   d->font = KSim::ThemeLoader::currentFontItem();
 
-  if (!QFile::exists(url + fileName + "_ksim")) {
-    QString newConfig = parseConfig(url, fileName);
-    d->reader = new KSimpleConfig(newConfig, true);
-    d->dReader = (alt != 0 ? new KSimpleConfig(parseConfig(url, 
-       "gkrellmrc"), true) : 0);
-  }
-  else {
-    d->reader = new KSimpleConfig(url + fileName + "_ksim", true);
-    d->dReader = (alt != 0 ? new KSimpleConfig(url +
-       "gkrellmrc_ksim", true) : 0);
-  }
+  d->file = QStringList::split("\n", parseConfig(url, fileName));
+
+  if (alt != 0)
+    d->dFile = QStringList::split("\n", parseConfig(url, "gkrellmrc"));
 }
 
 void KSim::Theme::reparse(const QString &url, const QString &fileName, int alt)
 {
-  delete d->reader;
-  delete d->dReader;
   init(url, fileName, alt);
 }
 
@@ -822,72 +839,46 @@ void KSim::Theme::setRecolour(bool value)
   d->recolour = value;
 }
 
-// Keep the uglyness here to make the rest
+// Keep the ugliness here to make the rest
 // of the class readable
 int KSim::Theme::internalNumEntry(const QString &entry, int defValue) const
 {
-  int value1((defValue == 0 && d->globalReader ?
-     d->globalReader->readNumEntry(entry, defValue) : defValue));
-  int value2((d->dReader == 0 ? value1 :
-     d->dReader->readNumEntry(entry, value1)));
-
-  return d->reader->readNumEntry(entry, value2);
+  return d->readOption(entry, true, QString::number(defValue)).toInt();
 }
 
 QRect KSim::Theme::internalRectEntry(const QString &entry,
    const QRect &defValue) const
 {
-  QRect rect1((defValue.isNull() && d->globalReader ?
-     d->globalReader->readRectEntry(entry, &defValue) : defValue));
-  QRect rect2((d->dReader == 0 ? rect1 :
-     d->dReader->readRectEntry(entry, &rect1)));
+  QString rect;
+  rect += QString::number(defValue.left());
+  rect += ",";
+  rect += QString::number(defValue.top());
+  rect += ",";
+  rect += QString::number(defValue.width());
+  rect += ",";
+  rect += QString::number(defValue.height());
 
-  return d->reader->readRectEntry(entry, &rect2);
+  QStringList list = QStringList::split(",", d->readOption(entry, true, rect));
+  QRect rect2(list[0].toInt(), list[1].toInt(), list[2].toInt(), list[3].toInt());
+
+  return rect2;
 }
 
 QColor KSim::Theme::internalColourEntry(const QString &entry,
    const QColor &defValue) const
 {
-  QColor colour1((defValue.isValid() && d->globalReader ?
-     d->globalReader->readColorEntry(entry, &defValue) : defValue));
-  QColor colour2((d->dReader == 0 ? colour1 :
-     d->dReader->readColorEntry(entry, &colour1)));
-
-  return d->reader->readColorEntry(entry, &colour2);
+  return d->readOption(entry, true, defValue.name());
 }
 
 QString KSim::Theme::internalStringEntry(const QString &entry,
    const QString &defValue) const
 {
-  QString string1((defValue.isNull() && d->globalReader ?
-     d->globalReader->readEntry(entry, defValue) : defValue));
-  QString string2((d->dReader == 0 ? string1 :
-     d->dReader->readEntry(entry, string1)));
-
-  return d->reader->readEntry(entry, string2);
+  return d->readOption(entry, true, defValue);
 }
 
 // check if the dir is writable, if not generate the new file in the home dir
 #define KSIM_THEME_URL(url) \
 { \
-  QString newUrl(url); \
-  if (!QFileInfo(url).isWritable() && currentName() != "ksim") { \
-    QString homePath = QDir::current().path(); \
-    homePath = locateLocal("data", "ksim") \
-       + QString::fromLatin1("/themes") \
-       + homePath.right(homePath.length() \
-       - homePath.findRev(QRegExp("\\/"), \
-       homePath.length())); \
-  \
-    if (!QFile::exists(homePath)) \
-      KStandardDirs::makeDir(homePath); \
-  \
-    kdWarning() << "Cant write to current dir, setting dir to " \
-       << homePath << endl; \
-    newUrl = homePath; \
-  } \
-  \
-  QDir::setCurrent(newUrl); \
 }
 
 KSim::ThemeLoader *KSim::ThemeLoader::m_self = 0; // initialize pointer
@@ -957,13 +948,13 @@ void KSim::ThemeLoader::reColourImage(QImage &image)
   if (!d->recolour || image.isNull())
     return;
 
-  QColor colour = QApplication::palette().active().background();
+  QColor color = QApplication::palette().active().background();
   QImage output(image.width(), image.height(), 32);
   output.setAlphaBuffer(image.hasAlphaBuffer());
 
-  Q_UINT32 r = colour.red();
-  Q_UINT32 g = colour.green();
-  Q_UINT32 b = colour.blue();
+  Q_UINT32 r = color.red();
+  Q_UINT32 g = color.green();
+  Q_UINT32 b = color.blue();
   Q_UINT32 *write = reinterpret_cast<Q_UINT32 *>(output.bits());
   Q_UINT32 *read  = reinterpret_cast<Q_UINT32 *>(image.bits());
   int size = image.width() * image.height();
@@ -982,7 +973,8 @@ void KSim::ThemeLoader::reColourImage(QImage &image)
 
     Q_UINT32 alpha = qAlpha(basePix);
     *write = qRgba(cr, cg, cb, alpha);
-    write++; read++;
+    write++;
+    read++;
   }
 
   image = output;
@@ -991,18 +983,13 @@ void KSim::ThemeLoader::reColourImage(QImage &image)
 QString KSim::ThemeLoader::parseConfig(const QString &url,
    const QString &fileName)
 {
-  kdDebug() << url + fileName << endl;
   QFile origFile(url + fileName);
-  QFile newFile(fileName + "_ksim");
 
-  KSIM_THEME_URL(url)
-
-  if (!origFile.open(IO_ReadOnly) || !newFile.open(IO_WriteOnly))
+  if (!origFile.open(IO_ReadOnly))
     return QString::null;
 
   QTextStream origStream(&origFile);
-  QTextStream newStream(&newFile);
-  newStream << "#Generated from " << fileName << " by KSim" << endl;
+  QString text;
   QRegExp reg("\\*"); // regexp for '*' chars
   QRegExp number("[0-9]+");  // regexp for all numbers
   QRegExp numbers("[0-9]+,[0-9]+,[0-9]+,[0-9]+"); // regexp for int,int,int,int
@@ -1011,33 +998,32 @@ QString KSim::ThemeLoader::parseConfig(const QString &url,
     QString line(origStream.readLine().simplifyWhiteSpace());
 
     if (line.find(reg) == 0) // find the location of the * comments
-      // replace all * comments with # comments so KConfig doesnt complain
+      // replace all * comments with # comments so KConfig doesn't complain
       line.replace(reg, "#");
 
     if (line.find("#") == -1) { // find the location of the string 'gkrellmms'
       if (line.findRev("=") == -1) { // if found we check for the string '='
         int numLoc = line.findRev(numbers);
         if (numLoc != -1)
-          // if '=' doesnt exist we add one so KConfig doesnt complain
+          // if '=' doesn't exist we add one so KConfig doesn't complain
           line.insert(numLoc, " = ");
 
         numLoc = line.findRev(number);
         if (numLoc != -1)
-          // if '=' doesnt exist we add one so KConfig doesnt complain
+          // if '=' doesn't exist we add one so KConfig doesn't complain
           line.insert(numLoc, " = ");
 
         numLoc = line.findRev(minus);
         if (numLoc != -1)
-          // replace the '-' with an '=' so KConfig doesnt get confused
+          // replace the '-' with an '=' so KConfig doesn't get confused
           line.replace(QRegExp("-"), "=");
       }
     }
 
-    newStream << line << endl;
+    text.append(line).append('\n');
   }
 
-  return QDir::currentDirPath() + QString::fromLatin1("/") +
-        fileName + QString::fromLatin1("_ksim");
+  return text;
 }
 
 // GKrellM themes seem to be rather inconsistant
@@ -1046,7 +1032,24 @@ QString KSim::ThemeLoader::parseConfig(const QString &url,
 // is still compliant with GKrellM.
 void KSim::ThemeLoader::parseDir(const QString &url, int alt)
 {
-  KSIM_THEME_URL(url)
+  if ( !QFileInfo( url ).isWritable() && currentName() != "ksim" )
+  {
+    QString homePath = QDir::current().path();
+    homePath = locateLocal( "data", "ksim" )
+       + QString::fromLatin1( "/themes" )
+       + homePath.right( homePath.length()
+       - homePath.findRev( QRegExp( "\\/" ),
+       homePath.length() ) );
+
+    if ( !QFile::exists( homePath ) )
+      KStandardDirs::makeDir( homePath );
+
+    kdWarning() << "Cant write to current dir, setting dir to "
+       << homePath << endl;
+
+    QDir::setCurrent( homePath );
+  }
+
   int alternatives = ++alt;
 
   QStringList formats;
@@ -1145,7 +1148,12 @@ QString KSim::ThemeLoader::defaultUrl()
 int KSim::ThemeLoader::currentAlternative()
 {
   KSim::Config::config()->setGroup("Theme");
-  return KSim::Config::config()->readNumEntry("Alternative");
+  int alternative = KSim::Config::config()->readNumEntry("Alternative");
+
+  if ( alternative > self().current().alternatives() )
+    alternative = self().current().alternatives();
+
+  return alternative;
 }
 
 QString KSim::ThemeLoader::alternativeAsString(int alt)
@@ -1215,8 +1223,9 @@ KSim::ThemeLoader::ThemeLoader()
   d->fileNames[29] = "bg_timer";
   d->fileNames[30] = "decal_net_leds";
 
-  QString fileName = QString::fromLatin1("gkrellmrc") + alternativeAsString();
   m_theme.create(d->fileNames, d->imageTypes, d->globalReader);
+
+  QString fileName = QString::fromLatin1("gkrellmrc") + alternativeAsString();
   m_theme.init(currentUrl(), fileName, currentAlternative());
 
   reColourItems();
