@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
 #include "ksimdisk.h"
@@ -35,6 +35,7 @@
 #include <kapplication.h>
 #include <klistview.h>
 #include <klineeditdlg.h>
+#include <kconfig.h>
 
 #include <chart.h>
 #include <progress.h>
@@ -55,12 +56,12 @@
 #include <linux/major.h>
 #endif
 
-#include <iostream.h>
+#include <iostream>
 
 #define DISK_SPEED 1000
 
 KSIM_INIT_PLUGIN(DiskPlugin)
- 
+
 DiskPlugin::DiskPlugin(const char *name)
    : KSim::PluginObject(name)
 {
@@ -100,6 +101,7 @@ DiskView::DiskView(KSim::PluginObject *parent, const char *name)
    : KSim::PluginView(parent, name)
 {
 #ifdef Q_OS_LINUX
+  m_bLinux24 = true;
   m_procStream = 0L;
   if ((m_procFile = fopen("/proc/stat", "r")))
     m_procStream = new QTextStream(m_procFile, IO_ReadOnly);
@@ -123,10 +125,10 @@ DiskView::DiskView(KSim::PluginObject *parent, const char *name)
 DiskView::~DiskView()
 {
 #ifdef Q_OS_LINUX
+  delete m_procStream;
+
   if (m_procFile)
     fclose(m_procFile);
-
-  delete m_procStream;
 #endif
 }
 
@@ -221,38 +223,129 @@ void DiskView::updateDisplay()
 void DiskView::updateData(DiskList &disks)
 {
 #ifdef Q_OS_LINUX
-  // here we need a regexp to match something like:
-  // (3,0):(108911,48080,1713380,60831,1102644)
-  QRegExp regexp("\\([0-9]+,[0-9]+\\):\\([0-9]+,[0-9]+,[0-9]+,[0-9]+,[0-9]+\\)");
-  regexp.search(m_procStream->read());
-  QStringList list;
-  QString string;
+  if (!m_procStream)
+     return;
 
-  QStringList stringList = regexp.capturedTexts();
-  QStringList::ConstIterator it;
-  for (it = stringList.begin(); it != stringList.end(); ++ it) {
-    string = (*it);
-    string.replace(QRegExp(":"), ",");
-    string.replace(QRegExp("\\)?\\(?"), QString::null);
+  m_procStream->device()->reset();
+  fseek(m_procFile, 0L, SEEK_SET);
 
-    list = QStringList::split(',', string);
-    DiskData diskData;
-    diskData.major = list[0].toInt();
-    diskData.minor = list[1].toInt();
-    setDiskName(diskData);
+  if (m_bLinux24)
+  {
+    // here we need a regexp to match something like:
+    // (3,0):(108911,48080,1713380,60831,1102644)
+    QRegExp regexp("\\([0-9]+,[0-9]+\\):\\([0-9]+,[0-9]+,[0-9]+,[0-9]+,[0-9]+\\)");
+    QString content = m_procStream->read();
+    if (content.find("disk_io") == -1)
+    {
+       m_bLinux24 = false;
+       
+       fclose(m_procFile);
+       delete m_procStream;
+       m_procStream = 0;
+       
+       if ((m_procFile = fopen("/proc/diskstats", "r")))
+          m_procStream = new QTextStream(m_procFile, IO_ReadOnly);
+       
+       updateData(disks);
+       return;
+    }
+    int idx = 0;
+    while ((idx = regexp.search(content, idx)) != -1)
+    {
+      idx += regexp.matchedLength();
+      QString diskStr = regexp.cap(0);
+      diskStr.replace(':', ',');
+      diskStr.replace(QRegExp("\\)?\\(?"), QString::null);
 
-    diskData.total = list[2].toULong();
-    diskData.readIO = list[3].toULong();
-    diskData.readBlocks = list[4].toULong();
-    diskData.writeIO = list[5].toULong();
-    diskData.writeBlocks = list[6].toULong();
-    disks.append(diskData);
+      QStringList list = QStringList::split(',', diskStr);
+      if (list.count() < 7)
+        continue;
+
+      DiskData diskData;
+      diskData.major = list[0].toInt();
+      diskData.minor = list[1].toInt();
+      diskData.name = diskName( diskData.major, diskData.minor );
+      diskData.total = list[2].toULong();
+      diskData.readIO = list[3].toULong();
+      diskData.readBlocks = list[4].toULong();
+      diskData.writeIO = list[5].toULong();
+      diskData.writeBlocks = list[6].toULong();
+      disks.append(diskData);
+    }
+  }
+  else
+  {
+    // 3    0 hda 564142 160009 14123957 12369403 1052983 2801992 30905928 78981451 0 4531584 91518334
+    // The 11 fields after the device name are defined as follows:
+    // Field  1 -- # of reads issued
+    //    This is the total number of reads completed successfully.
+    // Field  2 -- # of reads merged, 
+    //    Reads and writes which are adjacent to each other may be merged for
+    //    efficiency.  Thus two 4K reads may become one 8K read before it is
+    //    ultimately handed to the disk, and so it will be counted (and queued)
+    //    as only one I/O.  This field lets you know how often this was done.
+    // Field  3 -- # of sectors read
+    //    This is the total number of sectors read successfully.
+    // Field  4 -- # of milliseconds spent reading
+    //    This is the total number of milliseconds spent by all reads (as
+    //    measured from __make_request() to end_that_request_last()).
+    // Field  5 -- # of writes completed
+    //    This is the total number of writes completed successfully.
+    // Field  6 -- # of writes merged
+    //    See field 2
+    // Field  7 -- # of sectors written
+    //    This is the total number of sectors written successfully.
+    // Field  8 -- # of milliseconds spent writing
+    //    This is the total number of milliseconds spent by all writes (as
+    //    measured from __make_request() to end_that_request_last()).
+    // Field  9 -- # of I/Os currently in progress
+    //    The only field that should go to zero. Incremented as requests are
+    //    given to appropriate request_queue_t and decremented as they finish.
+    // Field 10 -- # of milliseconds spent doing I/Os
+    //    This field is increases so long as field 9 is nonzero.
+    // Field 11 -- weighted # of milliseconds spent doing I/Os
+    //    This field is incremented at each I/O start, I/O completion, I/O
+    //    merge, or read of these stats by the number of I/Os in progress
+    //    (field 9) times the number of milliseconds spent doing I/O since the
+    //    last update of this field.  This can provide an easy measure of both
+    //    I/O completion time and the backlog that may be accumulating.
+    QString content = m_procStream->read();
+    QStringList lines = QStringList::split('\n', content);
+
+    for(QStringList::ConstIterator it = lines.begin();
+        it != lines.end(); ++it)
+    {
+      QString diskStr = (*it).simplifyWhiteSpace();
+      QStringList list = QStringList::split(' ', diskStr);
+      if (list.count() < 14)
+        continue;
+
+      DiskData diskData;
+      diskData.major = list[0].toInt();
+      diskData.minor = list[1].toInt();
+      diskData.name = list[2];
+      diskData.readIO = 0;
+      diskData.readBlocks = list[3+2].toULong();
+      diskData.writeIO = 0;
+      diskData.writeBlocks = list[7+2].toULong();
+      diskData.total = diskData.readBlocks + diskData.writeBlocks;
+      disks.append(diskData);
+    }
   }
 
-  fseek(m_procFile, 0L, SEEK_SET);
 #endif
 
 #ifdef Q_OS_FREEBSD
+#if __FreeBSD_version < 500107
+#define	devstat_getdevs(fd, stats)	getdevs(stats)
+#define	devstat_selectdevs		selectdevs
+#define	bytes_read(dev)			(dev).bytes_read
+#define	bytes_written(dev)		(dev).bytes_written
+#else
+#define	bytes_read(dev)			(dev).bytes[DEVSTAT_READ]
+#define	bytes_written(dev)		(dev).bytes[DEVSTAT_WRITE]
+#endif
+
   statinfo diskStats;
   bzero(&diskStats, sizeof(diskStats));
   diskStats.dinfo = (struct devinfo *)malloc(sizeof(struct devinfo));
@@ -263,11 +356,11 @@ void DiskView::updateData(DiskList &disks)
   long generation;
   device_selection *deviceSelect = 0;
 
-  if (getdevs(&diskStats) < 0)
+  if (devstat_getdevs(NULL, &diskStats) < 0)
     return;
 
   deviceAmount = diskStats.dinfo->numdevs;
-  if (selectdevs(&deviceSelect, &selected, &selections,
+  if (devstat_selectdevs(&deviceSelect, &selected, &selections,
      &generation, diskStats.dinfo->generation,
      diskStats.dinfo->devices, deviceAmount,
      0, 0, 0, 0, DS_SELECT_ONLY, 10, 1) < 0)
@@ -280,8 +373,8 @@ void DiskView::updateData(DiskList &disks)
     disk = deviceSelect[i].position;
     device = diskStats.dinfo->devices[disk];
     blockSize = (device.block_size <= 0 ? 512 : device.block_size);
-    readBlocks = device.bytes_read / blockSize;
-    writeBlocks = device.bytes_written / blockSize;
+    readBlocks = bytes_read(device) / blockSize;
+    writeBlocks = bytes_written(device) / blockSize;
 
     DiskData diskData;
     diskData.name = device.device_name
@@ -301,11 +394,12 @@ void DiskView::updateData(DiskList &disks)
 #endif
 }
 
-void DiskView::setDiskName(DiskData &disk) const
+QString DiskView::diskName( int major, int minor ) const
 {
 #ifdef Q_OS_LINUX
   QString returnValue;
-  switch (disk.major) {
+  switch ( major )
+  {
     case IDE0_MAJOR:
       returnValue.prepend(QString::fromLatin1("hda"));
       break;
@@ -323,8 +417,8 @@ void DiskView::setDiskName(DiskData &disk) const
       break;
   }
 
-  returnValue.at(2) = returnValue.at(2).latin1() + disk.minor;
-  disk.name = returnValue;
+  returnValue.at(2) = returnValue.at(2).latin1() + minor;
+  return returnValue;
 #endif
 }
 
@@ -365,16 +459,17 @@ DiskConfig::DiskConfig(KSim::PluginObject *parent, const char *name)
    : KSim::PluginPage(parent, name)
 {
   m_layout = new QVBoxLayout(this);
+  m_layout->setSpacing(6);
 
   m_listview = new KListView(this);
   m_listview->addColumn(i18n("Disks"));
   m_layout->addWidget(m_listview);
 
-  new QListViewItem(m_listview, i18n("All Disks"));
-
   QHBoxLayout *layout = new QHBoxLayout;
+  layout->setSpacing(6);
+
   QSpacerItem *spacer = new QSpacerItem(20, 20,
-     QSizePolicy::Expanding, QSizePolicy::Fixed);
+     QSizePolicy::Expanding, QSizePolicy::Minimum);
   layout->addItem(spacer);
 
   m_add = new QPushButton(this);
@@ -395,7 +490,7 @@ DiskConfig::DiskConfig(KSim::PluginObject *parent, const char *name)
   m_totalButton->setText(i18n("Display the read and write data as one"));
   m_bothButton = new QRadioButton(m_buttonBox);
   m_bothButton->setText(i18n("Display the read and write data"
-     "\nseperatly as in/out data"));
+     "\nseparately as in/out data"));
 
   QSpacerItem *vSpacer = new QSpacerItem(20, 20,
      QSizePolicy::Minimum, QSizePolicy::Expanding);
