@@ -2,7 +2,7 @@
  *
  *  Copyright (C) 2001  Robbie Ward <linuxphreak@gmx.co.uk>
  *
- *  $Id: ksimfsystem.cpp,v 1.55.2.3 2003/07/17 11:02:38 mueller Exp $
+ *  $Id: ksimfsystem.cpp,v 1.62 2003/08/17 13:12:09 hausmann Exp $
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,29 +16,11 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
 #include <config.h>
 
-#include <sys/types.h>
-#include <sys/param.h>
-
-#ifdef HAVE_SYS_STATVFS_H
-#include <sys/statvfs.h>
-#elif defined(HAVE_SYS_STATFS_H)
-#include <sys/statfs.h>
-#endif
-#ifdef HAVE_SYS_VFS_H
-#include <sys/vfs.h>
-#endif
-#ifdef HAVE_SYS_MOUNT_H
-#include <sys/mount.h>
-#endif
-
-#include <stdio.h>
-#include <unistd.h>
-
 #include <qlayout.h>
 #include <qvaluelist.h>
 #include <qtimer.h>
@@ -54,7 +36,8 @@
 
 #include "ksimfsystem.h"
 #include "fsystemconfig.h"
-#include "fsysscroller.h"
+#include "filesystemwidget.h"
+#include "filesystemstats.h"
 #include <themeloader.h>
 
 KSIM_INIT_PLUGIN(PluginModule)
@@ -99,31 +82,22 @@ void PluginModule::showAbout()
 }
 
 Fsystem::Fsystem(KSim::PluginObject *parent, const char *name)
-   : KSim::PluginView(parent, name),
-   DCOPObject("fsystem")
+   : DCOPObject("fsystem"),
+   KSim::PluginView(parent, name)
 {
   config()->setGroup("Fsystem");
   (new QVBoxLayout(this))->setAutoAdd(true);
 
-  // Add here any items that should be ignored
-  m_ignoreList.append("/proc.*");
-  m_ignoreList.append("/dev/pts");
-
   m_mountEntries = makeList(config()->readListEntry("mountEntries"));
   m_showPercentage = config()->readBoolEntry("ShowPercentage", true);
 
-  int updateVal = config()->readNumEntry("scrollerUpdate", 65);
-  stackItems = config()->readBoolEntry("stackItems", false);
-  m_scroller = new FSysScroller(stackItems, updateVal, this);
+  m_widget = new FilesystemWidget(this, "FilesystemWidget");
 
   createFreeInfo();
 
   m_updateTimer = new QTimer(this);
   connect(m_updateTimer, SIGNAL(timeout()), SLOT(updateFS()));
   m_updateTimer->start(config()->readNumEntry("updateValue", 60) * 1000);
-  
-  // A little hackish, write a proper fix later on
-  QTimer::singleShot(0, m_scroller, SLOT(resizeScroller()));
 }
 
 Fsystem::~Fsystem()
@@ -135,28 +109,15 @@ void Fsystem::reparseConfig()
   config()->setGroup("Fsystem");
 
   m_showPercentage = config()->readBoolEntry("ShowPercentage", true);
-  bool stack = config()->readBoolEntry("stackItems", false);
   MountEntryList mountEntries = makeList(config()->readListEntry("mountEntries"));
 
   if (m_mountEntries != mountEntries) {
-    m_scroller->clear();
+    m_widget->clear();
     m_mountEntries = mountEntries;
     createFreeInfo();
   }
 
-  if (stackItems != stack) {
-    stackItems = stack;
-    m_scroller->setStackScroller(stackItems);
-  }
-
-  if (!stackItems) {
-    int updateVal = config()->readNumEntry("scrollerUpdate", 65);
-    m_scroller->setScrollSpeed(updateVal);
-  }
-
   updateFS();
-  // A little hackish, write a proper fix later on
-  QTimer::singleShot(0, m_scroller, SLOT(resizeScroller()));
 }
 
 int Fsystem::totalFreeSpace() const
@@ -165,68 +126,13 @@ int Fsystem::totalFreeSpace() const
   int totalFreeSpace = 0;
   MountEntryList::ConstIterator it;
   for (it = m_mountEntries.begin(); it != m_mountEntries.end(); ++it) {
-    getMountInfo((*it).first, totalSize, totalFree);
-    totalFreeSpace += totalFree;
+    if ( FilesystemStats::readStats( ( *it ).first, totalSize, totalFree ) )
+      totalFreeSpace += totalFree;
   }
 
   return totalFreeSpace;
 }
 
-#ifdef HAVE_STATVFS
-#define FSystemStats struct statvfs
-#elif defined(HAVE_STATFS)
-#define FSystemStats struct statfs
-#elif defined(__FreeBSD__)
-#define FSystemStats struct statfs
-#else
-struct ksim_statfs // fall back for (possibly) non-supported systems
-{
-  int f_blocks;
-  int f_bfree;
-};
-
-#define FSystemStats struct ksim_statfs
-#endif
-
-int fsystemStats(const char *file, FSystemStats &stats)
-{
-#ifdef HAVE_STATVFS
-  return statvfs(file, &stats);
-#elif defined(HAVE_STATFS)
-  return statfs(file, &stats);
-#elif defined(__FreeBSD__)
-  return statfs(file, &stats);
-#else // fall back for (possibly) non-supported systems
-  (void)file;
-
-  stats.f_blocks = 0;
-  stats.f_bfree = 0;
-  return -1;
-#endif
-}
-
-void Fsystem::getMountInfo(const QString &mntPoint,
-   int &totalBlocks, int &freeBlocks) const
-{
-  if (isFound(mntPoint)) {
-    kdWarning() << "Ignoring entry " << mntPoint << endl;
-    totalBlocks = 1;
-    freeBlocks = 1;
-    return;
-  }
-
-  FSystemStats sysStats;
-  if (fsystemStats(QFile::encodeName(mntPoint).data(), sysStats) < 0) {
-    kdError() << "While reading filesystem information for " << mntPoint << endl;
-    totalBlocks = 1;
-    freeBlocks = 1;
-    return;
-  }
-
-  totalBlocks = sysStats.f_blocks;
-  freeBlocks = sysStats.f_bfree;
-}
-
 void Fsystem::createFreeInfo()
 {
   int total, free;
@@ -235,24 +141,21 @@ void Fsystem::createFreeInfo()
   for (it = m_mountEntries.begin(); it != m_mountEntries.end(); ++it) {
     // returns the total space and free space from *it
     // (the current mounted partition)
-    getMountInfo((*it).first, total, free);
+    if ( !FilesystemStats::readStats( ( *it ).first, total, free ) )
+      continue;
+
     int percent = 0;
 	if( total != 0)
 		percent = ((total - free) * 100) / total;
-    
-	m_scroller->append(i, total, (*it).first);
-    m_scroller->setValue(i, total - free);
+    m_widget->append(total, (*it).first);
+    m_widget->setValue(i, total - free);
     if (m_showPercentage)
-      m_scroller->setText(i, ((*it).second.isEmpty() ? (*it).first : (*it).second)
+      m_widget->setText(i, ((*it).second.isEmpty() ? (*it).first : (*it).second)
          + " - " + QString::number(percent) + "%");
     else
-      m_scroller->setText(i, ((*it).second.isEmpty() ? (*it).first : (*it).second));
+      m_widget->setText(i, ((*it).second.isEmpty() ? (*it).first : (*it).second));
     i++;
   }
-
-  // hack to make the scrolling smooth
-  if (!stackItems && m_mountEntries.count() >= 2)
-    m_scroller->insertDummy();
 }
 
 void Fsystem::updateFS()
@@ -263,34 +166,20 @@ void Fsystem::updateFS()
   for (it = m_mountEntries.begin(); it != m_mountEntries.end(); ++it) {
     // returns the total space and free space from *it
     // (the current mounted partition)
-    getMountInfo((*it).first, total, free);
+    if ( !FilesystemStats::readStats( ( *it ).first, total, free ) )
+      continue;
+
     int percent = 0;
 	if( total != 0 )
 		percent = ((total - free) * 100) / total;
-    m_scroller->setValue(i, total - free);
+    m_widget->setValue(i, total - free);
     if (m_showPercentage)
-      m_scroller->setText(i, ((*it).second.isEmpty() ? (*it).first : (*it).second)
+      m_widget->setText(i, ((*it).second.isEmpty() ? (*it).first : (*it).second)
          + " - " + QString::number(percent) + "%");
     else
-      m_scroller->setText(i, ((*it).second.isEmpty() ? (*it).first : (*it).second));
+      m_widget->setText(i, ((*it).second.isEmpty() ? (*it).first : (*it).second));
     i++;
   }
-
-  // hack to make the scrolling smooth
-  if (!stackItems && m_mountEntries.count() >= 2)
-    m_scroller->insertDummy();
-}
-
-bool Fsystem::isFound(const QString &point) const
-{
-  QStringList::ConstIterator it;
-  for (it = m_ignoreList.begin(); it != m_ignoreList.end(); ++ it) {
-    QRegExp regexp((*it));
-    if (regexp.search(point) != -1)
-      return true;
-  }
-
-  return false;
 }
 
 Fsystem::MountEntryList Fsystem::makeList(const QStringList &list) const
