@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
 #include <time.h>
@@ -40,6 +40,8 @@ static int mib[] = { CTL_NET, PF_ROUTE, 0, 0, NET_RT_IFLIST, 0 };
 #include <qlayout.h>
 #include <qtimer.h>
 #include <qregexp.h>
+#include <qcursor.h>
+#include <qpopupmenu.h>
 
 #include <kdebug.h>
 #include <klocale.h>
@@ -49,13 +51,11 @@ static int mib[] = { CTL_NET, PF_ROUTE, 0, 0, NET_RT_IFLIST, 0 };
 #include <kglobal.h>
 #include <krun.h>
 #include <kapplication.h>
+#include <kiconloader.h>
 
 #include "ksimnet.h"
 #include "netconfig.h"
 #include <themetypes.h>
-#include <label.h>
-#include <led.h>
-#include <chart.h>
 
 #define NET_UPDATE 1000
 #define LED_UPDATE 125
@@ -112,33 +112,30 @@ NetView::NetView(KSim::PluginObject *parent, const char *name)
   m_allocSize = 0;
 #endif
 
-  m_data = 0;
-  m_oldData = 0;
-  m_max = 0L;
-  m_firstTime = 0;
+  m_firstTime = true;
   m_netLayout = new QVBoxLayout(this);
 
-  config()->setGroup("Net");
-  int deviceAmount = config()->readNumEntry("deviceAmount", 0);
-  m_deviceList = createDeviceList(deviceAmount);
-  init(deviceAmount);
+  m_networkList = createList();
+  addDisplay();
 
   m_netTimer = new QTimer(this);
   connect(m_netTimer, SIGNAL(timeout()), SLOT(updateGraph()));
   m_netTimer->start(NET_UPDATE);
+
   m_lightTimer = new QTimer(this);
   connect(m_lightTimer, SIGNAL(timeout()), SLOT(updateLights()));
   m_lightTimer->start(LED_UPDATE);
+
   updateGraph();
 }
 
 NetView::~NetView()
 {
 #ifdef __linux__
+  delete m_procStream;
+
   if (m_procFile)
     fclose(m_procFile);
-
-  delete m_procStream;
 #endif
 
   cleanup();
@@ -146,107 +143,85 @@ NetView::~NetView()
 
 void NetView::reparseConfig()
 {
-  config()->setGroup("Net");
-
-  int deviceAmount = config()->readNumEntry("deviceAmount", 0);
-  DeviceList deviceList = createDeviceList(deviceAmount);
-  if (deviceList == m_deviceList)
+  Network::List networkList = createList();
+  if ( networkList == m_networkList )
     return;
 
   m_netTimer->stop();
   m_lightTimer->stop();
-  m_firstTime = 0;
+  m_firstTime = true;
 
-  DeviceList::Iterator it;
-  for (it = m_widgetList.begin(); it != m_widgetList.end(); ++it) {
-    delete (*it).netLabel;
-    delete (*it).netLed;
-    delete (*it).netChart;
-    delete (*it).cMenu;
-    (*it).netLabel = 0;
-    (*it).netLed = 0;
-    (*it).netChart = 0;
-    (*it).cMenu = 0;
-  }
-
-  m_deviceList = deviceList;
   cleanup();
-  init(deviceAmount);
+
+  m_networkList = networkList;
+  addDisplay();
+
   m_netTimer->start(NET_UPDATE);
   m_lightTimer->start(LED_UPDATE);
 }
 
 void NetView::cleanup()
 {
-  if (m_data) {
-    delete[] m_data;
-    m_data = 0;
+  Network::List::Iterator it;
+  for ( it = m_networkList.begin(); it != m_networkList.end(); ++it )
+  {
+    ( *it ).cleanup();
   }
 
-  if (m_oldData) {
-    delete[] m_oldData;
-    m_oldData = 0;
-  }
-
-  if (m_max) {
-    delete[] m_max;
-    m_max = 0;
-  }
+  m_networkList.clear();
 }
 
-void NetView::init(int amount)
+void NetView::addDisplay()
 {
-  m_widgetList.clear();
-
-  config()->setGroup("Net");
-
-  if (!m_data)
-    m_data = new NetData[amount];
-
-  if (!m_oldData)
-    m_oldData = new NetData[amount];
-
-  if (!m_max)
-    m_max = new unsigned long[amount];
-
   int i = 0;
-  DeviceList::ConstIterator it;
-  for (it = m_deviceList.begin(); it != m_deviceList.end(); ++it) {
-    if (menu()->indexOf(100 + i) != -1)
-      menu()->removeItem(100 + i);
 
-    m_max[i] = 0;
-    newNetMonitor((*it), i);
+  Network::List::Iterator it;
+  for ( it = m_networkList.begin(); it != m_networkList.end(); ++it )
+  {
+    KSim::Chart *chart = addChart();
+    KSim::LedLabel *led = addLedLabel( ( *it ).name() );
+    KSim::Label *label = ( ( *it ).showTimer() ? addLabel() : 0L );
+    QPopupMenu * popup = ( ( *it ).commandsEnabled() ?
+       addPopupMenu( ( *it ).name(), i ) : 0L );
+
+    if ( ( *it ).commandsEnabled() )
+    {
+      if ( chart )
+      {
+        chart->installEventFilter( this );
+      }
+
+      if ( led )
+      {
+        led->installEventFilter( this );
+      }
+
+      if ( label )
+      {
+        label->installEventFilter( this );
+      }
+    }
+
+    ( *it ).setDisplay( chart, led, label, popup );
     ++i;
   }
-
-  qHeapSort(m_widgetList);
-}
-
-void NetView::newNetMonitor(const NetDevice &device, int value)
-{
-  KSim::Chart *chart = (device.showGraph ? addChart() : 0L);
-  KSim::LedLabel *led = addLedLabel(device.deviceName);
-  KSim::Label *label = (device.showTimer ? addLabel() : 0L);
-
-  m_widgetList.append(NetDevice(
-     QString::number(value), device.showTimer,
-     device.timerFormat, device.showLabel,
-     device.deviceName, chart, led, label,
-     (device.commandsEnabled ?
-     addPopupMenu(device.deviceName, value) : 0L)));
 }
 
 // Run the connect command
-void NetView::runConnectCommand(int value)
+void NetView::runConnectCommand( int value )
 {
   int i = 0;
-  DeviceList::ConstIterator it;
-  for (it = m_deviceList.begin(); it != m_deviceList.end(); ++it) {
-    if (value == i) {
+  Network::List::ConstIterator it;
+  for ( it = m_networkList.begin(); it != m_networkList.end(); ++it )
+  {
+    if ( value == i )
+    {
       // I use KRun here as it provides startup notification
-      if (!(*it).dCommand.isNull())
-        KRun::runCommand((*it).cCommand);
+      if ( !( *it ).connectCommand().isNull() )
+      {
+        KRun::runCommand( ( *it ).connectCommand() );
+      }
+
       break;
     }
     ++i;
@@ -254,171 +229,185 @@ void NetView::runConnectCommand(int value)
 }
 
 // Run the disconnect command
-void NetView::runDisconnectCommand(int value)
+void NetView::runDisconnectCommand( int value )
 {
   int i = 0;
-  DeviceList::ConstIterator it;
-  for (it = m_deviceList.begin(); it != m_deviceList.end(); ++it) {
-    if (value == i) {
+  Network::List::ConstIterator it;
+  for ( it = m_networkList.begin(); it != m_networkList.end(); ++it )
+  {
+    if ( value == i )
+    {
       // I use KRun here as it provides startup notification
-      if (!(*it).dCommand.isNull())
-        KRun::runCommand((*it).dCommand);
+      if ( !( *it ).disconnectCommand().isNull() )
+      {
+        KRun::runCommand( ( *it ).disconnectCommand() );
+      }
+
       break;
     }
+
     ++i;
   }
 }
 
-DeviceList NetView::createDeviceList(int amount) const
+Network::List NetView::createList() const
 {
-  DeviceList deviceList;
-  for (int i = 0; i < amount; ++i) {
-    if (config()->hasGroup("device-" + QString::number(i))) {
-      config()->setGroup("device-" + QString::number(i));
+  config()->setGroup( "Net" );
+  int amount = config()->readNumEntry( "deviceAmount", 0 );
 
-      deviceList.append(NetDevice(
-         config()->readBoolEntry("showTimer"),
-         config()->readEntry("deviceFormat"),
-         config()->readBoolEntry("commands"),
-         config()->readEntry("cCommand"),
-         config()->readEntry("dCommand"),
-         config()->readBoolEntry("showGraph"),
-         config()->readBoolEntry("showLabel"),
-         config()->readEntry("deviceName")));
+  Network::List list;
+  for ( int i = 0; i < amount; ++i )
+  {
+    if ( !config()->hasGroup( "device-" + QString::number( i ) ) )
+    {
+      continue;
     }
+
+    config()->setGroup( "device-" + QString::number( i ) );
+
+    list.append( Network( config()->readEntry( "deviceName" ),
+       config()->readEntry( "deviceFormat" ),
+       config()->readBoolEntry( "showTimer" ),
+       config()->readBoolEntry( "commands" ),
+       config()->readEntry( "cCommand" ),
+       config()->readEntry("dCommand") ) );
   }
 
-  return deviceList;
+  qHeapSort( list );
+  return list;
 }
 
 void NetView::updateLights()
 {
-  int i = 0;
-  DeviceList::ConstIterator it;
-  for (it = m_widgetList.begin(); it != m_widgetList.end(); ++it) {
-    if (isOnline((*it).deviceName)) {
-      unsigned long recieveDiff = m_data[i].in - m_oldData[i].in;
-      unsigned long sendDiff = m_data[i].out - m_oldData[i].out;
+  Network::List::Iterator it;
+  for ( it = m_networkList.begin(); it != m_networkList.end(); ++it )
+  {
+    if ( isOnline( ( *it ).name() ) )
+    {
+      unsigned long receiveDiff = ( *it ).data().in - ( *it ).oldData().in;
+      unsigned long sendDiff = ( *it ).data().out - ( *it ).oldData().out;
+      unsigned long halfMax = ( *it ).maxValue() / 2;
 
-      if (recieveDiff == 0 && sendDiff == 0) {
-        (*it).netLed->setValue(0);
-        (*it).netLed->setOff(KSim::Led::First);
-        (*it).netLed->setOff(KSim::Led::Second);
-        continue;
+      ( *it ).led()->setMaxValue( ( *it ).maxValue() / 1024 );
+      ( *it ).led()->setValue( receiveDiff / 1024 );
+
+      if ( receiveDiff == 0 )
+      {
+        ( *it ).led()->setOff( KSim::Led::First );
+      }
+      else if ( ( receiveDiff / 1024 ) >= halfMax )
+      {
+        ( *it ).led()->setOn( KSim::Led::First );
+      }
+      else
+      {
+        ( *it ).led()->toggle( KSim::Led::First );
       }
 
-      unsigned long halfMax = m_max[i] / 2;
-      (*it).netLed->setMaxValue(m_max[i] / 1024);
-      (*it).netLed->setValue(recieveDiff / 1024);
-      if (recieveDiff == 0)
-        (*it).netLed->setOff(KSim::Led::First);
+      if ( sendDiff == 0 )
+      {
+        ( *it ).led()->setOff( KSim::Led::Second );
+      }
+      else if ( ( sendDiff / 1024 ) >= halfMax )
+      {
+        ( *it ).led()->setOn( KSim::Led::Second );
+      }
       else
-        if ((recieveDiff / 1024) >= halfMax)
-          (*it).netLed->setOn(KSim::Led::First);
-        else
-          (*it).netLed->toggle(KSim::Led::First);
-
-      if (sendDiff == 0)
-        (*it).netLed->setOff(KSim::Led::Second);
-      else
-        if ((sendDiff / 1024) >= halfMax)
-          (*it).netLed->setOn(KSim::Led::Second);
-        else
-          (*it).netLed->toggle(KSim::Led::Second);
+      {
+        ( *it ).led()->toggle( KSim::Led::Second );
+      }
     }
-    else {
-      (*it).netLed->setMaxValue(0);
-      (*it).netLed->setValue(0);
-      (*it).netLed->setOff(KSim::Led::First);
-      (*it).netLed->setOff(KSim::Led::Second);
+    else
+    {
+      ( *it ).led()->setMaxValue( 0 );
+      ( *it ).led()->setValue( 0 );
+      ( *it ).led()->setOff( KSim::Led::First );
+      ( *it ).led()->setOff( KSim::Led::Second );
     }
-    ++i;
   }
 }
 
 void NetView::updateGraph()
 {
-  int i = 0;
-  QString hours, minutes, seconds;
-  int timer = 0, h = 0, m = 0, s = 0;
+  int timer = 0;
+  int hours = 0;
+  int minutes = 0;
+  int seconds = 0;
+
   time_t start = 0;
   struct stat st;
+
   QTime netTime;
-  QString timerFormat;
-  QString pid("/var/run/%1.pid");
+  QString timeDisplay;
+  QString pid( "/var/run/%1.pid" );
   QString newPid;
 
-  DeviceList::ConstIterator it;
-  for (it = m_widgetList.begin(); it != m_widgetList.end(); ++it) {
-    if (isOnline((*it).deviceName)) {
-      timerFormat = (*it).timerFormat;
-      newPid = pid.arg((*it).deviceName);
-      
-      if (QFile::exists(newPid) && stat(QFile::encodeName(newPid).data(), &st) == 0) {
-        start = st.st_mtime;
+  Network::List::Iterator it;
+  for ( it = m_networkList.begin(); it != m_networkList.end(); ++it )
+  {
+    if ( isOnline( ( *it ).name() ) )
+    {
+      NetData data;
 
-        timer = (int)(time(0) - start);
-        h = timer / 3600;
-        m = (timer - h * 3600) / 60;
-        s = timer % 60;
-        if (netTime.isValid(h, m, s))
-          netTime.setHMS(h, m, s);
+      if ( ( *it ).label() )
+      {
+        timeDisplay = ( *it ).format();
+        newPid = pid.arg( ( *it ).name() );
+
+        if ( QFile::exists( newPid ) && stat( QFile::encodeName( newPid ).data(), &st ) == 0 )
+        {
+          start = st.st_mtime;
+
+          timer = static_cast<int>( difftime( time( 0 ), start ) );
+          hours = timer / 3600;
+          minutes = (timer - hours * 3600) / 60;
+          seconds = timer % 60;
+          if ( netTime.isValid( hours, minutes, seconds ) )
+            netTime.setHMS( hours, minutes, seconds );
+        }
+
+        // Keep backwards compat for now
+        if ( timeDisplay.contains( '%' ) > 0 )
+          timeDisplay.replace( '%', "" );
+
+        ( *it ).label()->setText( netTime.toString( timeDisplay ) );
       }
 
-      m_oldData[i] = m_data[i];
+      netStatistics( ( *it ).name(), data );
+      ( *it ).setData( data );
 
-      if ((*it).showTimer) {
-        hours.sprintf("%02i", netTime.hour());
-        minutes.sprintf("%02i", netTime.minute());
-        seconds.sprintf("%02i", netTime.second());
+      unsigned long receiveDiff = data.in - ( *it ).oldData().in;
+      unsigned long sendDiff = data.out - ( *it ).oldData().out;
 
-        timerFormat.replace(QRegExp("%h"), hours);
-        timerFormat.replace(QRegExp("%m"), minutes);
-        timerFormat.replace(QRegExp("%s"), seconds);
-        (*it).netLabel->setText(timerFormat);
+      if ( m_firstTime )
+      {
+        receiveDiff = sendDiff = 0;
       }
 
-      netStatistics((*it).deviceName, m_data[i]);
+      ( *it ).chart()->setValue( receiveDiff, sendDiff );
+      ( *it ).setMaxValue( ( *it ).chart()->maxValue() );
 
-      unsigned long recieveDiff = m_data[i].in - m_oldData[i].in;
-      unsigned long sendDiff = m_data[i].out - m_oldData[i].out;
+      QString receiveString = KGlobal::locale()->formatNumber( ( float ) receiveDiff / 1024.0, 1 );
+      QString sendString = KGlobal::locale()->formatNumber( ( float ) sendDiff / 1024.0, 1 );
 
-      if (m_firstTime == 0) {
-        recieveDiff = 0;
-        sendDiff = 0;
-      }
-
-      if ((*it).netChart) {
-        (*it).netChart->setValue(recieveDiff, sendDiff);
-        m_max[i] = (*it).netChart->maxValue();
-
-        if ((*it).showLabel)
-          (*it).netChart->setText(i18n("in: %1k")
-             .arg(KGlobal::locale()->formatNumber((float)recieveDiff / 1024.0, 1)),
-             i18n("out: %1k").arg(KGlobal::locale()->formatNumber((float)sendDiff / 1024.0, 1)));
-      }
+      ( *it ).chart()->setText( i18n( "in: %1k" ).arg( receiveString ),
+         i18n( "out: %1k" ).arg( sendString ) );
     }
-    else {
-      m_data[i] = m_oldData[i] = 0;
-      m_max[i] = 0;
+    else
+    {
+      ( *it ).setData( NetData() );
+      ( *it ).chart()->setValue( 0, 0 );
 
-      if ((*it).netChart) {
-        (*it).netChart->setValue(0, 0);
+      ( *it ).chart()->setText( i18n( "in: %1k" ).arg( KGlobal::locale()->formatNumber( 0.0, 1 ) ),
+         i18n( "out: %1k" ).arg( KGlobal::locale()->formatNumber( 0.0, 1 ) ) );
 
-        if ((*it).showLabel)
-          (*it).netChart->setText(i18n("in: %1k")
-             .arg(KGlobal::locale()->formatNumber(0.0, 1)),
-             i18n("out: %1k").arg(KGlobal::locale()->formatNumber(0.0, 1)));
-      }
-
-      if ((*it).showTimer)
-        (*it).netLabel->setText(i18n("offline"));
+      if ( ( *it ).label() )
+        ( *it ).label()->setText( i18n( "offline" ) );
     }
-    ++i;
   }
 
-  if (m_firstTime != 1)
-    m_firstTime = 1;
+  if ( m_firstTime )
+    m_firstTime = false;
 }
 
 KSim::Chart *NetView::addChart()
@@ -450,10 +439,10 @@ KSim::Label *NetView::addLabel()
 QPopupMenu *NetView::addPopupMenu(const QString &device, int value)
 {
   QPopupMenu *popup = new QPopupMenu(this);
-  popup->insertItem(i18n("Connect"), this,
+  popup->insertItem(SmallIcon("network"), i18n("Connect"), this,
      SLOT(runConnectCommand(int)), 0, 1);
   popup->setItemParameter(1, value);
-  popup->insertItem(i18n("Disconnect"), this,
+  popup->insertItem(SmallIcon("network"), i18n("Disconnect"), this,
      SLOT(runDisconnectCommand(int)), 0, 2);
   popup->setItemParameter(2, value);
   menu()->insertItem(device, popup, 100 + value);
@@ -474,7 +463,7 @@ void NetView::netStatistics(const QString &device, NetData &data)
   // Parse the proc file
   while (!m_procStream->atEnd()) {
     parser = m_procStream->readLine();
-    // remove all the entrys apart from the line containing 'device'
+    // remove all the entries apart from the line containing 'device'
     if (parser.find(device) != -1)
       output = parser;
   }
@@ -485,7 +474,7 @@ void NetView::netStatistics(const QString &device, NetData &data)
     return;
   }
 
-  // make sure our output doesnt contain "eth0:11210107" so we dont
+  // make sure our output doesn't contain "eth0:11210107" so we dont
   // end up with netList[1] actually being netList[2]
   output.replace(QRegExp(":"), " ");
   QStringList netList = QStringList::split(' ', output);
@@ -631,4 +620,49 @@ bool NetView::isOnline(const QString &device)
 #endif
 }
 
+// EventFilter
+bool NetView::eventFilter( QObject * o, QEvent * e )
+{
+  // find out which interface we are
+  int i = 0;
+  Network::List::Iterator it;
+  for ( it = m_networkList.begin(); it != m_networkList.end(); ++it )
+  {
+    if ( o == ( *it ).chart() || o == ( *it ).label() || o == ( *it ).led() )
+    {
+      break;
+    }
+
+    ++i;
+  }
+
+  if ( e->type() == QEvent::MouseButtonPress )
+  {
+    if ( static_cast<QMouseEvent *>( e )->button() == QMouseEvent::RightButton )
+    {
+      showMenu(i);
+    }
+
+    return true;
+  }
+
+  return false;
+}
+
+void NetView::showMenu(int i) {
+
+  QPopupMenu menu;
+  menu.insertItem( SmallIcon("network"), i18n("Connect"), 1);
+  menu.insertItem( SmallIcon("network"), i18n("Disconnect"), 2);
+  switch (menu.exec(QCursor::pos())) {
+    case 1:
+      runConnectCommand(i);
+      break;
+    case 2:
+      runDisconnectCommand(i);
+      break;
+  }
+}
+
+
 #include "ksimnet.moc"
